@@ -4,7 +4,7 @@
     Description          : Aspect that manages a column
     --------------------------------------------------------------------
     Copyright            : (C) 2007-2009 Tilman Benkert (thzs@gmx.net)
-    Copyright            : (C) 2013-2015 by Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2013-2017 by Alexander Semke (alexander.semke@web.de)
 
  ***************************************************************************/
 
@@ -34,16 +34,14 @@
 #include "backend/core/datatypes/String2DateTimeFilter.h"
 #include "backend/core/datatypes/DateTime2StringFilter.h"
 
-#include <QFont>
-#include <QFontMetrics>
 #include <QThreadPool>
-
-#include <KIcon>
-#include <KLocale>
 #ifndef NDEBUG
 #include <QDebug>
 #endif
 
+#include <KIcon>
+#include <KLocale>
+
 extern "C" {
 #include <gsl/gsl_sort.h>
 }
@@ -71,8 +69,7 @@ extern "C" {
  * \param mode initial column mode
  */
 Column::Column(const QString& name, AbstractColumn::ColumnMode mode)
- : AbstractColumn(name), m_column_private( new ColumnPrivate(this, mode) )
-{
+	: AbstractColumn(name), m_column_private( new ColumnPrivate(this, mode) ) {
 	init();
 }
 
@@ -83,8 +80,7 @@ Column::Column(const QString& name, AbstractColumn::ColumnMode mode)
  * \param data initial data vector
  */
 Column::Column(const QString& name, QVector<double> data)
- : AbstractColumn(name), m_column_private( new ColumnPrivate(this, AbstractColumn::Numeric, new QVector<double>(data)) )
-{
+	: AbstractColumn(name), m_column_private( new ColumnPrivate(this, AbstractColumn::Numeric, new QVector<double>(data)) ) {
 	init();
 }
 
@@ -95,8 +91,7 @@ Column::Column(const QString& name, QVector<double> data)
  * \param data initial data vector
  */
 Column::Column(const QString& name, QStringList data)
- : AbstractColumn(name), m_column_private( new ColumnPrivate(this, AbstractColumn::Text, new QStringList(data)))
-{
+	: AbstractColumn(name), m_column_private( new ColumnPrivate(this, AbstractColumn::Text, new QStringList(data))) {
 	init();
 }
 
@@ -107,8 +102,7 @@ Column::Column(const QString& name, QStringList data)
  * \param data initial data vector
  */
 Column::Column(const QString& name, QList<QDateTime> data)
- : AbstractColumn(name), m_column_private( new ColumnPrivate(this, AbstractColumn::DateTime, new QList<QDateTime>(data)) )
-{
+	: AbstractColumn(name), m_column_private( new ColumnPrivate(this, AbstractColumn::DateTime, new QList<QDateTime>(data)) ) {
 	init();
 }
 
@@ -123,14 +117,6 @@ void Column::init() {
 	m_column_private->outputFilter()->setHidden(true);
 	addChild(m_column_private->inputFilter());
 	addChild(m_column_private->outputFilter());
-    m_column_private->statisticsAvailable = false;
-
-	//set the default width, synchronize this with the format used for the header in SpreadsheetModel::updateHorizontalHeader()
-	QString str = name() + QLatin1String(" {") + i18n("Numeric") + QLatin1String("} ");
-	QFont font;
-	QFontMetrics fm(font);
-	m_column_private->setWidth(fm.width(str)*1.1);
-
 	m_suppressDataChangedSignal = false;
 }
 
@@ -155,21 +141,18 @@ void Column::setSuppressDataChangedSignal(bool b) {
  * This sets the column mode and, if
  * necessary, converts it to another datatype.
  */
-void Column::setColumnMode(AbstractColumn::ColumnMode mode)
-{
+void Column::setColumnMode(AbstractColumn::ColumnMode mode) {
 	if(mode == columnMode()) return;
 	beginMacro(i18n("%1: change column type", name()));
 	AbstractSimpleFilter * old_input_filter = m_column_private->inputFilter();
 	AbstractSimpleFilter * old_output_filter = m_column_private->outputFilter();
 	exec(new ColumnSetModeCmd(m_column_private, mode));
-	if (m_column_private->inputFilter() != old_input_filter)
-	{
+	if (m_column_private->inputFilter() != old_input_filter) {
 		removeChild(old_input_filter);
 		addChild(m_column_private->inputFilter());
 		m_column_private->inputFilter()->input(0,m_string_io);
 	}
-	if (m_column_private->outputFilter() != old_output_filter)
-	{
+	if (m_column_private->outputFilter() != old_output_filter) {
 		removeChild(old_output_filter);
 		addChild(m_column_private->outputFilter());
 		m_column_private->outputFilter()->input(0, this);
@@ -177,7 +160,6 @@ void Column::setColumnMode(AbstractColumn::ColumnMode mode)
 	endMacro();
 }
 
-
 /**
  * \brief Copy another column of the same type
  *
@@ -185,8 +167,7 @@ void Column::setColumnMode(AbstractColumn::ColumnMode mode)
  * of 'other' is not the same as the type of 'this'.
  * Use a filter to convert a column to another type.
  */
-bool Column::copy(const AbstractColumn * other)
-{
+bool Column::copy(const AbstractColumn * other) {
 	Q_CHECK_PTR(other);
 	if(other->columnMode() != columnMode()) return false;
 	exec(new ColumnFullCopyCmd(m_column_private, other));
@@ -203,8 +184,7 @@ bool Column::copy(const AbstractColumn * other)
  * \param dest_start first row to copy in
  * \param num_rows the number of rows to copy
  */
-bool Column::copy(const AbstractColumn * source, int source_start, int dest_start, int num_rows)
-{
+bool Column::copy(const AbstractColumn * source, int source_start, int dest_start, int num_rows) {
 	Q_CHECK_PTR(source);
 	if(source->columnMode() != columnMode()) return false;
 	exec(new ColumnPartialCopyCmd(m_column_private, source, source_start, dest_start, num_rows));
@@ -214,8 +194,7 @@ bool Column::copy(const AbstractColumn * source, int source_start, int dest_star
 /**
  * \brief Insert some empty (or initialized with zero) rows
  */
-void Column::handleRowInsertion(int before, int count)
-{
+void Column::handleRowInsertion(int before, int count) {
 	AbstractColumn::handleRowInsertion(before, count);
 	exec(new ColumnInsertRowsCmd(m_column_private, before, count));
 	if (!m_suppressDataChangedSignal)
@@ -227,8 +206,7 @@ void Column::handleRowInsertion(int before, int count)
 /**
  * \brief Remove 'count' rows starting from row 'first'
  */
-void Column::handleRowRemoval(int first, int count)
-{
+void Column::handleRowRemoval(int first, int count) {
 	AbstractColumn::handleRowRemoval(first, count);
 	exec(new ColumnRemoveRowsCmd(m_column_private, first, count));
 	if (!m_suppressDataChangedSignal)
@@ -240,8 +218,7 @@ void Column::handleRowRemoval(int first, int count)
 /**
  * \brief Set the column plot designation
  */
-void Column::setPlotDesignation(AbstractColumn::PlotDesignation pd)
-{
+void Column::setPlotDesignation(AbstractColumn::PlotDesignation pd) {
 	if(pd != plotDesignation())
 		exec(new ColumnSetPlotDesignationCmd(m_column_private, pd));
 }
@@ -249,25 +226,21 @@ void Column::setPlotDesignation(AbstractColumn::PlotDesignation pd)
 /**
  * \brief Get width
  */
-int Column::width() const
-{
+int Column::width() const {
 	return m_column_private->width();
 }
 
 /**
  * \brief Set width
  */
-void Column::setWidth(int value)
-{
-	if (value != m_column_private->width())
-		exec(new ColumnSetWidthCmd(m_column_private, value));
+void Column::setWidth(int value) {
+	m_column_private->setWidth(value);
 }
 
 /**
  * \brief Clear the whole column
  */
-void Column::clear()
-{
+void Column::clear() {
 	exec(new ColumnClearCmd(m_column_private));
 }
 
@@ -304,24 +277,21 @@ void Column::setFormula(const QString& formula, const QStringList& variableNames
 /**
  * \brief Set a formula string for an interval of rows
  */
-void Column::setFormula(Interval<int> i, QString formula)
-{
+void Column::setFormula(Interval<int> i, QString formula) {
 	exec(new ColumnSetFormulaCmd(m_column_private, i, formula));
 }
 
 /**
  * \brief Overloaded function for convenience
  */
-void Column::setFormula(int row, QString formula)
-{
+void Column::setFormula(int row, QString formula) {
 	setFormula(Interval<int>(row, row), formula);
 }
 
 /**
  * \brief Clear all formulas
  */
-void Column::clearFormulas()
-{
+void Column::clearFormulas() {
 	exec(new ColumnClearFormulasCmd(m_column_private));
 }
 
@@ -371,9 +341,8 @@ void Column::setDateAt(int row, const QDate& new_value) {
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-void Column::setTimeAt(int row,const QTime& new_value)
-{
-    setStatisticsAvailable(false);
+void Column::setTimeAt(int row,const QTime& new_value) {
+	setStatisticsAvailable(false);
 	setDateTimeAt(row, QDateTime(dateAt(row), new_value));
 }
 
@@ -382,9 +351,8 @@ void Column::setTimeAt(int row,const QTime& new_value)
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-void Column::setDateTimeAt(int row, const QDateTime& new_value)
-{
-    setStatisticsAvailable(false);
+void Column::setDateTimeAt(int row, const QDateTime& new_value) {
+	setStatisticsAvailable(false);
 	exec(new ColumnSetDateTimeCmd(m_column_private, row, new_value));
 }
 
@@ -393,12 +361,11 @@ void Column::setDateTimeAt(int row, const QDateTime& new_value)
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-void Column::replaceDateTimes(int first, const QList<QDateTime>& new_values)
-{
-    if (!new_values.isEmpty()){
-        setStatisticsAvailable(false);
+void Column::replaceDateTimes(int first, const QList<QDateTime>& new_values) {
+	if (!new_values.isEmpty()) {
+		setStatisticsAvailable(false);
 		exec(new ColumnReplaceDateTimesCmd(m_column_private, first, new_values));
-    }
+	}
 }
 
 /**
@@ -406,9 +373,8 @@ void Column::replaceDateTimes(int first, const QList<QDateTime>& new_values)
  *
  * Use this only when columnMode() is Numeric
  */
-void Column::setValueAt(int row, double new_value)
-{
-    setStatisticsAvailable(false);
+void Column::setValueAt(int row, double new_value) {
+	setStatisticsAvailable(false);
 	exec(new ColumnSetValueCmd(m_column_private, row, new_value));
 }
 
@@ -417,12 +383,11 @@ void Column::setValueAt(int row, double new_value)
  *
  * Use this only when columnMode() is Numeric
  */
-void Column::replaceValues(int first, const QVector<double>& new_values)
-{
-    if (!new_values.isEmpty()){
-        setStatisticsAvailable(false);
+void Column::replaceValues(int first, const QVector<double>& new_values) {
+	if (!new_values.isEmpty()) {
+		setStatisticsAvailable(false);
 		exec(new ColumnReplaceValuesCmd(m_column_private, first, new_values));
-    }
+	}
 }
 
 void Column::setStatisticsAvailable(bool available) {
@@ -438,120 +403,114 @@ const Column::ColumnStatistics& Column::statistics() {
 	if (!statisticsAvailable())
 		calculateStatistics();
 
-    return m_column_private->statistics;
+	return m_column_private->statistics;
 }
 
 void Column::calculateStatistics() {
-    m_column_private->statistics = ColumnStatistics();
+	m_column_private->statistics = ColumnStatistics();
 	ColumnStatistics& statistics = m_column_private->statistics;
 
-    QVector<double>* rowValues = reinterpret_cast<QVector<double>*>(data());
+	QVector<double>* rowValues = reinterpret_cast<QVector<double>*>(data());
 
-    int notNanCount = 0;
-    double val;
-    double columnSum = 0.0;
-    double columnProduct = 1.0;
-    double columnSumNeg = 0.0;
-    double columnSumSquare = 0.0;
-    statistics.minimum = INFINITY;
-    statistics.maximum = -INFINITY;
-    QMap<double, int> frequencyOfValues;
-    QVector<double> rowData;
-    rowData.reserve(rowValues->size());
-    for (int row = 0; row < rowValues->size(); ++row) {
-        val = rowValues->value(row);
-        if (std::isnan(val) || isMasked(row))
-            continue;
+	int notNanCount = 0;
+	double val;
+	double columnSum = 0.0;
+	double columnProduct = 1.0;
+	double columnSumNeg = 0.0;
+	double columnSumSquare = 0.0;
+	statistics.minimum = INFINITY;
+	statistics.maximum = -INFINITY;
+	QMap<double, int> frequencyOfValues;
+	QVector<double> rowData;
+	rowData.reserve(rowValues->size());
+	for (int row = 0; row < rowValues->size(); ++row) {
+		val = rowValues->value(row);
+		if (std::isnan(val) || isMasked(row))
+			continue;
 
-        if (val < statistics.minimum){
-            statistics.minimum = val;
-        }
-        if (val > statistics.maximum){
-            statistics.maximum = val;
-        }
-        columnSum+= val;
-        columnSumNeg += (1.0 / val);
-        columnSumSquare += pow(val, 2.0);
-        columnProduct *= val;
-        if (frequencyOfValues.contains(val)){
-            frequencyOfValues.operator [](val)++;
-        }
-        else{
-            frequencyOfValues.insert(val, 1);
-        }
-        ++notNanCount;
-        rowData.push_back(val);
-    }
+		if (val < statistics.minimum)
+			statistics.minimum = val;
+		if (val > statistics.maximum)
+			statistics.maximum = val;
+		columnSum+= val;
+		columnSumNeg += (1.0 / val);
+		columnSumSquare += pow(val, 2.0);
+		columnProduct *= val;
+		if (frequencyOfValues.contains(val))
+			frequencyOfValues.operator [](val)++;
+		else
+			frequencyOfValues.insert(val, 1);
+		++notNanCount;
+		rowData.push_back(val);
+	}
 
-    if (notNanCount == 0) {
+	if (notNanCount == 0) {
 		setStatisticsAvailable(true);
 		return;
 	}
 
-    if (rowData.size() < rowValues->size()){
-        rowData.squeeze();
-    }
+	if (rowData.size() < rowValues->size())
+		rowData.squeeze();
 
-    statistics.arithmeticMean = columnSum / notNanCount;
-    statistics.geometricMean = pow(columnProduct, 1.0 / notNanCount);
-    statistics.harmonicMean = notNanCount / columnSumNeg;
-    statistics.contraharmonicMean = columnSumSquare / columnSum;
+	statistics.arithmeticMean = columnSum / notNanCount;
+	statistics.geometricMean = pow(columnProduct, 1.0 / notNanCount);
+	statistics.harmonicMean = notNanCount / columnSumNeg;
+	statistics.contraharmonicMean = columnSumSquare / columnSum;
 
-    double columnSumVariance = 0;
-    double columnSumMeanDeviation = 0.0;
-    double columnSumMedianDeviation = 0.0;
-    double sumForCentralMoment_r3 = 0.0;
-    double sumForCentralMoment_r4 = 0.0;
+	double columnSumVariance = 0;
+	double columnSumMeanDeviation = 0.0;
+	double columnSumMedianDeviation = 0.0;
+	double sumForCentralMoment_r3 = 0.0;
+	double sumForCentralMoment_r4 = 0.0;
 
-    gsl_sort(rowData.data(), 1, notNanCount);
-    statistics.median = (notNanCount % 2 ? rowData.at((notNanCount-1)/2) :
-                                             (rowData.at((notNanCount-1)/2) +
-                                              rowData.at(notNanCount/2))/2.0);
-    QVector<double> absoluteMedianList;
-    absoluteMedianList.reserve(notNanCount);
-    absoluteMedianList.resize(notNanCount);
+	gsl_sort(rowData.data(), 1, notNanCount);
+	statistics.median = (notNanCount%2) ? rowData.at((notNanCount-1)/2) :
+	                    (rowData.at((notNanCount-1)/2) + rowData.at(notNanCount/2))/2.0;
+	QVector<double> absoluteMedianList;
+	absoluteMedianList.reserve(notNanCount);
+	absoluteMedianList.resize(notNanCount);
 
-    int idx = 0;
-    for(int row = 0; row < rowValues->size(); ++row){
-        val = rowValues->value(row);
-        if ( std::isnan(val) || isMasked(row) )
-            continue;
-        columnSumVariance+= pow(val - statistics.arithmeticMean, 2.0);
+	int idx = 0;
+	for(int row = 0; row < rowValues->size(); ++row) {
+		val = rowValues->value(row);
+		if ( std::isnan(val) || isMasked(row) )
+			continue;
+		columnSumVariance+= pow(val - statistics.arithmeticMean, 2.0);
 
-        sumForCentralMoment_r3 += pow(val - statistics.arithmeticMean, 3.0);
-        sumForCentralMoment_r4 += pow(val - statistics.arithmeticMean, 4.0);
-        columnSumMeanDeviation += fabs( val - statistics.arithmeticMean );
+		sumForCentralMoment_r3 += pow(val - statistics.arithmeticMean, 3.0);
+		sumForCentralMoment_r4 += pow(val - statistics.arithmeticMean, 4.0);
+		columnSumMeanDeviation += fabs( val - statistics.arithmeticMean );
 
-        absoluteMedianList[idx] = fabs(val - statistics.median);
-        columnSumMedianDeviation += absoluteMedianList[idx];
-        idx++;
-    }
+		absoluteMedianList[idx] = fabs(val - statistics.median);
+		columnSumMedianDeviation += absoluteMedianList[idx];
+		idx++;
+	}
 
-    statistics.meanDeviationAroundMedian = columnSumMedianDeviation / notNanCount;
-    statistics.medianDeviation = (notNanCount % 2 ? absoluteMedianList.at((notNanCount-1)/2) :
-                                                      (absoluteMedianList.at((notNanCount-1)/2) + absoluteMedianList.at(notNanCount/2))/2.0);
+	statistics.meanDeviationAroundMedian = columnSumMedianDeviation / notNanCount;
+	statistics.medianDeviation = (notNanCount%2) ? absoluteMedianList.at((notNanCount-1)/2) :
+	                             (absoluteMedianList.at((notNanCount-1)/2) + absoluteMedianList.at(notNanCount/2))/2.0;
 
-    const double centralMoment_r3 = sumForCentralMoment_r3 / notNanCount;
-    const double centralMoment_r4 = sumForCentralMoment_r4 / notNanCount;
+	const double centralMoment_r3 = sumForCentralMoment_r3 / notNanCount;
+	const double centralMoment_r4 = sumForCentralMoment_r4 / notNanCount;
 
-    statistics.variance = columnSumVariance / notNanCount;
-    statistics.standardDeviation = sqrt(statistics.variance);
-    statistics.skewness = centralMoment_r3 / pow(statistics.standardDeviation, 3.0);
-    statistics.kurtosis = (centralMoment_r4 / pow(statistics.standardDeviation, 4.0)) - 3.0;
-    statistics.meanDeviation = columnSumMeanDeviation / notNanCount;
+	statistics.variance = columnSumVariance / notNanCount;
+	statistics.standardDeviation = sqrt(statistics.variance);
+	statistics.skewness = centralMoment_r3 / pow(statistics.standardDeviation, 3.0);
+	statistics.kurtosis = (centralMoment_r4 / pow(statistics.standardDeviation, 4.0)) - 3.0;
+	statistics.meanDeviation = columnSumMeanDeviation / notNanCount;
 
-    double entropy = 0.0;
-    QList<int> frequencyOfValuesValues = frequencyOfValues.values();
-    for (int i = 0; i < frequencyOfValuesValues.size(); ++i){
-        double frequencyNorm = static_cast<double>(frequencyOfValuesValues.at(i)) / notNanCount;
-        entropy += (frequencyNorm * log2(frequencyNorm));
-    }
+	double entropy = 0.0;
+	QList<int> frequencyOfValuesValues = frequencyOfValues.values();
+	for (int i = 0; i < frequencyOfValuesValues.size(); ++i) {
+		double frequencyNorm = static_cast<double>(frequencyOfValuesValues.at(i)) / notNanCount;
+		entropy += (frequencyNorm * log2(frequencyNorm));
+	}
 
-    statistics.entropy = -entropy;
-    setStatisticsAvailable(true);
+	statistics.entropy = -entropy;
+	setStatisticsAvailable(true);
 }
 
-void* Column::data() const{
+void* Column::data() const {
 	return m_column_private->dataPointer();
 }
 /**
@@ -559,8 +518,7 @@ void* Column::data() const{
  *
  * Use this only when columnMode() is Text
  */
-QString Column::textAt(int row) const
-{
+QString Column::textAt(int row) const {
 	return m_column_private->textAt(row);
 }
 
@@ -569,8 +527,7 @@ QString Column::textAt(int row) const
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-QDate Column::dateAt(int row) const
-{
+QDate Column::dateAt(int row) const {
 	return m_column_private->dateAt(row);
 }
 
@@ -579,8 +536,7 @@ QDate Column::dateAt(int row) const
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-QTime Column::timeAt(int row) const
-{
+QTime Column::timeAt(int row) const {
 	return m_column_private->timeAt(row);
 }
 
@@ -589,16 +545,14 @@ QTime Column::timeAt(int row) const
  *
  * Use this only when columnMode() is DateTime, Month or Day
  */
-QDateTime Column::dateTimeAt(int row) const
-{
+QDateTime Column::dateTimeAt(int row) const {
 	return m_column_private->dateTimeAt(row);
 }
 
 /**
  * \brief Return the double value in row 'row'
  */
-double Column::valueAt(int row) const
-{
+double Column::valueAt(int row) const {
 	return m_column_private->valueAt(row);
 }
 
@@ -622,18 +576,16 @@ void Column::setChanged() {
  * \brief Return an icon to be used for decorating the views and spreadsheet column headers
  */
 QIcon Column::icon() const {
-	//TODO: provide type-specific icons
-// 	switch(columnMode()) {
-// 		case AbstractColumn::Numeric:
-// 			return KIcon("x-shape-text");
-// 		case AbstractColumn::Text:
-// 			return QIcon(QPixmap(":/texttype.png"));
-// 		case AbstractColumn::DateTime:
-// 		case AbstractColumn::Month:
-// 		case AbstractColumn::Day:
-// 			return QIcon(QPixmap(""));
-// 	}
-
+	switch(columnMode()) {
+	case AbstractColumn::Numeric:
+		return KIcon("x-shape-text");
+	case AbstractColumn::Text:
+		return KIcon("draw-text");
+	case AbstractColumn::DateTime:
+	case AbstractColumn::Month:
+	case AbstractColumn::Day:
+		return KIcon("chronometer");
+	}
 	return KIcon("x-shape-text");
 }
 
@@ -658,15 +610,13 @@ void Column::save(QXmlStreamWriter* writer) const {
 		writer->writeTextElement("text", formula());
 
 		writer->writeStartElement("variableNames");
-		for (int i=0; i<formulaVariableNames().size(); ++i) {
+		for (int i=0; i<formulaVariableNames().size(); ++i)
 			writer->writeTextElement("name", formulaVariableNames().at(i));
-		}
 		writer->writeEndElement();
 
 		writer->writeStartElement("columnPathes");
-		for (int i=0; i<formulaVariableColumnPathes().size(); ++i) {
+		for (int i=0; i<formulaVariableColumnPathes().size(); ++i)
 			writer->writeTextElement("path", formulaVariableColumnPathes().at(i));
-		}
 		writer->writeEndElement();
 
 		writer->writeEndElement();
@@ -695,53 +645,53 @@ void Column::save(QXmlStreamWriter* writer) const {
 
 	int i;
 	switch(columnMode()) {
-		case AbstractColumn::Numeric:
-			{
-				const char* data = reinterpret_cast<const char*>(
-				static_cast< QVector<double>* >(m_column_private->dataPointer())->constData());
-				int size = m_column_private->rowCount()*sizeof(double);
-				writer->writeCharacters(QByteArray::fromRawData(data,size).toBase64());
-				break;
-			}
-		case AbstractColumn::Text:
-			for(i=0; i<rowCount(); ++i)
-			{
-				writer->writeStartElement("row");
-				writer->writeAttribute("index", QString::number(i));
-				writer->writeCharacters(textAt(i));
-				writer->writeEndElement();
-			}
+	case AbstractColumn::Numeric: {
+			const char* data = reinterpret_cast<const char*>(
+			                       static_cast< QVector<double>* >(m_column_private->dataPointer())->constData());
+			int size = m_column_private->rowCount()*sizeof(double);
+			writer->writeCharacters(QByteArray::fromRawData(data,size).toBase64());
 			break;
+		}
+	case AbstractColumn::Text:
+		for(i=0; i<rowCount(); ++i) {
+			writer->writeStartElement("row");
+			writer->writeAttribute("index", QString::number(i));
+			writer->writeCharacters(textAt(i));
+			writer->writeEndElement();
+		}
+		break;
 
-		case AbstractColumn::DateTime:
-		case AbstractColumn::Month:
-		case AbstractColumn::Day:
-			for(i=0; i<rowCount(); ++i)
-			{
-				writer->writeStartElement("row");
-				writer->writeAttribute("index", QString::number(i));
-				writer->writeCharacters(dateTimeAt(i).toString("yyyy-dd-MM hh:mm:ss:zzz"));
-				writer->writeEndElement();
-			}
-			break;
+	case AbstractColumn::DateTime:
+	case AbstractColumn::Month:
+	case AbstractColumn::Day:
+		for(i=0; i<rowCount(); ++i) {
+			writer->writeStartElement("row");
+			writer->writeAttribute("index", QString::number(i));
+			writer->writeCharacters(dateTimeAt(i).toString("yyyy-dd-MM hh:mm:ss:zzz"));
+			writer->writeEndElement();
+		}
+		break;
 	}
 
 	writer->writeEndElement(); // "column"
 }
 
 class DecodeColumnTask : public QRunnable {
-	public:
-		DecodeColumnTask(ColumnPrivate* priv, const QString& content) { m_private = priv; m_content = content;};
-		void run() {
-			QByteArray bytes = QByteArray::fromBase64(m_content.toAscii());
-			QVector<double> * data = new QVector<double>(bytes.size()/sizeof(double));
-			memcpy(data->data(), bytes.data(), bytes.size());
-			m_private->replaceData(data);
-		}
+public:
+	DecodeColumnTask(ColumnPrivate* priv, const QString& content) {
+		m_private = priv;
+		m_content = content;
+	};
+	void run() {
+		QByteArray bytes = QByteArray::fromBase64(m_content.toAscii());
+		QVector<double> * data = new QVector<double>(bytes.size()/sizeof(double));
+		memcpy(data->data(), bytes.data(), bytes.size());
+		m_private->replaceData(data);
+	}
 
-	private:
-		ColumnPrivate* m_private;
-		QString m_content;
+private:
+	ColumnPrivate* m_private;
+	QString m_content;
 };
 
 /**
@@ -787,8 +737,7 @@ bool Column::load(XmlStreamReader* reader) {
 					ret_val = XmlReadFormula(reader);
 				else if(reader->name() == "row")
 					ret_val = XmlReadRow(reader);
-				else // unknown element
-				{
+				else { // unknown element
 					reader->raiseWarning(i18n("unknown element '%1'", reader->name().toString()));
 					if (!reader->skipToEndElement()) return false;
 				}
@@ -801,8 +750,7 @@ bool Column::load(XmlStreamReader* reader) {
 				QThreadPool::globalInstance()->start(task);
 			}
 		}
-	}
-	else // no column element
+	} else // no column element
 		reader->raiseError(i18n("no column element found"));
 
 	return !reader->error();
@@ -811,8 +759,7 @@ bool Column::load(XmlStreamReader* reader) {
 /**
  * \brief Read XML input filter element
  */
-bool Column::XmlReadInputFilter(XmlStreamReader * reader)
-{
+bool Column::XmlReadInputFilter(XmlStreamReader * reader) {
 	Q_ASSERT(reader->isStartElement() && reader->name() == "input_filter");
 	if (!reader->skipToNextTag()) return false;
 	if (!m_column_private->inputFilter()->load(reader)) return false;
@@ -824,8 +771,7 @@ bool Column::XmlReadInputFilter(XmlStreamReader * reader)
 /**
  * \brief Read XML output filter element
  */
-bool Column::XmlReadOutputFilter(XmlStreamReader * reader)
-{
+bool Column::XmlReadOutputFilter(XmlStreamReader * reader) {
 	Q_ASSERT(reader->isStartElement() && reader->name() == "output_filter");
 	if (!reader->skipToNextTag()) return false;
 	if (!m_column_private->outputFilter()->load(reader)) return false;
@@ -844,9 +790,9 @@ bool Column::XmlReadFormula(XmlStreamReader* reader) {
 	while (reader->readNext()) {
 		if (reader->isEndElement()) break;
 
-		if (reader->name() == "text") {
+		if (reader->name() == "text")
 			formula = reader->readElementText();
-		} else if (reader->name() == "variableNames") {
+		else if (reader->name() == "variableNames") {
 			while (reader->readNext()) {
 				if (reader->name() == "variableNames" && reader->isEndElement()) break;
 
@@ -890,8 +836,7 @@ bool Column::XmlReadFormula(XmlStreamReader* reader) {
 /**
  * \brief Read XML row element
  */
-bool Column::XmlReadRow(XmlStreamReader * reader)
-{
+bool Column::XmlReadRow(XmlStreamReader * reader) {
 	Q_ASSERT(reader->isStartElement() && reader->name() == "row");
 
 	QString str;
@@ -907,26 +852,25 @@ bool Column::XmlReadRow(XmlStreamReader * reader)
 
 	str = reader->readElementText();
 	switch(columnMode()) {
-		case AbstractColumn::Numeric:
-			{
-				double value = str.toDouble(&ok);
-				if(!ok) {
-					reader->raiseError(i18n("invalid row value"));
-					return false;
-				}
-				setValueAt(index, value);
-				break;
+	case AbstractColumn::Numeric: {
+			double value = str.toDouble(&ok);
+			if(!ok) {
+				reader->raiseError(i18n("invalid row value"));
+				return false;
 			}
-		case AbstractColumn::Text:
-			setTextAt(index, str);
+			setValueAt(index, value);
 			break;
+		}
+	case AbstractColumn::Text:
+		setTextAt(index, str);
+		break;
 
-		case AbstractColumn::DateTime:
-		case AbstractColumn::Month:
-		case AbstractColumn::Day:
-			QDateTime date_time = QDateTime::fromString(str,"yyyy-dd-MM hh:mm:ss:zzz");
-			setDateTimeAt(index, date_time);
-			break;
+	case AbstractColumn::DateTime:
+	case AbstractColumn::Month:
+	case AbstractColumn::Day:
+		QDateTime date_time = QDateTime::fromString(str,"yyyy-dd-MM hh:mm:ss:zzz");
+		setDateTimeAt(index, date_time);
+		break;
 	}
 
 	return true;
@@ -950,8 +894,7 @@ bool Column::isReadOnly() const {
  * by plots. The column mode specifies how to interpret
  * the values in the column additional to the data type.
  */
-AbstractColumn::ColumnMode Column::columnMode() const
-{
+AbstractColumn::ColumnMode Column::columnMode() const {
 	return m_column_private->columnMode();
 }
 
@@ -962,28 +905,25 @@ AbstractColumn::ColumnMode Column::columnMode() const
  * Rows beyond this can be masked etc. but should be ignored by filters,
  * plots etc.
  */
-int Column::rowCount() const
-{
+int Column::rowCount() const {
 	return m_column_private->rowCount();
 }
 
 /**
  * \brief Return the column plot designation
  */
-AbstractColumn::PlotDesignation Column::plotDesignation() const
-{
+AbstractColumn::PlotDesignation Column::plotDesignation() const {
 	return m_column_private->plotDesignation();
 }
 
-AbstractSimpleFilter * Column::outputFilter() const
-{
+AbstractSimpleFilter* Column::outputFilter() const {
 	return m_column_private->outputFilter();
 }
 
 /**
  * \brief Return a wrapper column object used for String I/O.
  */
-ColumnStringIO *Column::asStringColumn() const {
+ColumnStringIO* Column::asStringColumn() const {
 	return m_string_io;
 }
 
@@ -994,8 +934,7 @@ ColumnStringIO *Column::asStringColumn() const {
 /**
  * \brief Return the formula associated with row 'row'
  */
-QString Column::formula(int row) const
-{
+QString Column::formula(int row) const {
 	return m_column_private->formula(row);
 }
 
@@ -1012,16 +951,14 @@ QString Column::formula(int row) const
  * 	list << QString(interval.toString() + ": " + my_column.formula(interval.start()));
  * \endcode
  */
-QList< Interval<int> > Column::formulaIntervals() const
-{
+QList< Interval<int> > Column::formulaIntervals() const {
 	return m_column_private->formulaIntervals();
 }
 
-void Column::handleFormatChange()
-{
+void Column::handleFormatChange() {
 	if (columnMode() == AbstractColumn::DateTime) {
-		String2DateTimeFilter *input_filter = static_cast<String2DateTimeFilter*>(m_column_private->inputFilter());
-		DateTime2StringFilter *output_filter = static_cast<DateTime2StringFilter*>(m_column_private->outputFilter());
+		String2DateTimeFilter* input_filter = static_cast<String2DateTimeFilter*>(m_column_private->inputFilter());
+		DateTime2StringFilter* output_filter = static_cast<DateTime2StringFilter*>(m_column_private->outputFilter());
 		input_filter->setFormat(output_filter->format());
 	}
 
@@ -1036,8 +973,7 @@ void Column::handleFormatChange()
  * \class ColumnStringIO
  * \brief String-IO interface of Column.
  */
-void ColumnStringIO::setTextAt(int row, const QString &value)
-{
+void ColumnStringIO::setTextAt(int row, const QString &value) {
 	m_setting = true;
 	m_to_set = value;
 	m_owner->copy(m_owner->m_column_private->inputFilter()->output(0), 0, row, 1);
@@ -1046,8 +982,7 @@ void ColumnStringIO::setTextAt(int row, const QString &value)
 	m_owner->setStatisticsAvailable(false);
 }
 
-QString ColumnStringIO::textAt(int row) const
-{
+QString ColumnStringIO::textAt(int row) const {
 	if (m_setting)
 		return m_to_set;
 	else
