@@ -153,7 +153,7 @@ bool DatapickerImage::exportView() const {
 	ExportWorksheetDialog* dlg = new ExportWorksheetDialog(m_view);
 	dlg->setFileName(name());
     bool ret;
-    if ( (ret = dlg->exec()==QDialog::Accepted)){
+    if ( (ret = (dlg->exec()==QDialog::Accepted)) ){
 		const QString path = dlg->path();
 		const WorksheetView::ExportFormat format = dlg->exportFormat();
 		const int resolution = dlg->exportResolution();
@@ -172,7 +172,7 @@ bool DatapickerImage::printView() {
 	QPrintDialog* dlg = new QPrintDialog(&printer, m_view);
     bool ret;
 	dlg->setWindowTitle(i18n("Print Datapicker Image"));
-    if ((ret = dlg->exec() == QDialog::Accepted)) {
+    if ( (ret = (dlg->exec() == QDialog::Accepted)) ) {
 		DatapickerImageView* view = reinterpret_cast<DatapickerImageView*>(m_view);
 		view->print(&printer);
 	}
