@@ -3,7 +3,7 @@ File                 : AsciiFilter.cpp
 Project              : LabPlot
 Description          : ASCII I/O-filter
 --------------------------------------------------------------------
-Copyright            : (C) 2009-2015 Stefan Gerlach (stefan.gerlach@uni.kn)
+Copyright            : (C) 2009-2017 Stefan Gerlach (stefan.gerlach@uni.kn)
 Copyright            : (C) 2009-2015 Alexander Semke (alexander.semke@web.de)
 
 ***************************************************************************/
@@ -30,9 +30,9 @@ Copyright            : (C) 2009-2015 Alexander Semke (alexander.semke@web.de)
 #include "backend/datasources/filters/AsciiFilterPrivate.h"
 #include "backend/datasources/FileDataSource.h"
 #include "backend/core/column/Column.h"
+#include "backend/lib/macros.h"
 
 #include <QTextStream>
-#include <QDebug>
 #include <KLocale>
 #include <KFilterDev>
 
@@ -56,7 +56,7 @@ AsciiFilter::~AsciiFilter() {
 /*!
   reads the content of the file \c fileName.
 */
-QString AsciiFilter::readData(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode importMode,  int lines) {
+QList <QStringList> AsciiFilter::readData(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode importMode, int lines) {
 	return d->readData(fileName, dataSource, importMode, lines);
 }
 
@@ -102,16 +102,15 @@ QStringList AsciiFilter::predefinedFilters() {
   returns the list of all predefined separator characters.
 */
 QStringList AsciiFilter::separatorCharacters() {
-	return (QStringList()<<"auto"<<"TAB"<<"SPACE"<<","<<";"<<":"
-				  <<",TAB"<<";TAB"<<":TAB"
-				  <<",SPACE"<<";SPACE"<<":SPACE");
+	return (QStringList() << "auto" << "TAB" << "SPACE" << "," << ";" << ":"
+		<< ",TAB" << ";TAB" << ":TAB" << ",SPACE" << ";SPACE" << ":SPACE");
 }
 
 /*!
 returns the list of all predefined comment characters.
 */
 QStringList AsciiFilter::commentCharacters() {
-	return (QStringList()<<"#"<<"!"<<"//"<<"+"<<"c"<<":"<<";");
+	return (QStringList() << "#" << "!" << "//" << "+" << "c" << ":" << ";");
 }
 
 /*!
@@ -126,7 +125,8 @@ int AsciiFilter::columnNumber(const QString & fileName) {
 		return 0;
 
 	line = device.readLine();
-	lineStringList = line.split( QRegExp("\\s+")); //TODO
+	lineStringList = line.split(QRegExp("\\s+")); //TODO
+
 	return lineStringList.size();
 }
 
@@ -134,13 +134,13 @@ int AsciiFilter::columnNumber(const QString & fileName) {
 /*!
   returns the number of lines in the file \c fileName.
 */
-long AsciiFilter::lineNumber(const QString & fileName) {
+size_t AsciiFilter::lineNumber(const QString & fileName) {
 	//TODO: compare the speed of this function with the speed of wc from GNU-coreutils.
 	KFilterDev device(fileName);
 	if (!device.open(QIODevice::ReadOnly))
 		return 0;
 
-	long rows=0;
+	size_t rows = 0;
 	while (!device.atEnd()) {
 		device.readLine();
 		rows++;
@@ -150,7 +150,7 @@ long AsciiFilter::lineNumber(const QString & fileName) {
 }
 
 void AsciiFilter::setTransposed(const bool b) {
-	d->transposed=b;
+	d->transposed = b;
 }
 
 bool AsciiFilter::isTransposed() const{
@@ -158,7 +158,7 @@ bool AsciiFilter::isTransposed() const{
 }
 
 void AsciiFilter::setCommentCharacter(const QString& s) {
-	d->commentCharacter=s;
+	d->commentCharacter = s;
 }
 
 QString AsciiFilter::commentCharacter() const{
@@ -166,7 +166,7 @@ QString AsciiFilter::commentCharacter() const{
 }
 
 void AsciiFilter::setSeparatingCharacter(const QString& s) {
-	d->separatingCharacter=s;
+	d->separatingCharacter = s;
 }
 
 QString AsciiFilter::separatingCharacter() const{
@@ -174,7 +174,7 @@ QString AsciiFilter::separatingCharacter() const{
 }
 
 void AsciiFilter::setAutoModeEnabled(bool b) {
-	d->autoModeEnabled=b;
+	d->autoModeEnabled = b;
 }
 
 bool AsciiFilter::isAutoModeEnabled() const{
@@ -182,7 +182,7 @@ bool AsciiFilter::isAutoModeEnabled() const{
 }
 
 void AsciiFilter::setHeaderEnabled(bool b) {
-	d->headerEnabled=b;
+	d->headerEnabled = b;
 }
 
 bool AsciiFilter::isHeaderEnabled() const{
@@ -190,7 +190,7 @@ bool AsciiFilter::isHeaderEnabled() const{
 }
 
 void AsciiFilter::setVectorNames(const QString s) {
-	d->vectorNames=s.simplified();
+	d->vectorNames = s.simplified();
 }
 
 QString AsciiFilter::vectorNames() const{
@@ -198,7 +198,7 @@ QString AsciiFilter::vectorNames() const{
 }
 
 void AsciiFilter::setSkipEmptyParts(bool b) {
-	d->skipEmptyParts=b;
+	d->skipEmptyParts = b;
 }
 
 bool AsciiFilter::skipEmptyParts() const{
@@ -206,7 +206,7 @@ bool AsciiFilter::skipEmptyParts() const{
 }
 
 void AsciiFilter::setSimplifyWhitespacesEnabled(bool b) {
-	d->simplifyWhitespacesEnabled=b;
+	d->simplifyWhitespacesEnabled = b;
 }
 
 bool AsciiFilter::simplifyWhitespacesEnabled() const{
@@ -214,7 +214,7 @@ bool AsciiFilter::simplifyWhitespacesEnabled() const{
 }
 
 void AsciiFilter::setStartRow(const int r) {
-	d->startRow=r;
+	d->startRow = r;
 }
 
 int AsciiFilter::startRow() const{
@@ -222,7 +222,7 @@ int AsciiFilter::startRow() const{
 }
 
 void AsciiFilter::setEndRow(const int r) {
-	d->endRow=r;
+	d->endRow = r;
 }
 
 int AsciiFilter::endRow() const{
@@ -230,7 +230,7 @@ int AsciiFilter::endRow() const{
 }
 
 void AsciiFilter::setStartColumn(const int c) {
-	d->startColumn=c;
+	d->startColumn = c;
 }
 
 int AsciiFilter::startColumn() const{
@@ -238,7 +238,7 @@ int AsciiFilter::startColumn() const{
 }
 
 void AsciiFilter::setEndColumn(const int c) {
-	d->endColumn=c;
+	d->endColumn = c;
 }
 
 int AsciiFilter::endColumn() const{
@@ -266,18 +266,19 @@ AsciiFilterPrivate::AsciiFilterPrivate(AsciiFilter* owner) : q(owner),
     reads the content of the file \c fileName to the data source \c dataSource or return as string for preview.
     Uses the settings defined in the data source.
 */
-QString AsciiFilterPrivate::readData(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode mode, int lines) {
+QList<QStringList> AsciiFilterPrivate::readData(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode mode, int lines) {
 
 	KFilterDev device(fileName);
+	QList<QStringList> dataStrings;
 	if (!device.open(QIODevice::ReadOnly))
-		return QString();
+		return dataStrings << (QStringList() << QString());
 
 	//TODO implement
 	// if (transposed)
 	//...
 
 	//skip rows, if required
-	for (int i=0; i < startRow-1; i++) {
+	for (int i = 0; i < startRow - 1; i++) {
 		//if the number of rows to skip is bigger then the actual number of the rows in the file, then quit the function.
 		if( device.atEnd() ) {
 			if (mode == AbstractFileFilter::Replace) {
@@ -285,7 +286,7 @@ QString AsciiFilterPrivate::readData(const QString & fileName, AbstractDataSourc
 				if (dataSource != NULL)
 					dataSource->clear();
 			}
-			return QString();
+			return dataStrings << (QStringList() << QString());
 		}
 
 		device.readLine();
@@ -300,7 +301,7 @@ QString AsciiFilterPrivate::readData(const QString & fileName, AbstractDataSourc
 			if (dataSource != NULL)
 				dataSource->clear();
 		}
-		return QString();
+		return dataStrings << (QStringList() << QString());
 	}
 
 	QString line = device.readLine();
@@ -312,27 +313,27 @@ QString AsciiFilterPrivate::readData(const QString & fileName, AbstractDataSourc
 	QStringList lineStringList;
 	if (separatingCharacter == "auto") {
 		QRegExp regExp("(\\s+)|(,\\s+)|(;\\s+)|(:\\s+)");
-		lineStringList = line.split( regExp, QString::SplitBehavior(skipEmptyParts) );
+		lineStringList = line.split(regExp, QString::SplitBehavior(skipEmptyParts));
 
 		//determine the separator
-		if (lineStringList.size()) {
+		DEBUG("auto columns =" << lineStringList.size());
+		if (!lineStringList.isEmpty()) {
 			int length1 = lineStringList.at(0).length();
-			if (lineStringList.size()>1) {
-				int pos2 = line.indexOf(lineStringList.at(1),length1);
-				separator = line.mid(length1, pos2-length1);
-			}else {
-				separator = line.right(line.length()-length1);
+			if (lineStringList.size() > 1) {
+				int pos2 = line.indexOf(lineStringList.at(1), length1);
+				separator = line.mid(length1, pos2 - length1);
+			} else {
+				//old: separator = line.right(line.length() - length1);
+				separator = ' ';
 			}
 		}
 	} else {
-		separator = separatingCharacter.replace(QLatin1String("TAB"), QLatin1String("\t"), Qt::CaseInsensitive);
-		separator = separatingCharacter.replace(QLatin1String("SPACE"), QLatin1String(" "), Qt::CaseInsensitive);
+		separator = separatingCharacter.replace(QLatin1String("TAB"), QLatin1String(" "), Qt::CaseInsensitive);
+		separator = separator.replace(QLatin1String("SPACE"), QLatin1String(" "), Qt::CaseInsensitive);
 		lineStringList = line.split(separator, QString::SplitBehavior(skipEmptyParts));
 	}
-#ifndef NDEBUG
- 	qDebug() << "separator '"<<separator << "'";
- 	qDebug() << "headerEnabled ="<<headerEnabled;
-#endif
+ 	QDEBUG("separator: " << separator);
+ 	DEBUG("headerEnabled =" << headerEnabled);
 
 	if (endColumn == -1)
 		endColumn = lineStringList.size(); //use the last available column index
@@ -352,33 +353,27 @@ QString AsciiFilterPrivate::readData(const QString & fileName, AbstractDataSourc
 	int actualEndRow;
 	if (endRow == -1)
 		actualEndRow = actualRows;
-	else if (endRow > actualRows-1)
+	else if (endRow > actualRows - 1)
 		actualEndRow = actualRows-1;
 	else
 		actualEndRow = endRow;
-	int actualCols=endColumn-startColumn+1;
+	int actualCols = endColumn - startColumn+1;
 
 	if (headerEnabled)
 		actualRows = actualEndRow-startRow;
 	else
 		actualRows = actualEndRow-startRow+1;
 	if (lines == -1)
-		lines=actualRows;
+		lines = actualRows;
 
-#ifndef NDEBUG
-	qDebug()<<"	start column ="<<startColumn;
-	qDebug()<<"	end column ="<<endColumn;
-	qDebug()<<"	actual cols ="<<actualCols;
-	qDebug()<<"	start row ="<<startRow;
-	qDebug()<<"	end row ="<<actualEndRow;
-	qDebug()<<"	actual rows ="<<actualRows;
-	qDebug()<<"	lines ="<<lines;
-#endif
+	DEBUG("start/end column: " << startColumn << endColumn);
+	DEBUG("start/end row: " << startRow << actualEndRow);
+	DEBUG("actual cols/rows: " << actualCols << actualRows);
+	DEBUG("lines:" << lines);
 
-	int currentRow=0; //indexes the position in the vector(column)
-	int columnOffset=0; //indexes the "start column" in the spreadsheet. Starting from this column the data will be imported.
+	int currentRow = 0; // indexes the position in the vector(column)
+	int columnOffset = 0; // indexes the "start column" in the spreadsheet. Starting from this column the data will be imported.
 	QVector<QVector<double>*> dataPointers;	// pointers to the actual data containers
-	QStringList dataString;
 
 	if (dataSource != NULL)
 		columnOffset = dataSource->create(dataPointers, mode, actualRows, actualCols, vectorNameList);
@@ -386,21 +381,22 @@ QString AsciiFilterPrivate::readData(const QString & fileName, AbstractDataSourc
 	//header: import the values in the first line, if they were not used as the header (as the names for the columns)
 	bool isNumber;
 	if (!headerEnabled) {
+		QStringList lineString;
 		for (int n=0; n < actualCols; n++) {
 			if (n < lineStringList.size()) {
 				const double value = lineStringList.at(n).toDouble(&isNumber);
 				if (dataSource != NULL)
 					isNumber ? dataPointers[n]->operator[](0) = value : dataPointers[n]->operator[](0) = NAN;
 				else
-					isNumber ? dataString<<QString::number(value)<<" " : dataString<<QLatin1String("NAN ");
+					isNumber ? lineString << QString::number(value) : lineString << QLatin1String("NAN");
 			} else {
 				if (dataSource != NULL)
 					dataPointers[n]->operator[](0) = NAN;
 				else
-					dataString<<QLatin1String("NAN ");
+					lineString << QLatin1String("NAN");
 			}
 		}
-		dataString<<"\n";
+		dataStrings << lineString;
 		currentRow++;
 	}
 
@@ -415,36 +411,37 @@ QString AsciiFilterPrivate::readData(const QString & fileName, AbstractDataSourc
 		if (line.isEmpty())
 			continue;
 
-		if (line.startsWith(commentCharacter) == true ) {
+		if (line.startsWith(commentCharacter) == true) {
 			currentRow++;
 			continue;
 		}
 
-		lineStringList = line.split( separator, QString::SplitBehavior(skipEmptyParts) );
+		lineStringList = line.split(separator, QString::SplitBehavior(skipEmptyParts));
 
 		// TODO : read strings (comments) or datetime too
-		for (int n=0; n < actualCols; n++) {
+		QStringList lineString;
+		for (int n = 0; n < actualCols; n++) {
 			if (n < lineStringList.size()) {
 				const double value = lineStringList.at(n).toDouble(&isNumber);
 				if (dataSource != NULL)
 					isNumber ? dataPointers[n]->operator[](currentRow) = value : dataPointers[n]->operator[](currentRow) = NAN;
 				else
-					isNumber ? dataString<<QString::number(value)<<" " : dataString<<QString("NAN ");
+					isNumber ? lineString += QString::number(value) : lineString += QString("NAN");
 			} else {
 				if (dataSource != NULL)
 					dataPointers[n]->operator[](currentRow) = NAN;
 				else
-					dataString<<QLatin1String("NAN ");
+					lineString += QLatin1String("NAN");
 			}
 		}
 
-		dataString<<"\n";
+		dataStrings << lineString;
 		currentRow++;
 		emit q->completed(100*currentRow/actualRows);
 	}
 
 	if (!dataSource)
-		return dataString.join("");
+		return dataStrings;
 
 	//make everything undo/redo-able again
 	//set the comments for each of the columns
@@ -462,7 +459,7 @@ QString AsciiFilterPrivate::readData(const QString & fileName, AbstractDataSourc
 			}
 		}
 		spreadsheet->setUndoAware(true);
-		return dataString.join("");
+		return dataStrings;
 	}
 
 
@@ -473,14 +470,14 @@ QString AsciiFilterPrivate::readData(const QString & fileName, AbstractDataSourc
 		matrix->setUndoAware(true);
 	}
 
-	return dataString.join("");
+	return dataStrings;
 }
 
 /*!
     reads the content of the file \c fileName to the data source \c dataSource.
 */
 void AsciiFilterPrivate::read(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode mode) {
-	readData(fileName,dataSource,mode);
+	readData(fileName, dataSource, mode);
 }
 
 /*!
