@@ -3,7 +3,7 @@ File                 : BinaryFilter.cpp
 Project              : LabPlot
 Description          : Binary I/O-filter
 --------------------------------------------------------------------
-Copyright            : (C) 2015 by Stefan Gerlach (stefan.gerlach@uni.kn)
+Copyright            : (C) 2015-2017 by Stefan Gerlach (stefan.gerlach@uni.kn)
 ***************************************************************************/
 
 /***************************************************************************
@@ -51,7 +51,7 @@ BinaryFilter::~BinaryFilter() {
 /*!
   reads the content of the file \c fileName.
 */
-QString BinaryFilter::readData(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode importMode,  int lines) {
+QList <QStringList> BinaryFilter::readData(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode importMode,  int lines) {
 	return d->readData(fileName, dataSource, importMode, lines);
 }
 
@@ -204,19 +204,20 @@ bool BinaryFilter::isAutoModeEnabled() const {
 //#####################################################################
 
 BinaryFilterPrivate::BinaryFilterPrivate(BinaryFilter* owner) :
-	q(owner), vectors(2), dataType(BinaryFilter::INT8), byteOrder(BinaryFilter::LittleEndian), skipStartBytes(0), startRow(1), endRow(-1), skipBytes(0) {
+	q(owner), vectors(2), dataType(BinaryFilter::INT8), byteOrder(BinaryFilter::LittleEndian),
+	skipStartBytes(0), startRow(1), endRow(-1), skipBytes(0), autoModeEnabled(true) {
 }
 
 /*!
     reads the content of the file \c fileName to the data source \c dataSource or return as string for preview.
     Uses the settings defined in the data source.
 */
-QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode mode, int lines) {
-	QStringList dataString;
+QList<QStringList> BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode mode, int lines) {
+	QList<QStringList> dataStrings;
 
 	QIODevice *device = KFilterDev::deviceForFile(fileName);
 	if (! device->open(QIODevice::ReadOnly))
-		return QString();
+		return dataStrings << (QStringList() << i18n("could not open device"));
 
 	QDataStream in(device);
 
@@ -231,18 +232,18 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 	if (skipStartBytes >= BinaryFilter::dataSize(dataType)*vectors*numRows || startRow > numRows) {
 		if (dataSource != NULL)
 			dataSource->clear();
-		return QString();
+		return dataStrings << (QStringList() << i18n("data selection empty"));
 	}
 
 	// skip bytes at start
-	for (int i=0; i < skipStartBytes; i++) {
+	for (int i = 0; i < skipStartBytes; i++) {
 		qint8 tmp;
 		in >> tmp;
 	}
 
 	// skip until start row
-	for (int i=0; i < (startRow-1)*vectors; ++i) {
-		for (int j=0; j < BinaryFilter::dataSize(dataType); ++j) {
+	for (int i = 0; i < (startRow-1)*vectors; ++i) {
+		for (int j = 0; j < BinaryFilter::dataSize(dataType); ++j) {
 			qint8 tmp;
 			in >> tmp;
 		}
@@ -256,10 +257,10 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 		actualRows = numRows;
 	else
 		actualRows = endRow-startRow+1;
-	int actualCols=vectors;
+	int actualCols = vectors;
 	if (lines == -1)
-		lines=actualRows;
-#ifdef QT_DEBUG
+		lines = actualRows;
+#ifndef NDEBUG
 	qDebug()<<"	numRows ="<<numRows;
 	qDebug()<<"	startRow ="<<startRow;
 	qDebug()<<"	endRow ="<<endRow;
@@ -274,8 +275,9 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 		columnOffset = dataSource->create(dataPointers, mode, actualRows, actualCols);
 
 	// read data
-	for (int i=0; i<qMin(actualRows,lines); i++) {
-		for ( int n=0; n<actualCols; n++ ) {
+	for (int i = 0; i < qMin(actualRows, lines); i++) {
+		QStringList lineString;
+		for (int n = 0; n < actualCols; n++) {
 			switch (dataType) {
 			case BinaryFilter::INT8: {
 				qint8 value;
@@ -283,7 +285,7 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 				if (dataSource != NULL)
 					dataPointers[n]->operator[](i) = value;
 				else
-					dataString<<QString::number(value)<<" ";
+					lineString << QString::number(value);
 				break;
 			}
 			case BinaryFilter::INT16: {
@@ -292,7 +294,7 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 				if (dataSource != NULL)
 					dataPointers[n]->operator[](i) = value;
 				else
-					dataString<<QString::number(value)<<" ";
+					lineString << QString::number(value);
 				break;
 			}
 			case BinaryFilter::INT32: {
@@ -301,7 +303,7 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 				if (dataSource != NULL)
 					dataPointers[n]->operator[](i) = value;
 				else
-					dataString<<QString::number(value)<<" ";
+					lineString << QString::number(value);
 				break;
 			}
 			case BinaryFilter::INT64: {
@@ -310,7 +312,7 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 				if (dataSource != NULL)
 					dataPointers[n]->operator[](i) = value;
 				else
-					dataString<<QString::number(value)<<" ";
+					lineString << QString::number(value);
 				break;
 			}
 			case BinaryFilter::UINT8: {
@@ -319,7 +321,7 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 				if (dataSource != NULL)
 					dataPointers[n]->operator[](i) = value;
 				else
-					dataString<<QString::number(value)<<" ";
+					lineString << QString::number(value);
 				break;
 			}
 			case BinaryFilter::UINT16: {
@@ -328,7 +330,7 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 				if (dataSource != NULL)
 					dataPointers[n]->operator[](i) = value;
 				else
-					dataString<<QString::number(value)<<" ";
+					lineString << QString::number(value);
 				break;
 			}
 			case BinaryFilter::UINT32: {
@@ -337,7 +339,7 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 				if (dataSource != NULL)
 					dataPointers[n]->operator[](i) = value;
 				else
-					dataString<<QString::number(value)<<" ";
+					lineString << QString::number(value);
 				break;
 			}
 			case BinaryFilter::UINT64: {
@@ -346,7 +348,7 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 				if (dataSource != NULL)
 					dataPointers[n]->operator[](i) = value;
 				else
-					dataString<<QString::number(value)<<" ";
+					lineString << QString::number(value);
 				break;
 			}
 			case BinaryFilter::REAL32: {
@@ -355,7 +357,7 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 				if (dataSource != NULL)
 					dataPointers[n]->operator[](i) = value;
 				else
-					dataString<<QString::number(value)<<" ";
+					lineString << QString::number(value);
 				break;
 			}
 			case BinaryFilter::REAL64: {
@@ -364,17 +366,17 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 				if (dataSource != NULL)
 					dataPointers[n]->operator[](i) = value;
 				else
-					dataString<<QString::number(value)<<" ";
+					lineString << QString::number(value);
 				break;
 			}
 			}
 		}
-		dataString<<"\n";
+		dataStrings << lineString;
 		emit q->completed(100*i/actualRows);
 	}
 
 	if (!dataSource)
-		return dataString.join("");
+		return dataStrings;
 
 	//make everything undo/redo-able again
 	//set the comments for each of the columns
@@ -392,7 +394,7 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 			}
 		}
 		spreadsheet->setUndoAware(true);
-		return dataString.join("");
+		return dataStrings;
 	}
 
 	Matrix* matrix = dynamic_cast<Matrix*>(dataSource);
@@ -402,7 +404,7 @@ QString BinaryFilterPrivate::readData(const QString & fileName, AbstractDataSour
 		matrix->setUndoAware(true);
 	}
 
-	return dataString.join("");
+	return dataStrings;
 }
 
 
