@@ -3,7 +3,7 @@ File                 : NetCDFFilter.cpp
 Project              : LabPlot
 Description          : NetCDF I/O-filter
 --------------------------------------------------------------------
-Copyright            : (C) 2015 by Stefan Gerlach (stefan.gerlach@uni.kn)
+Copyright            : (C) 2015-2017 by Stefan Gerlach (stefan.gerlach@uni.kn)
 ***************************************************************************/
 
 /***************************************************************************
@@ -66,7 +66,7 @@ QString NetCDFFilter::readAttribute(const QString & fileName, const QString & na
 /*!
   reads the content of the current variable from file \c fileName.
 */
-QString NetCDFFilter::readCurrentVar(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode importMode,  int lines) {
+QList <QStringList> NetCDFFilter::readCurrentVar(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode importMode, int lines) {
 	return d->readCurrentVar(fileName, dataSource, importMode, lines);
 }
 
@@ -81,7 +81,7 @@ void NetCDFFilter::read(const QString & fileName, AbstractDataSource* dataSource
 writes the content of the data source \c dataSource to the file \c fileName.
 */
 void NetCDFFilter::write(const QString & fileName, AbstractDataSource* dataSource) {
- 	d->write(fileName, dataSource);
+	d->write(fileName, dataSource);
 // 	emit()
 }
 
@@ -90,14 +90,14 @@ void NetCDFFilter::write(const QString & fileName, AbstractDataSource* dataSourc
   loads the predefined filter settings for \c filterName
 */
 void NetCDFFilter::loadFilterSettings(const QString& filterName) {
-    Q_UNUSED(filterName);
+	Q_UNUSED(filterName);
 }
 
 /*!
   saves the current settings as a new filter with the name \c filterName
 */
-void NetCDFFilter::saveFilterSettings(const QString& filterName) const{
-    Q_UNUSED(filterName);
+void NetCDFFilter::saveFilterSettings(const QString& filterName) const {
+	Q_UNUSED(filterName);
 }
 
 ///////////////////////////////////////////////////////////////////////
@@ -106,24 +106,24 @@ void NetCDFFilter::setCurrentVarName(QString ds) {
 	d->currentVarName = ds;
 }
 
-const QString NetCDFFilter::currentVarName() const{
+const QString NetCDFFilter::currentVarName() const {
 	return d->currentVarName;
 }
 
 void NetCDFFilter::setStartRow(const int s) {
-        d->startRow = s;
+	d->startRow = s;
 }
 
-int NetCDFFilter::startRow() const{
-        return d->startRow;
+int NetCDFFilter::startRow() const {
+	return d->startRow;
 }
 
 void NetCDFFilter::setEndRow(const int e) {
-        d->endRow = e;
+	d->endRow = e;
 }
 
-int NetCDFFilter::endRow() const{
-        return d->endRow;
+int NetCDFFilter::endRow() const {
+	return d->endRow;
 }
 
 void NetCDFFilter::setStartColumn(const int c) {
@@ -135,7 +135,7 @@ int NetCDFFilter::startColumn() const {
 }
 
 void NetCDFFilter::setEndColumn(const int c) {
-	d->endColumn=c;
+	d->endColumn = c;
 }
 
 int NetCDFFilter::endColumn() const {
@@ -147,14 +147,13 @@ int NetCDFFilter::endColumn() const {
 //#####################################################################
 
 NetCDFFilterPrivate::NetCDFFilterPrivate(NetCDFFilter* owner) :
-	q(owner),startRow(1), endRow(-1),startColumn(1),endColumn(-1), status(0) {
+	q(owner), startRow(1), endRow(-1), startColumn(1), endColumn(-1), status(0) {
 }
 
 #ifdef HAVE_NETCDF
 void NetCDFFilterPrivate::handleError(int err, QString function) {
-	if (err != NC_NOERR) {
-		qDebug()<<"ERROR:"<<function<<"() - "<<nc_strerror(status);
-	}
+	if (err != NC_NOERR)
+		qDebug() << "NETCDF ERROR:" << function << "() - " << nc_strerror(status);
 }
 
 QString NetCDFFilterPrivate::translateDataType(nc_type type) {
@@ -162,43 +161,43 @@ QString NetCDFFilterPrivate::translateDataType(nc_type type) {
 
 	switch (type) {
 	case NC_BYTE:
-		typeString="BYTE";
+		typeString = "BYTE";
 		break;
 	case NC_UBYTE:
-		typeString="UBYTE";
+		typeString = "UBYTE";
 		break;
 	case NC_CHAR:
-		typeString="CHAR";
+		typeString = "CHAR";
 		break;
 	case NC_SHORT:
-		typeString="SHORT";
+		typeString = "SHORT";
 		break;
 	case NC_USHORT:
-		typeString="USHORT";
+		typeString = "USHORT";
 		break;
 	case NC_INT:
-		typeString="INT";
+		typeString = "INT";
 		break;
 	case NC_UINT:
-		typeString="UINT";
+		typeString = "UINT";
 		break;
 	case NC_INT64:
-		typeString="INT64";
+		typeString = "INT64";
 		break;
 	case NC_UINT64:
-		typeString="UINT64";
+		typeString = "UINT64";
 		break;
 	case NC_FLOAT:
-		typeString="FLOAT";
+		typeString = "FLOAT";
 		break;
 	case NC_DOUBLE:
-		typeString="DOUBLE";
+		typeString = "DOUBLE";
 		break;
 	case NC_STRING:
-		typeString="STRING";
+		typeString = "STRING";
 		break;
 	default:
-		typeString="UNKNOWN";
+		typeString = "UNKNOWN";
 	}
 
 	return typeString;
@@ -207,132 +206,130 @@ QString NetCDFFilterPrivate::translateDataType(nc_type type) {
 QString NetCDFFilterPrivate::scanAttrs(int ncid, int varid, int attid, QTreeWidgetItem* parentItem) {
 	char name[NC_MAX_NAME + 1];
 
-	int nattr, nstart=0;
+	int nattr, nstart = 0;
 	if (attid == -1) {
 		status = nc_inq_varnatts(ncid, varid, &nattr);
-		handleError(status,"nc_inq_varnatts");
+		handleError(status, "nc_inq_varnatts");
 	} else {
-		nstart=attid;
-		nattr=attid+1;
+		nstart = attid;
+		nattr = attid+1;
 	}
 
 	nc_type type;
 	size_t len;
 	QStringList valueString;
-	for (int i=nstart; i < nattr; i++) {
+	for (int i = nstart; i < nattr; i++) {
 		valueString.clear();
-		status = nc_inq_attname(ncid,varid,i,name);
-		handleError(status,"nc_inq_attname");
+		status = nc_inq_attname(ncid, varid, i, name);
+		handleError(status, "nc_inq_attname");
 
 		status = nc_inq_att(ncid, varid, name, &type, &len);
-		handleError(status,"nc_inq_att");
-#ifdef QT_DEBUG
-		qDebug()<<"	attr"<<i+1<<": name/type/len="<<name<<translateDataType(type)<<len;
-#endif
+		handleError(status, "nc_inq_att");
+		QDEBUG("	attr" << i+1 << "name/type/len =" << name << translateDataType(type) << len);
 
 		//read attribute
 		switch (type) {
 		case NC_BYTE: {
-			signed char *value = (signed char *)malloc(len*sizeof(signed char));
-			status = nc_get_att_schar(ncid, varid, name, value);
-			handleError(status,"nc_get_att_schar");
-			for (unsigned int l=0; l < len; l++)
-				valueString<<QString::number(value[l]);
-			free(value);
-			break;
-		}
+				signed char *value = (signed char *)malloc(len*sizeof(signed char));
+				status = nc_get_att_schar(ncid, varid, name, value);
+				handleError(status, "nc_get_att_schar");
+				for (unsigned int l = 0; l < len; l++)
+					valueString << QString::number(value[l]);
+				free(value);
+				break;
+			}
 		case NC_UBYTE: {
-			unsigned char *value = (unsigned char *)malloc(len*sizeof(unsigned char));
-			status = nc_get_att_uchar(ncid, varid, name, value);
-			handleError(status,"nc_get_att_uchar");
-			for (unsigned int l=0; l < len; l++)
-				valueString<<QString::number(value[l]);
-			free(value);
-			break;
-		}
+				unsigned char *value = (unsigned char *)malloc(len*sizeof(unsigned char));
+				status = nc_get_att_uchar(ncid, varid, name, value);
+				handleError(status, "nc_get_att_uchar");
+				for (unsigned int l = 0; l < len; l++)
+					valueString << QString::number(value[l]);
+				free(value);
+				break;
+			}
 		case NC_CHAR: {
-			char *value = (char *)malloc((len+1)*sizeof(char));
-			status = nc_get_att_text(ncid, varid, name, value);
-			handleError(status,"nc_get_att_text");
-			value[len]=0;
-			valueString<<value;
-			free(value);
-			break;
-		}
+				char *value = (char *)malloc((len+1)*sizeof(char));
+				status = nc_get_att_text(ncid, varid, name, value);
+				handleError(status, "nc_get_att_text");
+				value[len] = 0;
+				valueString << value;
+				free(value);
+				break;
+			}
 		case NC_SHORT: {
-			short *value = (short *)malloc(len*sizeof(short));
-			status = nc_get_att_short(ncid, varid, name, value);
-			handleError(status,"nc_get_att_short");
-			for (unsigned int l=0; l < len; l++)
-				valueString<<QString::number(value[l]);
-			free(value);
-			break;
-		}
+				short *value = (short *)malloc(len*sizeof(short));
+				status = nc_get_att_short(ncid, varid, name, value);
+				handleError(status, "nc_get_att_short");
+				for (unsigned int l = 0; l < len; l++)
+					valueString << QString::number(value[l]);
+				free(value);
+				break;
+			}
 		case NC_USHORT: {
-			unsigned short *value = (unsigned short *)malloc(len*sizeof(unsigned short));
-			status = nc_get_att_ushort(ncid, varid, name, value);
-			handleError(status,"nc_get_att_ushort");
-			for (unsigned int l=0; l < len; l++)
-				valueString<<QString::number(value[l]);
-			free(value);
-			break;
-		}
+				unsigned short *value = (unsigned short *)malloc(len*sizeof(unsigned short));
+				status = nc_get_att_ushort(ncid, varid, name, value);
+				handleError(status, "nc_get_att_ushort");
+				for (unsigned int l = 0; l < len; l++)
+					valueString << QString::number(value[l]);
+				free(value);
+				break;
+			}
 		case NC_INT: {
-			int *value = (int *)malloc(len*sizeof(int));
-			status = nc_get_att_int(ncid, varid, name, value);
-			handleError(status,"nc_get_att_int");
-			for (unsigned int l=0; l < len; l++)
-				valueString<<QString::number(value[l]);
-			free(value);
-			break;
-		}
+				int *value = (int *)malloc(len*sizeof(int));
+				status = nc_get_att_int(ncid, varid, name, value);
+				handleError(status, "nc_get_att_int");
+				for (unsigned int l = 0; l < len; l++)
+					valueString << QString::number(value[l]);
+				free(value);
+				break;
+			}
 		case NC_UINT: {
-			unsigned int *value = (unsigned int *)malloc(len*sizeof(unsigned int));
-			status = nc_get_att_uint(ncid, varid, name, value);
-			handleError(status,"nc_get_att_uint");
-			for (unsigned int l=0; l < len; l++)
-				valueString<<QString::number(value[l]);
-			free(value);
-			break;
-		}
+				unsigned int *value = (unsigned int *)malloc(len*sizeof(unsigned int));
+				status = nc_get_att_uint(ncid, varid, name, value);
+				handleError(status, "nc_get_att_uint");
+				for (unsigned int l = 0; l < len; l++)
+					valueString << QString::number(value[l]);
+				free(value);
+				break;
+			}
 		case NC_INT64: {
-			long long *value = (long long *)malloc(len*sizeof(long long));
-			status = nc_get_att_longlong(ncid, varid, name, value);
-			handleError(status,"nc_get_att_longlong");
-			for (unsigned int l=0; l < len; l++)
-				valueString<<QString::number(value[l]);
-			free(value);
-			break;
-		}
+				long long *value = (long long *)malloc(len*sizeof(long long));
+				status = nc_get_att_longlong(ncid, varid, name, value);
+				handleError(status, "nc_get_att_longlong");
+				for (unsigned int l = 0; l < len; l++)
+					valueString << QString::number(value[l]);
+				free(value);
+				break;
+			}
 		case NC_UINT64: {
-			unsigned long long *value = (unsigned long long *)malloc(len*sizeof(unsigned long long));
-			status = nc_get_att_ulonglong(ncid, varid, name, value);
-			handleError(status,"nc_get_att_ulonglong");
-			for (unsigned int l=0; l < len; l++)
-				valueString<<QString::number(value[l]);
-			free(value);
-			break;
-		}
+				unsigned long long *value = (unsigned long long *)malloc(len*sizeof(unsigned long long));
+				status = nc_get_att_ulonglong(ncid, varid, name, value);
+				handleError(status, "nc_get_att_ulonglong");
+				for (unsigned int l = 0; l < len; l++)
+					valueString << QString::number(value[l]);
+				free(value);
+				break;
+			}
 		case NC_FLOAT: {
-			float *value = (float *)malloc(len*sizeof(float));
-			status = nc_get_att_float(ncid, varid, name, value);
-			handleError(status,"nc_get_att_float");
-			for (unsigned int l=0; l < len; l++)
-				valueString<<QString::number(value[l]);
-			free(value);
-			break;
-		}
+				float *value = (float *)malloc(len*sizeof(float));
+				status = nc_get_att_float(ncid, varid, name, value);
+				handleError(status, "nc_get_att_float");
+				for (unsigned int l = 0; l < len; l++)
+					valueString << QString::number(value[l]);
+				free(value);
+				break;
+			}
 		case NC_DOUBLE: {
-			double *value = (double *)malloc(len*sizeof(double));
-			status = nc_get_att_double(ncid, varid, name, value);
-			handleError(status,"nc_get_att_double");
-			for (unsigned int l=0; l < len; l++)
-				valueString<<QString::number(value[l]);
-			free(value);
-			break;
-		}
+				double *value = (double *)malloc(len*sizeof(double));
+				status = nc_get_att_double(ncid, varid, name, value);
+				handleError(status, "nc_get_att_double");
+				for (unsigned int l = 0; l < len; l++)
+					valueString << QString::number(value[l]);
+				free(value);
+				break;
+			}
 		default:
-			valueString<<"not supported";
+			valueString << "not supported";
 		}
 
 		if (parentItem != NULL) {
@@ -342,12 +339,12 @@ QString NetCDFFilterPrivate::scanAttrs(int ncid, int varid, int attid, QTreeWidg
 			else {
 				char varName[NC_MAX_NAME + 1];
 				status = nc_inq_varname(ncid, varid, varName);
-				typeName=QString(varName) + ' ' + i18n("attribute");
+				typeName = QString(varName) + ' ' + i18n("attribute");
 			}
 			QStringList props;
-			props<<translateDataType(type)<<" ("<<QString::number(len)<<")";
-			QTreeWidgetItem *attrItem = new QTreeWidgetItem((QTreeWidget*)0, QStringList()<<QString(name)<<typeName<<props.join("")<<valueString.join(", "));
-			attrItem->setIcon(0,QIcon(KIcon("accessories-calculator")));
+			props << translateDataType(type) << " (" << QString::number(len) << ")";
+			QTreeWidgetItem *attrItem = new QTreeWidgetItem(QStringList() << QString(name) << typeName << props.join("") << valueString.join(", "));
+			attrItem->setIcon(0, QIcon(KIcon("accessories-calculator")));
 			attrItem->setFlags(Qt::ItemIsEnabled);
 			parentItem->addChild(attrItem);
 		}
@@ -358,25 +355,23 @@ QString NetCDFFilterPrivate::scanAttrs(int ncid, int varid, int attid, QTreeWidg
 
 void NetCDFFilterPrivate::scanDims(int ncid, int ndims, QTreeWidgetItem* parentItem) {
 	int ulid;
-	status = nc_inq_unlimdim(ncid,&ulid);
-	handleError(status,"nc_inq_att");
+	status = nc_inq_unlimdim(ncid, &ulid);
+	handleError(status, "nc_inq_att");
 
 	char name[NC_MAX_NAME + 1];
 	size_t len;
-	for (int i=0; i < ndims; i++) {
+	for (int i = 0; i < ndims; i++) {
 		status = nc_inq_dim(ncid, i, name, &len);
-		handleError(status,"nc_inq_att");
-#ifdef QT_DEBUG
-		qDebug()<<"	dim"<<i+1<<": name/len="<<name<<len;
-#endif
+		handleError(status, "nc_inq_att");
+		DEBUG("	dim" << i+1 << ": name/len =" << name << len);
 
 		QStringList props;
 		props<<i18n("length") << QLatin1String(" = ") << QString::number(len);
 		QString value;
 		if (i == ulid)
 			value = i18n("unlimited");
-		QTreeWidgetItem *attrItem = new QTreeWidgetItem((QTreeWidget*)0, QStringList()<<QString(name)<<i18n("dimension")<<props.join("")<<value);
-		attrItem->setIcon(0,QIcon(KIcon("accessories-calculator")));
+		QTreeWidgetItem *attrItem = new QTreeWidgetItem(QStringList() << QString(name) << i18n("dimension") << props.join("") << value);
+		attrItem->setIcon(0, QIcon(KIcon("accessories-calculator")));
 		attrItem->setFlags(Qt::ItemIsEnabled);
 		parentItem->addChild(attrItem);
 	}
@@ -388,37 +383,37 @@ void NetCDFFilterPrivate::scanVars(int ncid, int nvars, QTreeWidgetItem* parentI
 	int ndims, nattrs;
 	int dimids[NC_MAX_VAR_DIMS];
 
-	for (int i=0; i < nvars; i++) {
+	for (int i = 0; i < nvars; i++) {
 		status = nc_inq_var(ncid, i, name, &type, &ndims, dimids, &nattrs);
-		handleError(status,"nc_inq_att");
+		handleError(status, "nc_inq_att");
 
-#ifdef QT_DEBUG
-		qDebug()<<"	var"<<i+1<<": name/type="<<name<<translateDataType(type);
-		qDebug()<<"		ndims/nattr"<<ndims<<nattrs;
-#endif
+		QDEBUG("	var" << i+1 << ": name/type=" << name << translateDataType(type));
+		DEBUG("		ndims/nattr" << ndims << nattrs);
 
 		QStringList props;
-		props<<translateDataType(type);
+		props << translateDataType(type);
 		char dname[NC_MAX_NAME + 1];
 		size_t dlen;
-		props<<"(";
-		for (int j=0; j < ndims; j++) {
+		props << "(";
+		for (int j = 0; j < ndims; j++) {
 			status = nc_inq_dim(ncid, dimids[j], dname, &dlen);
 			if (j != 0)
-				props<<"x";
-			props<<QString::number(dlen);
+				props << "x";
+			props << QString::number(dlen);
 		}
-		props<<")";
+		props << ")";
 
-		QTreeWidgetItem *varItem = new QTreeWidgetItem((QTreeWidget*)0, QStringList()<<QString(name)<<i18n("variable")<<props.join("")<<"");
-		varItem->setIcon(0,QIcon(KIcon("x-office-spreadsheet")));
+		QTreeWidgetItem *varItem = new QTreeWidgetItem(QStringList() << QString(name) << i18n("variable") << props.join("") << "");
+		varItem->setIcon(0, QIcon(KIcon("x-office-spreadsheet")));
 		varItem->setFlags(Qt::ItemIsEnabled | Qt::ItemIsSelectable);
 		// highlight item
-		for (int c=0; c < varItem->columnCount(); c++)
-			varItem->setBackground(c,QBrush(QColor(192,255,192)));
+		for (int c = 0; c < varItem->columnCount(); c++) {
+			varItem->setBackground(c, QColor(192, 255, 192));
+			varItem->setForeground(c, Qt::black);
+		}
 		parentItem->addChild(varItem);
 
-		scanAttrs(ncid,i,-1,varItem);
+		scanAttrs(ncid, i, -1, varItem);
 	}
 }
 #endif
@@ -432,32 +427,30 @@ void NetCDFFilterPrivate::parse(const QString & fileName, QTreeWidgetItem* rootI
 
 	int ncid;
 	status = nc_open(bafileName.data(), NC_NOWRITE, &ncid);
-	handleError(status,"nc_open");
+	handleError(status, "nc_open");
 
 	int ndims, nvars, nattr, uldid;
 	status = nc_inq(ncid, &ndims, &nvars, &nattr, &uldid);
-	handleError(status,"nc_inq");
-#ifdef QT_DEBUG
-	qDebug()<<" nattr/ndims/nvars ="<<nattr<<ndims<<nvars;
-#endif
+	handleError(status, "nc_inq");
+	DEBUG(" nattr/ndims/nvars =" << nattr << ndims << nvars);
 
-	QTreeWidgetItem *attrItem = new QTreeWidgetItem((QTreeWidget*)0, QStringList()<<QString(i18n("Attributes")));
-	attrItem->setIcon(0,QIcon(KIcon("folder")));
+	QTreeWidgetItem *attrItem = new QTreeWidgetItem(QStringList() << QString(i18n("Attributes")));
+	attrItem->setIcon(0, QIcon(KIcon("folder")));
 	attrItem->setFlags(Qt::ItemIsEnabled);
 	rootItem->addChild(attrItem);
-	scanAttrs(ncid,NC_GLOBAL,-1,attrItem);
+	scanAttrs(ncid, NC_GLOBAL, -1, attrItem);
 
-	QTreeWidgetItem *dimItem = new QTreeWidgetItem((QTreeWidget*)0, QStringList()<<QString(i18n("Dimensions")));
-	dimItem->setIcon(0,QIcon(KIcon("folder")));
+	QTreeWidgetItem *dimItem = new QTreeWidgetItem(QStringList() << QString(i18n("Dimensions")));
+	dimItem->setIcon(0, QIcon(KIcon("folder")));
 	dimItem->setFlags(Qt::ItemIsEnabled);
 	rootItem->addChild(dimItem);
-	scanDims(ncid,ndims,dimItem);
+	scanDims(ncid, ndims, dimItem);
 
-	QTreeWidgetItem *varItem = new QTreeWidgetItem((QTreeWidget*)0, QStringList()<<QString(i18n("Variables")));
-	varItem->setIcon(0,QIcon(KIcon("folder")));
+	QTreeWidgetItem *varItem = new QTreeWidgetItem(QStringList() << QString(i18n("Variables")));
+	varItem->setIcon(0, QIcon(KIcon("folder")));
 	varItem->setFlags(Qt::ItemIsEnabled);
 	rootItem->addChild(varItem);
-	scanVars(ncid,nvars,varItem);
+	scanVars(ncid, nvars, varItem);
 #else
 	Q_UNUSED(fileName)
 	Q_UNUSED(rootItem)
@@ -469,25 +462,25 @@ QString NetCDFFilterPrivate::readAttribute(const QString & fileName, const QStri
 	int ncid;
 	QByteArray bafileName = fileName.toLatin1();
 	status = nc_open(bafileName.data(), NC_NOWRITE, &ncid);
-	handleError(status,"nc_open");
+	handleError(status, "nc_open");
 
 	// get varid
 	int varid;
-	if (varName == "global") {
+	if (varName == "global")
 		varid = NC_GLOBAL;
-	} else {
+	else {
 		QByteArray bavarName = varName.toLatin1();
 		status = nc_inq_varid(ncid, bavarName.data(), &varid);
-		handleError(status,"nc_inq_varid");
+		handleError(status, "nc_inq_varid");
 	}
 
 	// attribute 'name'
 	int attid;
 	QByteArray baName = name.toLatin1();
 	status = nc_inq_attid(ncid, varid, baName.data(), &attid);
-	handleError(status,"nc_inq_attid");
+	handleError(status, "nc_inq_attid");
 
-	return scanAttrs(ncid,varid,attid);
+	return scanAttrs(ncid, varid, attid);
 #else
 	Q_UNUSED(fileName)
 	Q_UNUSED(name)
@@ -499,155 +492,153 @@ QString NetCDFFilterPrivate::readAttribute(const QString & fileName, const QStri
 /*!
     reads the content of the variable in the file \c fileName to a string (for preview) or to the data source.
 */
-QString NetCDFFilterPrivate::readCurrentVar(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode mode, int lines) {
-	QStringList dataString;
+QList<QStringList> NetCDFFilterPrivate::readCurrentVar(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode mode, int lines) {
+	QList<QStringList> dataStrings;
 
 	if (currentVarName.isEmpty())
-		return i18n("No variable selected");
-#ifdef QT_DEBUG
-	qDebug()<<" current variable ="<<currentVarName;
-#endif
+		return dataStrings << (QStringList() << i18n("No variable selected"));
+	QDEBUG(" current variable =" << currentVarName);
 
 #ifdef HAVE_NETCDF
 	int ncid;
 	QByteArray bafileName = fileName.toLatin1();
 	status = nc_open(bafileName.data(), NC_NOWRITE, &ncid);
-	handleError(status,"nc_open");
+	handleError(status, "nc_open");
 
 	int varid;
 	QByteArray baVarName = currentVarName.toLatin1();
-	status = nc_inq_varid(ncid,baVarName.data(),&varid);
-	handleError(status,"nc_inq_varid");
+	status = nc_inq_varid(ncid, baVarName.data(), &varid);
+	handleError(status, "nc_inq_varid");
 
 	int ndims;
 	nc_type type;
 	status = nc_inq_varndims(ncid, varid, &ndims);
-	handleError(status,"nc_inq_varndims");
+	handleError(status, "nc_inq_varndims");
 	status = nc_inq_vartype(ncid, varid, &type);
-	handleError(status,"nc_inq_type");
+	handleError(status, "nc_inq_type");
 
-	int* dimids = (int *) malloc(ndims*sizeof(int));
+	int* dimids = (int *) malloc(ndims * sizeof(int));
 	status = nc_inq_vardimid(ncid, varid, dimids);
-	handleError(status,"nc_inq_vardimid");
+	handleError(status, "nc_inq_vardimid");
 
-	int actualRows=0, actualCols=0;
-	int columnOffset=0;
+	int actualRows = 0, actualCols = 0;
+	int columnOffset = 0;
 	QVector<QVector<double>*> dataPointers;
 	switch (ndims) {
 	case 0:
-		qDebug()<<"zero dimensions";
+		dataStrings << (QStringList() << i18n("zero dimensions"));
+		qDebug() << dataStrings;
 		break;
 	case 1: {
-		size_t size;
-		status = nc_inq_dimlen(ncid, dimids[0], &size);
-		handleError(status,"nc_inq_dimlen");
+			size_t size;
+			status = nc_inq_dimlen(ncid, dimids[0], &size);
+			handleError(status, "nc_inq_dimlen");
 
-		if (endRow == -1)
-			endRow=size;
-		if (lines == -1)
-			lines=endRow;
-		actualRows=endRow-startRow+1;
-		actualCols=1;
+			if (endRow == -1)
+				endRow = size;
+			if (lines == -1)
+				lines = endRow;
+			actualRows = endRow-startRow+1;
+			actualCols = 1;
 
-#ifdef QT_DEBUG
-		qDebug()<<"start/end row"<<startRow<<endRow;
-		qDebug()<<"act rows/cols"<<actualRows<<actualCols;
-#endif
+			DEBUG("start/end row" << startRow << endRow);
+			DEBUG("act rows/cols" << actualRows << actualCols);
 
-		if (dataSource != NULL)
-			columnOffset = dataSource->create(dataPointers, mode, actualRows, actualCols);
+			if (dataSource != NULL)
+				columnOffset = dataSource->create(dataPointers, mode, actualRows, actualCols);
 
-		double* data = 0;
-		if (dataSource)
-			data = dataPointers[0]->data();
-		else
-			data = (double *)malloc(actualRows*sizeof(double));
+			double* data = 0;
+			if (dataSource)
+				data = dataPointers[0]->data();
+			else
+				data = (double *)malloc(actualRows * sizeof(double));
 
-		size_t start=startRow-1, count=actualRows;
-		status = nc_get_vara_double(ncid, varid, &start, &count, data);
-		handleError(status,"nc_get_vara_double");
+			size_t start = startRow-1, count = actualRows;
+			status = nc_get_vara_double(ncid, varid, &start, &count, data);
+			handleError(status, "nc_get_vara_double");
 
-		if (!dataSource) {
-			for (int i=0; i < actualRows; i++) {
-				dataString<<QString::number(data[i])<<"\n";
+			if (!dataSource) {
+				for (int i = 0; i < qMin(actualRows, lines); i++)
+					dataStrings << (QStringList() << QString::number(data[i]));
+				free(data);
 			}
-			free(data);
+			break;
 		}
-		break;
-	}
 	case 2: {
-		size_t rows, cols;
-		status = nc_inq_dimlen(ncid, dimids[0], &rows);
-		handleError(status,"nc_inq_dimlen");
-		status = nc_inq_dimlen(ncid, dimids[1], &cols);
-		handleError(status,"nc_inq_dimlen");
+			size_t rows, cols;
+			status = nc_inq_dimlen(ncid, dimids[0], &rows);
+			handleError(status, "nc_inq_dimlen");
+			status = nc_inq_dimlen(ncid, dimids[1], &cols);
+			handleError(status, "nc_inq_dimlen");
 
-		if (endRow == -1)
-			endRow=rows;
-		if (lines == -1)
-			lines=endRow;
-		if (endColumn == -1)
-			endColumn=cols;
-		actualRows=endRow-startRow+1;
-		actualCols=endColumn-startColumn+1;
+			if (endRow == -1)
+				endRow = rows;
+			if (lines == -1)
+				lines = endRow;
+			if (endColumn == -1)
+				endColumn = cols;
+			actualRows = endRow-startRow+1;
+			actualCols = endColumn-startColumn+1;
 
-#ifdef QT_DEBUG
-		qDebug()<<"dim ="<<rows<<"x"<<cols;
-		qDebug()<<"startRow/endRow"<<startRow<<endRow;
-		qDebug()<<"startColumn/endColumn"<<startColumn<<endColumn;
-		qDebug()<<"actual rows/cols"<<actualRows<<actualCols;
-		qDebug()<<"lines"<<lines;
-#endif
+			DEBUG("dim =" << rows << "x" << cols);
+			DEBUG("startRow/endRow:" << startRow << endRow);
+			DEBUG("startColumn/endColumn:" << startColumn << endColumn);
+			DEBUG("actual rows/cols:" << actualRows << actualCols);
+			DEBUG("lines:" << lines);
 
-		if (dataSource != NULL)
-			columnOffset = dataSource->create(dataPointers, mode, actualRows, actualCols);
+			if (dataSource != NULL)
+				columnOffset = dataSource->create(dataPointers, mode, actualRows, actualCols);
 
-		double** data = (double**) malloc(rows*sizeof(double*));
-		data[0] = (double*)malloc( cols*rows*sizeof(double) );
-		for (unsigned int i=1; i < rows; i++) data[i] = data[0]+i*cols;
+			double** data = (double**) malloc(rows * sizeof(double*));
+			data[0] = (double*)malloc( cols * rows * sizeof(double) );
+			for (unsigned int i = 1; i < rows; i++) data[i] = data[0] + i*cols;
 
-		status = nc_get_var_double(ncid, varid, &data[0][0]);
-		handleError(status,"nc_get_var_double");
-		for (int i=0; i < qMin((int)rows,lines); i++) {
-			for (unsigned int j=0; j < cols; j++) {
-				if (dataPointers.size()>0)
-					dataPointers[j-startColumn+1]->operator[](i-startRow+1) = data[i][j];
-				else
-					dataString<<QString::number(static_cast<double>(data[i][j]))<<" ";
+			status = nc_get_var_double(ncid, varid, &data[0][0]);
+			handleError(status, "nc_get_var_double");
+			for (int i = 0; i < qMin((int)rows, lines); i++) {
+				QStringList line;
+				for (unsigned int j = 0; j < cols; j++) {
+					if (!dataPointers.isEmpty())
+						dataPointers[j-startColumn+1]->operator[](i-startRow+1) = data[i][j];
+					else {
+						line << QString::number(static_cast<double>(data[i][j]));
+					}
+				}
+				dataStrings << line;
+				emit q->completed(100*i/actualRows);
 			}
-			dataString<<"\n";
-			emit q->completed(100*i/actualRows);
-		}
-		free(data[0]);
-		free(data);
+			free(data[0]);
+			free(data);
 
-		break;
-	}
+			break;
+		}
 	default:
-		qDebug()<<"strange number of dimensions:"<<ndims;
+		dataStrings << (QStringList() << i18n("%1 dimensional data of type %2 not supported yet").arg(ndims).arg(translateDataType(type)));
+		qDebug() << dataStrings;
 	}
 
 	free(dimids);
 
 	if (!dataSource)
-		return dataString.join("");
+		return dataStrings;
 
 	// make everything undo/redo-able again
 	// set column comments in spreadsheet
 	Spreadsheet* spreadsheet = dynamic_cast<Spreadsheet*>(dataSource);
 	if (spreadsheet) {
 		QString comment = i18np("numerical data, %1 element", "numerical data, %1 elements", actualRows);
-		for (int n=0; n < actualCols; n++) {
+		for (int n = 0; n < actualCols; n++) {
 			Column* column = spreadsheet->column(columnOffset+n);
 			column->setComment(comment);
+			column->setName(currentVarName);
 			column->setUndoAware(true);
-			if (mode==AbstractFileFilter::Replace) {
+			if (mode == AbstractFileFilter::Replace) {
 				column->setSuppressDataChangedSignal(false);
 				column->setChanged();
 			}
 		}
 		spreadsheet->setUndoAware(true);
-		return dataString.join("");
+		return dataStrings;
 	}
 
 	Matrix* matrix = dynamic_cast<Matrix*>(dataSource);
@@ -665,7 +656,7 @@ QString NetCDFFilterPrivate::readCurrentVar(const QString & fileName, AbstractDa
 	Q_UNUSED(lines)
 #endif
 
-	return dataString.join("");
+	return dataStrings;
 }
 
 /*!
@@ -674,16 +665,12 @@ QString NetCDFFilterPrivate::readCurrentVar(const QString & fileName, AbstractDa
 */
 void NetCDFFilterPrivate::read(const QString & fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode mode) {
 	if (currentVarName.isEmpty()) {
-		qDebug()<<" No variable selected";
+		DEBUG(" No variable selected");
 		return;
 	}
 
-#ifdef QT_DEBUG
-	else
-		qDebug()<<" current variable ="<<currentVarName;
-#endif
-
-	readCurrentVar(fileName,dataSource,mode);
+	QDEBUG(" current variable =" << currentVarName);
+	readCurrentVar(fileName, dataSource, mode);
 }
 
 /*!
@@ -692,7 +679,7 @@ void NetCDFFilterPrivate::read(const QString & fileName, AbstractDataSource* dat
 void NetCDFFilterPrivate::write(const QString & fileName, AbstractDataSource* dataSource) {
 	Q_UNUSED(fileName);
 	Q_UNUSED(dataSource);
-	//TODO
+	//TODO: not implemented yet
 }
 
 //##############################################################################
@@ -716,7 +703,7 @@ bool NetCDFFilter::load(XmlStreamReader* reader) {
 		return false;
 	}
 
-	QString attributeWarning = i18n("Attribute '%1' missing or empty, default value is used");
-	QXmlStreamAttributes attribs = reader->attributes();
+// 	QString attributeWarning = i18n("Attribute '%1' missing or empty, default value is used");
+// 	QXmlStreamAttributes attribs = reader->attributes();
 	return true;
 }
