@@ -5,6 +5,7 @@
     --------------------------------------------------------------------
     Copyright            : (C) 2008 Tilman Benkert (thzs@gmx.net)
     Copyright            : (C) 2013-2015 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2016 Stefan Gerlach (stefan.gerlach@uni.kn)
 
  ***************************************************************************/
 
@@ -32,6 +33,20 @@
 
 #include <QApplication>
 
+// C++ style warning (works on Windows)
+#include <iostream>
+#define WARNING(x) std::cout << x << std::endl
+
+#ifndef NDEBUG
+#include <QDebug>
+#define QDEBUG(x) qDebug() << x
+// C++ style debugging (works on Windows)
+#define DEBUG(x) std::cout << x << std::endl
+#else
+#define QDEBUG(x) {}
+#define DEBUG(x) {}
+#endif
+
 #define BASIC_ACCESSOR(type, var, method, Method) \
 	type method() const { return var; }; \
 	void set ## Method(const type value) { var = value; }
@@ -400,6 +415,27 @@ do {																				\
 	d->columnName ##Path = str;														\
 } while(0)
 
+#define READ_INT_VALUE(name, var, type) \
+str = attribs.value(name).toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.arg(name)); \
+else \
+	d->var = (type)str.toInt();
+
+#define READ_DOUBLE_VALUE(name, var) \
+str = attribs.value(name).toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.arg(name)); \
+else \
+	d->var = str.toDouble();
+
+#define READ_STRING_VALUE(name, var) \
+str = attribs.value(name).toString(); \
+if (str.isEmpty()) \
+	reader->raiseWarning(attributeWarning.arg(name)); \
+else \
+	d->var = str;
+
 //used in Project::load()
 #define RESTORE_COLUMN_POINTER(obj, col, Col) 										\
 do {																				\
