@@ -104,33 +104,45 @@ QWidget *Spreadsheet::view() const {
 
 bool Spreadsheet::exportView() const {
 	ExportSpreadsheetDialog* dlg = new ExportSpreadsheetDialog(view());
-    dlg->setFileName(name());
-    if (const_cast<SpreadsheetView*>(reinterpret_cast<const SpreadsheetView*>(m_view))->selectedColumnCount() == 0) {
-        dlg->setExportSelection(false);
-    }
-    bool ret;
-    if ((ret = dlg->exec()==QDialog::Accepted)){
-        const QString path = dlg->path();
-        const bool exportHeader = dlg->exportHeader();
-        const SpreadsheetView* view = reinterpret_cast<const SpreadsheetView*>(m_view);
-        WAIT_CURSOR;
-        if (dlg->format() == ExportSpreadsheetDialog::LaTeX){
-            const bool exportLatexHeader = dlg->exportLatexHeader();
-            const bool gridLines = dlg->gridLines();
-            const bool captions = dlg->captions();
-            const bool skipEmptyRows =dlg->skipEmptyRows();
-            const bool exportEntire = dlg->entireSpreadheet();
-            view->exportToLaTeX(path, exportHeader, gridLines, captions,
-                                exportLatexHeader, skipEmptyRows, exportEntire);
-        }
-        else {
-            const QString separator = dlg->separator();
-            view->exportToFile(path, exportHeader, separator);
-        }
-        RESET_CURSOR;
-    }
+	dlg->setFileName(name());
+
+	dlg->setExportTo(QStringList() << i18n("FITS image") << i18n("FITS table"));
+	for (int i = 0; i < columnCount();++i) {
+		if (column(i)->columnMode() != AbstractColumn::Numeric) {
+			dlg->setExportToImage(false);
+			break;
+        	}
+	}
+	if (const_cast<SpreadsheetView*>(reinterpret_cast<const SpreadsheetView*>(m_view))->selectedColumnCount() == 0) {
+		dlg->setExportSelection(false);
+	}
+	bool ret;
+	if ((ret = dlg->exec()) == QDialog::Accepted) {
+		const QString path = dlg->path();
+		const bool exportHeader = dlg->exportHeader();
+		const SpreadsheetView* view = reinterpret_cast<const SpreadsheetView*>(m_view);
+		WAIT_CURSOR;
+		if (dlg->format() == ExportSpreadsheetDialog::LaTeX) {
+			const bool exportLatexHeader = dlg->exportLatexHeader();
+			const bool gridLines = dlg->gridLines();
+			const bool captions = dlg->captions();
+			const bool skipEmptyRows =dlg->skipEmptyRows();
+			const bool exportEntire = dlg->entireSpreadheet();
+			view->exportToLaTeX(path, exportHeader, gridLines, captions,
+				exportLatexHeader, skipEmptyRows, exportEntire);
+		} else if (dlg->format() == ExportSpreadsheetDialog::FITS) {
+			const int exportTo = dlg->exportToFits();
+			const bool commentsAsUnits = dlg->commentsAsUnitsFits();
+			view->exportToFits(path, exportTo, commentsAsUnits);
+		} else {
+			const QString separator = dlg->separator();
+			view->exportToFile(path, exportHeader, separator);
+		}
+		RESET_CURSOR;
+	}
 	delete dlg;
-    return ret;
+
+	return ret;
 }
 
 bool Spreadsheet::printView() {
@@ -138,7 +150,7 @@ bool Spreadsheet::printView() {
 	QPrintDialog* dlg = new QPrintDialog(&printer, view());
 	bool ret;
 	dlg->setWindowTitle(i18n("Print Spreadsheet"));
-	if ((ret = dlg->exec() == QDialog::Accepted)) {
+	if ((ret = dlg->exec()) == QDialog::Accepted) {
 		const SpreadsheetView* view = reinterpret_cast<const SpreadsheetView*>(m_view);
 		view->print(&printer);
 	}
@@ -171,7 +183,7 @@ void Spreadsheet::removeRows(int first, int count)
 	WAIT_CURSOR;
 	beginMacro( i18np("%1: remove 1 row", "%1: remove %2 rows", name(), count) );
 	foreach(Column * col, children<Column>(IncludeHidden))
-	    col->removeRows(first, count);
+		col->removeRows(first, count);
 	endMacro();
 	RESET_CURSOR;
 }
@@ -182,7 +194,7 @@ void Spreadsheet::insertRows(int before, int count)
 	WAIT_CURSOR;
 	beginMacro( i18np("%1: insert 1 row", "%1: insert %2 rows", name(), count) );
 	foreach(Column * col, children<Column>(IncludeHidden))
-	    col->insertRows(before, count);
+		col->insertRows(before, count);
 	endMacro();
 	RESET_CURSOR;
 }
@@ -352,10 +364,10 @@ void Spreadsheet::copy(Spreadsheet * other)
 		new_col->copy(src_col);
 		new_col->setPlotDesignation(src_col->plotDesignation());
 		QList< Interval<int> > masks = src_col->maskedIntervals();
-		foreach(const Interval<int>& iv, masks)
+		foreach (const Interval<int>& iv, masks)
 			new_col->setMasked(iv);
 		QList< Interval<int> > formulas = src_col->formulaIntervals();
-		foreach(const Interval<int>& iv, formulas)
+		foreach (const Interval<int>& iv, formulas)
 			new_col->setFormula(iv, src_col->formula(iv.start()));
 		new_col->setWidth(src_col->width());
 		addChild(new_col);
