@@ -33,6 +33,7 @@
 #include "backend/lib/XmlStreamReader.h"
 
 #include <QApplication>
+#include <QBuffer>
 #include <QtConcurrentRun>
 #include <QDesktopWidget>
 #include <QPainter>
@@ -86,7 +87,8 @@ void TextLabel::init() {
 
 	//properties common to all types
 	d->textWrapper.teXUsed = group.readEntry("TeXUsed", false);
-	d->teXFontSize = group.readEntry("TeXFontSize", 12);
+	d->teXFont.setFamily(group.readEntry("TeXFontFamily", "Computer Modern"));
+	d->teXFont.setPointSize(group.readEntry("TeXFontSize", 12));
 	d->teXFontColor = group.readEntry("TeXFontColor", QColor(Qt::black));
 	d->rotationAngle = group.readEntry("Rotation", 0.0);
 
@@ -179,8 +181,8 @@ QMenu* TextLabel::createContextMenu() {
 
 /* ============================ getter methods ================= */
 CLASS_SHARED_D_READER_IMPL(TextLabel, TextLabel::TextWrapper, text, textWrapper)
-CLASS_SHARED_D_READER_IMPL(TextLabel, int, teXFontSize, teXFontSize);
 CLASS_SHARED_D_READER_IMPL(TextLabel, QColor, teXFontColor, teXFontColor);
+CLASS_SHARED_D_READER_IMPL(TextLabel, QFont, teXFont, teXFont);
 CLASS_SHARED_D_READER_IMPL(TextLabel, TextLabel::PositionWrapper, position, position);
 BASIC_SHARED_D_READER_IMPL(TextLabel, TextLabel::HorizontalAlignment, horizontalAlignment, horizontalAlignment);
 BASIC_SHARED_D_READER_IMPL(TextLabel, TextLabel::VerticalAlignment, verticalAlignment, verticalAlignment);
@@ -192,14 +194,13 @@ void TextLabel::setText(const TextWrapper &textWrapper) {
 	Q_D(TextLabel);
 	if ( (textWrapper.text != d->textWrapper.text) || (textWrapper.teXUsed != d->textWrapper.teXUsed) )
 		exec(new TextLabelSetTextCmd(d, textWrapper, i18n("%1: set label text")));
-
 }
 
-STD_SETTER_CMD_IMPL_F_S(TextLabel, SetTeXFontSize, int, teXFontSize, updateText);
-void TextLabel::setTeXFontSize(const int fontSize) {
+STD_SETTER_CMD_IMPL_F_S(TextLabel, SetTeXFont, QFont, teXFont, updateText);
+void TextLabel::setTeXFont(const QFont& font) {
 	Q_D(TextLabel);
-	if (fontSize != d->teXFontSize)
-		exec(new TextLabelSetTeXFontSizeCmd(d, fontSize, i18n("%1: set TeX font size")));
+	if (font != d->teXFont)
+		exec(new TextLabelSetTeXFontCmd(d, font, i18n("%1: set TeX main font")));
 }
 
 STD_SETTER_CMD_IMPL_F_S(TextLabel, SetTeXFontColor, QColor, teXFontColor, updateText);
@@ -291,8 +292,9 @@ void TextLabel::visibilityChanged() {
 //##############################################################################
 //####################### Private implementation ###############################
 //##############################################################################
-TextLabelPrivate::TextLabelPrivate(TextLabel *owner)
-	: positionInvalid(false),
+TextLabelPrivate::TextLabelPrivate(TextLabel* owner)
+	: teXRenderSuccessful(false),
+	  positionInvalid(false),
 	  suppressItemChangeEvent(false),
 	  suppressRetransform(false),
 	  m_printing(false),
@@ -340,31 +342,31 @@ void TextLabelPrivate::retransform() {
 	QPointF itemPos;
 	switch (horizontalAlignment) {
 	case TextLabel::hAlignLeft:
-		itemPos.setX( x - w/2 );
+		itemPos.setX(x - w/2);
 		break;
 	case TextLabel::hAlignCenter:
-		itemPos.setX( x );
+		itemPos.setX(x);
 		break;
 	case TextLabel::hAlignRight:
-		itemPos.setX( x +w/2);
+		itemPos.setX(x + w/2);
 		break;
 	}
 
 	switch (verticalAlignment) {
 	case TextLabel::vAlignTop:
-		itemPos.setY( y - h/2 );
+		itemPos.setY(y - h/2);
 		break;
 	case TextLabel::vAlignCenter:
-		itemPos.setY( y );
+		itemPos.setY(y);
 		break;
 	case TextLabel::vAlignBottom:
-		itemPos.setY( y + h/2 );
+		itemPos.setY(y + h/2);
 		break;
 	}
 
-	suppressItemChangeEvent=true;
+	suppressItemChangeEvent = true;
 	setPos(itemPos);
-	suppressItemChangeEvent=false;
+	suppressItemChangeEvent = false;
 
 	boundingRectangle.setX(-w/2);
 	boundingRectangle.setY(-h/2);
@@ -390,7 +392,6 @@ void TextLabelPrivate::updatePosition() {
 		parentRect = scene()->sceneRect();
 	}
 
-
 	if (position.horizontalPosition != TextLabel::hPositionCustom) {
 		if (position.horizontalPosition == TextLabel::hPositionLeft)
 			position.point.setX( parentRect.x() );
@@ -417,7 +418,12 @@ void TextLabelPrivate::updatePosition() {
  */
 void TextLabelPrivate::updateText() {
 	if (textWrapper.teXUsed) {
-		QFuture<QImage> future = QtConcurrent::run(TeXRenderer::renderImageLaTeX, textWrapper.text, teXFontColor, teXFontSize, teXImageResolution);
+		TeXRenderer::Formatting format;
+		format.fontColor = teXFontColor;
+		format.fontSize = teXFont.pointSize();
+		format.fontFamily = teXFont.family();
+		format.dpi = teXImageResolution;
+		QFuture<QImage> future = QtConcurrent::run(TeXRenderer::renderImageLaTeX, textWrapper.text, &teXRenderSuccessful, format);
 		teXImageFutureWatcher.setFuture(future);
 
 		//don't need to call retransorm() here since it is done in updateTeXImage
@@ -433,10 +439,9 @@ void TextLabelPrivate::updateText() {
 
 void TextLabelPrivate::updateTeXImage() {
 	teXImage = teXImageFutureWatcher.result();
-
-	//the size of the tex image was most probably changed.
-	//call retransform() to recalculate the position and the bounding box of the label
 	retransform();
+	DEBUG("teXRenderSuccessful =" << teXRenderSuccessful);
+	emit q->teXImageUpdated(teXRenderSuccessful);
 }
 
 bool TextLabelPrivate::swapVisible(bool on) {
@@ -492,7 +497,7 @@ void TextLabelPrivate::paint(QPainter *painter, const QStyleOptionGraphicsItem *
 	painter->rotate(-rotationAngle);
 
 	if (textWrapper.teXUsed) {
-		if (boundingRect().width()!=0.0 &&  boundingRect().height()!=0.0) {
+		if (boundingRect().width() != 0.0 &&  boundingRect().height() != 0.0) {
 			QImage todraw = teXImage.scaled(boundingRect().width(), boundingRect().height(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
 			painter->drawImage(boundingRect(), todraw);
 		}
@@ -574,25 +579,25 @@ QPointF TextLabelPrivate::positionFromItemPosition(const QPointF& itemPos) {
 	//depending on the alignment, calculate the new position
 	switch (horizontalAlignment) {
 	case TextLabel::hAlignLeft:
-		tmpPosition.setX( x + w/2 );
+		tmpPosition.setX(x + w/2);
 		break;
 	case TextLabel::hAlignCenter:
-		tmpPosition.setX( x );
+		tmpPosition.setX(x);
 		break;
 	case TextLabel::hAlignRight:
-		tmpPosition.setX( x - w/2 );
+		tmpPosition.setX(x - w/2);
 		break;
 	}
 
 	switch (verticalAlignment) {
 	case TextLabel::vAlignTop:
-		tmpPosition.setY( y + h/2 );
+		tmpPosition.setY(y + h/2);
 		break;
 	case TextLabel::vAlignCenter:
-		tmpPosition.setY( y );
+		tmpPosition.setY(y);
 		break;
 	case TextLabel::vAlignBottom:
-		tmpPosition.setY( y - h/2 );
+		tmpPosition.setY(y - h/2);
 		break;
 	}
 
@@ -648,12 +653,22 @@ void TextLabel::save(QXmlStreamWriter* writer) const {
 
 	writer->writeStartElement( "format" );
 	writer->writeAttribute( "teXUsed", QString::number(d->textWrapper.teXUsed) );
-	writer->writeAttribute( "teXFontSize", QString::number(d->teXFontSize) );
+	WRITE_QFONT(d->teXFont);
 	writer->writeAttribute( "teXFontColor_r", QString::number(d->teXFontColor.red()) );
 	writer->writeAttribute( "teXFontColor_g", QString::number(d->teXFontColor.green()) );
 	writer->writeAttribute( "teXFontColor_b", QString::number(d->teXFontColor.blue()) );
 	writer->writeEndElement();
 
+	if (d->textWrapper.teXUsed) {
+		writer->writeStartElement("teXImage");
+		QByteArray ba;
+		QBuffer buffer(&ba);
+		buffer.open(QIODevice::WriteOnly);
+		d->teXImage.save(&buffer, "PNG");
+		writer->writeCharacters(ba.toBase64());
+		writer->writeEndElement();
+	}
+
 	writer->writeEndElement(); // close "textLabel" section
 }
 
@@ -673,6 +688,7 @@ bool TextLabel::load(XmlStreamReader* reader) {
 	QXmlStreamAttributes attribs;
 	QString str;
 	QRectF rect;
+	bool teXImageFound = false;
 
 	while (!reader->atEnd()) {
 		reader->readNext();
@@ -745,11 +761,7 @@ bool TextLabel::load(XmlStreamReader* reader) {
 			else
 				d->textWrapper.teXUsed = str.toInt();
 
-			str = attribs.value("teXFontSize").toString();
-			if(str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'teXFontSize'"));
-			else
-				d->teXFontSize = str.toInt();
+			READ_QFONT(d->teXFont);
 
 			str = attribs.value("teXFontColor_r").toString();
 			if(str.isEmpty())
@@ -768,13 +780,38 @@ bool TextLabel::load(XmlStreamReader* reader) {
 				reader->raiseWarning(attributeWarning.arg("'teXFontColor_b'"));
 			else
 				d->teXFontColor.setBlue( str.toInt() );
+		} else if (reader->name() == "teXImage") {
+			reader->readNext();
+			QString content = reader->text().toString().trimmed();
+			QByteArray ba = QByteArray::fromBase64(content.toAscii());
+			teXImageFound = d->teXImage.loadFromData(ba);
 		} else { // unknown element
 			reader->raiseWarning(i18n("unknown element '%1'", reader->name().toString()));
 			if (!reader->skipToEndElement()) return false;
 		}
 	}
 
-	d->updateText();
+	//in case we use latex and the image was stored (older versions of LabPlot didn't save the image)and loaded,
+	//we just need to retransform.
+	//otherwise, we set the static text and retransform in updateText()
+	if ( !(d->textWrapper.teXUsed && teXImageFound) )
+		d->updateText();
+	else
+		retransform();
 
 	return true;
 }
+
+//##############################################################################
+//#########################  Theme management ##################################
+//##############################################################################
+void TextLabel::loadThemeConfig(const KConfig& config) {
+	KConfigGroup group = config.group("Label");
+	this->setTeXFontColor(group.readEntry("TeXFontColor", (QColor) this->teXFontColor()));
+	this->teXFontColorChanged(group.readEntry("TeXFontColor", (QColor) this->teXFontColor()));
+}
+
+void TextLabel::saveThemeConfig(const KConfig& config) {
+	KConfigGroup group = config.group("Label");
+	group.writeEntry("TeXFontColor", (QColor) this->teXFontColor());
+}
