@@ -32,6 +32,9 @@
 #include "Axis.h"
 #include "XYCurve.h"
 #include "XYEquationCurve.h"
+#include "XYDataReductionCurve.h"
+#include "XYDifferentiationCurve.h"
+#include "XYIntegrationCurve.h"
 #include "XYInterpolationCurve.h"
 #include "XYSmoothCurve.h"
 #include "XYFitCurve.h"
@@ -47,19 +50,20 @@
 #include "backend/worksheet/TextLabel.h"
 #include "backend/lib/XmlStreamReader.h"
 #include "backend/lib/commandtemplates.h"
+#include "backend/lib/macros.h"
 
-#include <cmath>
+#include <QDir>
 #include <QMenu>
 #include <QToolBar>
 #include <QPainter>
-
 #include <QIcon>
 #include <QAction>
+#include <QWidgetAction>
+
+#include <KConfigGroup>
 #include <KLocale>
-
-#define SCALE_MIN CartesianCoordinateSystem::Scale::LIMIT_MIN
-#define SCALE_MAX CartesianCoordinateSystem::Scale::LIMIT_MAX
-
+#include "kdefrontend/ThemeHandler.h"
+#include "kdefrontend/widgets/ThemesWidget.h"
 
 /**
  * \class CartesianPlot
@@ -81,7 +85,7 @@ CartesianPlot::~CartesianPlot() {
 	delete m_coordinateSystem;
 	delete addNewMenu;
 	delete zoomMenu;
-
+	delete themeMenu;
 	//don't need to delete objects added with addChild()
 
 	//no need to delete the d-pointer here - it inherits from QGraphicsItem
@@ -94,7 +98,7 @@ CartesianPlot::~CartesianPlot() {
 void CartesianPlot::init() {
 	Q_D(CartesianPlot);
 
-	d->cSystem = new CartesianCoordinateSystem(this);;
+	d->cSystem = new CartesianCoordinateSystem(this);
 	m_coordinateSystem = d->cSystem;
 
 	d->autoScaleX = true;
@@ -125,6 +129,7 @@ void CartesianPlot::init() {
 	connect(this, SIGNAL(aspectAdded(const AbstractAspect*)), this, SLOT(childAdded(const AbstractAspect*)));
 	connect(this, SIGNAL(aspectRemoved(const AbstractAspect*,const AbstractAspect*,const AbstractAspect*)),
 			this, SLOT(childRemoved(const AbstractAspect*,const AbstractAspect*,const AbstractAspect*)));
+
 	graphicsItem()->setFlag(QGraphicsItem::ItemIsMovable, true);
 	graphicsItem()->setFlag(QGraphicsItem::ItemClipsChildrenToShape, true);
 	graphicsItem()->setFlag(QGraphicsItem::ItemIsSelectable, true);
@@ -350,6 +355,9 @@ void CartesianPlot::initActions() {
 	addCurveAction = new QAction(QIcon::fromTheme("labplot-xy-curve"), i18n("xy-curve"), this);
 	addEquationCurveAction = new QAction(QIcon::fromTheme("labplot-xy-equation-curve"), i18n("xy-curve from a mathematical equation"), this);
 // no icons yet
+	addDataReductionCurveAction = new QAction(i18n("xy-curve from a data reduction"), this);
+	addDifferentiationCurveAction = new QAction(i18n("xy-curve from a differentiation"), this);
+	addIntegrationCurveAction = new QAction(i18n("xy-curve from an integration"), this);
 	addInterpolationCurveAction = new QAction(i18n("xy-curve from an interpolation"), this);
 	addSmoothCurveAction = new QAction(i18n("xy-curve from a smooth"), this);
 	addFitCurveAction = new QAction(QIcon::fromTheme("labplot-xy-fit-curve"), i18n("xy-curve from a fit to data"), this);
@@ -366,6 +374,7 @@ void CartesianPlot::initActions() {
 
 	connect(addCurveAction, SIGNAL(triggered()), SLOT(addCurve()));
 	connect(addEquationCurveAction, SIGNAL(triggered()), SLOT(addEquationCurve()));
+	// TODO: other analysis functions?
 	connect(addFitCurveAction, SIGNAL(triggered()), SLOT(addFitCurve()));
 	connect(addFourierFilterCurveAction, SIGNAL(triggered()), SLOT(addFourierFilterCurve()));
 	connect(addFourierTransformCurveAction, SIGNAL(triggered()), SLOT(addFourierTransformCurve()));
@@ -413,6 +422,9 @@ void CartesianPlot::initMenus() {
 	addNewMenu = new QMenu(i18n("Add new"));
 	addNewMenu->addAction(addCurveAction);
 	addNewMenu->addAction(addEquationCurveAction);
+	addNewMenu->addAction(addDataReductionCurveAction);
+	addNewMenu->addAction(addDifferentiationCurveAction);
+	addNewMenu->addAction(addIntegrationCurveAction);
 	addNewMenu->addAction(addInterpolationCurveAction);
 	addNewMenu->addAction(addSmoothCurveAction);
 	addNewMenu->addAction(addFitCurveAction);
@@ -444,6 +456,16 @@ void CartesianPlot::initMenus() {
 	zoomMenu->addSeparator();
 	zoomMenu->addAction(shiftUpYAction);
 	zoomMenu->addAction(shiftDownYAction);
+
+	themeMenu = new QMenu(i18n("Apply Theme"));
+	ThemesWidget* themeWidget = new ThemesWidget(0);
+	// TODO: SLOT: loadTheme(KConfig config)
+	connect(themeWidget, SIGNAL(themeSelected(QString)), this, SLOT(loadTheme(QString)));
+	connect(themeWidget, SIGNAL(themeSelected(QString)), themeMenu, SLOT(close()));
+
+	QWidgetAction* widgetAction = new QWidgetAction(this);
+	widgetAction->setDefaultWidget(themeWidget);
+	themeMenu->addAction(widgetAction);
 }
 
 QMenu* CartesianPlot::createContextMenu() {
@@ -456,6 +478,8 @@ QMenu* CartesianPlot::createContextMenu() {
 	menu->insertMenu(firstAction, addNewMenu);
 	menu->insertMenu(firstAction, zoomMenu);
 	menu->insertSeparator(firstAction);
+	menu->insertMenu(firstAction, themeMenu);
+	menu->insertSeparator(firstAction);
 
 	return menu;
 }
@@ -468,19 +492,19 @@ QIcon CartesianPlot::icon() const {
 }
 
 void CartesianPlot::navigate(CartesianPlot::NavigationOperation op) {
-	if (op==ScaleAuto) scaleAuto();
-	else if (op==ScaleAutoX) scaleAutoX();
-	else if (op==ScaleAutoY) scaleAutoY();
-	else if (op==ZoomIn) zoomIn();
-	else if (op==ZoomOut) zoomOut();
-	else if (op==ZoomInX) zoomInX();
-	else if (op==ZoomOutX) zoomOutX();
-	else if (op==ZoomInY) zoomInY();
-	else if (op==ZoomOutY) zoomOutY();
-	else if (op==ShiftLeftX) shiftLeftX();
-	else if (op==ShiftRightX) shiftRightX();
-	else if (op==ShiftUpY) shiftUpY();
-	else if (op==ShiftDownY) shiftDownY();
+	if (op == ScaleAuto) scaleAuto();
+	else if (op == ScaleAutoX) scaleAutoX();
+	else if (op == ScaleAutoY) scaleAutoY();
+	else if (op == ZoomIn) zoomIn();
+	else if (op == ZoomOut) zoomOut();
+	else if (op == ZoomInX) zoomInX();
+	else if (op == ZoomOutX) zoomOutX();
+	else if (op == ZoomInY) zoomInY();
+	else if (op == ZoomOutY) zoomOutY();
+	else if (op == ShiftLeftX) shiftLeftX();
+	else if (op == ShiftRightX) shiftRightX();
+	else if (op == ShiftUpY) shiftUpY();
+	else if (op == ShiftDownY) shiftDownY();
 }
 
 //##############################################################################
@@ -535,9 +559,8 @@ void CartesianPlot::setRect(const QRectF& rect) {
 
 class CartesianPlotSetAutoScaleXCmd : public QUndoCommand {
 public:
-	CartesianPlotSetAutoScaleXCmd(CartesianPlotPrivate* private_obj, bool autoScale) {
-		m_private = private_obj;
-		m_autoScale = autoScale;
+	CartesianPlotSetAutoScaleXCmd(CartesianPlotPrivate* private_obj, bool autoScale) :
+		m_private(private_obj), m_autoScale(autoScale), m_minOld(0.0), m_maxOld(0.0) {
 		setText(i18n("%1: change x-range auto scaling", m_private->name()));
 	};
 
@@ -612,9 +635,8 @@ void CartesianPlot::setXRangeBreaks(const RangeBreaks& breakings) {
 
 class CartesianPlotSetAutoScaleYCmd : public QUndoCommand {
 public:
-	CartesianPlotSetAutoScaleYCmd(CartesianPlotPrivate* private_obj, bool autoScale) {
-		m_private = private_obj;
-		m_autoScale = autoScale;
+	CartesianPlotSetAutoScaleYCmd(CartesianPlotPrivate* private_obj, bool autoScale) :
+		m_private(private_obj), m_autoScale(autoScale), m_minOld(0.0), m_maxOld(0.0) {
 		setText(i18n("%1: change y-range auto scaling", m_private->name()));
 	};
 
@@ -715,41 +737,66 @@ void CartesianPlot::addVerticalAxis() {
 XYCurve* CartesianPlot::addCurve() {
 	XYCurve* curve = new XYCurve("xy-curve");
 	this->addChild(curve);
+	this->applyThemeOnNewCurve(curve);
 	return curve;
 }
 
 XYEquationCurve* CartesianPlot::addEquationCurve() {
 	XYEquationCurve* curve = new XYEquationCurve("f(x)");
 	this->addChild(curve);
+	this->applyThemeOnNewCurve(curve);
+	return curve;
+}
+
+XYDataReductionCurve* CartesianPlot::addDataReductionCurve() {
+	XYDataReductionCurve* curve = new XYDataReductionCurve("Data reduction");
+	this->addChild(curve);
+	return curve;
+}
+
+XYDifferentiationCurve* CartesianPlot::addDifferentiationCurve() {
+	XYDifferentiationCurve* curve = new XYDifferentiationCurve("Differentiation");
+	this->addChild(curve);
+	return curve;
+}
+
+XYIntegrationCurve* CartesianPlot::addIntegrationCurve() {
+	XYIntegrationCurve* curve = new XYIntegrationCurve("Integration");
+	this->addChild(curve);
 	return curve;
 }
 
 XYInterpolationCurve* CartesianPlot::addInterpolationCurve() {
 	XYInterpolationCurve* curve = new XYInterpolationCurve("Interpolation");
 	this->addChild(curve);
+	this->applyThemeOnNewCurve(curve);
 	return curve;
 }
 
 XYSmoothCurve* CartesianPlot::addSmoothCurve() {
 	XYSmoothCurve* curve = new XYSmoothCurve("Smooth");
 	this->addChild(curve);
+	this->applyThemeOnNewCurve(curve);
 	return curve;
 }
 XYFitCurve* CartesianPlot::addFitCurve() {
 	XYFitCurve* curve = new XYFitCurve("fit");
 	this->addChild(curve);
+	this->applyThemeOnNewCurve(curve);
 	return curve;
 }
 
 XYFourierFilterCurve* CartesianPlot::addFourierFilterCurve() {
 	XYFourierFilterCurve* curve = new XYFourierFilterCurve("Fourier filter");
 	this->addChild(curve);
+	this->applyThemeOnNewCurve(curve);
 	return curve;
 }
 
 XYFourierTransformCurve* CartesianPlot::addFourierTransformCurve() {
 	XYFourierTransformCurve* curve = new XYFourierTransformCurve("Fourier transform");
 	this->addChild(curve);
+	this->applyThemeOnNewCurve(curve);
 	return curve;
 }
 
@@ -1140,16 +1187,18 @@ void CartesianPlot::scaleAuto() {
 }
 
 void CartesianPlot::zoomIn() {
+	DEBUG("CartesianPlot::zoomIn()");
 	Q_D(CartesianPlot);
-	float oldRange = (d->xMax-d->xMin);
-	float newRange = (d->xMax-d->xMin)/m_zoomFactor;
-	d->xMax = d->xMax + (newRange-oldRange)/2;
-	d->xMin = d->xMin - (newRange-oldRange)/2;
 
-	oldRange = (d->yMax-d->yMin);
-	newRange = (d->yMax-d->yMin)/m_zoomFactor;
-	d->yMax = d->yMax + (newRange-oldRange)/2;
-	d->yMin = d->yMin - (newRange-oldRange)/2;
+	float oldRange = (d->xMax - d->xMin);
+	float newRange = (d->xMax - d->xMin) / m_zoomFactor;
+	d->xMax = d->xMax + (newRange - oldRange) / 2;
+	d->xMin = d->xMin - (newRange - oldRange) / 2;
+
+	oldRange = (d->yMax - d->yMin);
+	newRange = (d->yMax - d->yMin) / m_zoomFactor;
+	d->yMax = d->yMax + (newRange - oldRange) / 2;
+	d->yMin = d->yMin - (newRange - oldRange) / 2;
 
 	d->retransformScales();
 }
@@ -1264,6 +1313,7 @@ CartesianPlotPrivate::CartesianPlotPrivate(CartesianPlot *owner)
 	Also, the size (=bounding box) of CartesianPlot can be greater than the size of the plot area.
  */
 void CartesianPlotPrivate::retransform() {
+	DEBUG("CartesianPlotPrivate::retransform()");
 	if (suppressRetransform)
 		return;
 
@@ -1286,9 +1336,10 @@ void CartesianPlotPrivate::retransform() {
 }
 
 void CartesianPlotPrivate::retransformScales() {
+	DEBUG("CartesianPlotPrivate::retransformScales()");
+
 	CartesianPlot* plot = dynamic_cast<CartesianPlot*>(q);
-	QList<CartesianCoordinateSystem::Scale*> scales;
-	double sceneStart, sceneEnd, logicalStart, logicalEnd;
+	QList<CartesianScale*> scales;
 
 	//perform the mapping from the scene coordinates to the plot's coordinates here.
 	QRectF itemRect = mapRectFromScene(rect);
@@ -1297,89 +1348,113 @@ void CartesianPlotPrivate::retransformScales() {
 	if (xScale != CartesianPlot::ScaleLinear)
 		checkXRange();
 
-	//check where we have x-range breaks
-	bool hasValidBreak = false;
-	if (xRangeBreakingEnabled && !xRangeBreaks.list.isEmpty()) {
-		foreach(const CartesianPlot::RangeBreak& b, xRangeBreaks.list)
-			hasValidBreak = (!std::isnan(b.start) && !std::isnan(b.end));
-	}
+	//check whether we have x-range breaks - the first break, if available, should be valid
+	bool hasValidBreak = (xRangeBreakingEnabled && !xRangeBreaks.list.isEmpty() && xRangeBreaks.list.first().isValid());
+
+	static const int breakGap = 20;
+	double sceneStart, sceneEnd, logicalStart, logicalEnd;
 
 	//create x-scales
+	int plotSceneStart = itemRect.x() + horizontalPadding;
+	int plotSceneEnd = itemRect.x() + itemRect.width() - horizontalPadding;
 	if (!hasValidBreak) {
-		sceneStart = itemRect.x()+horizontalPadding;
-		sceneEnd = itemRect.x()+itemRect.width()-horizontalPadding;
+		//no breaks available -> range goes from the plot beginning to the end of the plot
+		sceneStart = plotSceneStart;
+		sceneEnd = plotSceneEnd;
 		logicalStart = xMin;
 		logicalEnd = xMax;
 
-		//TODO: how should we handle the case sceneStart=sceneEnd
+		//TODO: how should we handle the case sceneStart == sceneEnd?
 		//(to reproduce, create plots and adjust the spacing/pading to get zero size for the plots)
-		if (sceneStart!=sceneEnd) {
-			Interval<double> interval(SCALE_MIN, SCALE_MAX);
-			scales << this->createScale(xScale, interval, sceneStart, sceneEnd, logicalStart, logicalEnd);
-		}
+		if (sceneStart != sceneEnd)
+			scales << this->createScale(xScale, sceneStart, sceneEnd, logicalStart, logicalEnd);
 	} else {
-		foreach(const CartesianPlot::RangeBreak& b, xRangeBreaks.list) {
-			sceneStart = itemRect.x()+horizontalPadding;
-			sceneEnd = itemRect.x()+itemRect.width()-horizontalPadding;
-			sceneEnd = sceneStart+(sceneEnd-sceneStart)*b.position;
-			logicalStart = xMin;
-			logicalEnd = b.start;
+		int sceneEndLast = plotSceneStart;
+		int logicalEndLast = xMin;
+		for (int i = 0; i < xRangeBreaks.list.size(); ++i) {
+			const CartesianPlot::RangeBreak& curBreak = xRangeBreaks.list.at(i);
+			if (!curBreak.isValid())
+				break;
 
-			Interval<double> interval(SCALE_MIN, SCALE_MAX);
-			scales << this->createScale(xScale, interval, sceneStart, sceneEnd, logicalStart, logicalEnd);
+			//current range goes from the end of the previous one (or from the plot beginning) to curBreak.start
+			sceneStart = sceneEndLast;
+			if (i != 0) sceneStart += breakGap;
+			sceneEnd = plotSceneStart+(plotSceneEnd-plotSceneStart)*curBreak.position;
+			logicalStart = logicalEndLast;
+			logicalEnd = curBreak.start;
 
-			sceneStart = sceneEnd+50;
-			sceneEnd = itemRect.x()+itemRect.width()-horizontalPadding;
-			logicalStart = b.end;
-			logicalEnd = xMax;
-			Interval<double> interval2(SCALE_MIN, SCALE_MAX);
-			scales << this->createScale(xScale, interval2, sceneStart, sceneEnd, logicalStart, logicalEnd);
+			if (sceneStart!=sceneEnd)
+				scales << this->createScale(xScale, sceneStart, sceneEnd, logicalStart, logicalEnd);
+
+			sceneEndLast = sceneEnd;
+			logicalEndLast = curBreak.end;
 		}
+
+		//add the remaining range going from the last available range break to the end of the plot (=end of the x-data range)
+		sceneStart = sceneEndLast+breakGap;
+		sceneEnd = plotSceneEnd;
+		logicalStart = logicalEndLast;
+		logicalEnd = xMax;
+
+		if (sceneStart != sceneEnd)
+			scales << this->createScale(xScale, sceneStart, sceneEnd, logicalStart, logicalEnd);
 	}
 
-	cSystem ->setXScales(scales);
+	cSystem->setXScales(scales);
 
 	//check ranges for log-scales
 	if (yScale != CartesianPlot::ScaleLinear)
 		checkYRange();
 
-	//check where we have y-range breaks
-	hasValidBreak = false;
-	if (yRangeBreakingEnabled && !yRangeBreaks.list.isEmpty()) {
-		foreach(const CartesianPlot::RangeBreak& b, yRangeBreaks.list)
-			hasValidBreak = (!std::isnan(b.start) && !std::isnan(b.end));
-	}
+	//check whether we have y-range breaks - the first break, if available, should be valid
+	hasValidBreak = (yRangeBreakingEnabled && !yRangeBreaks.list.isEmpty() && yRangeBreaks.list.first().isValid());
 
 	//create y-scales
 	scales.clear();
+	plotSceneStart = itemRect.y()+itemRect.height()-verticalPadding;
+	plotSceneEnd = itemRect.y()+verticalPadding;
 	if (!hasValidBreak) {
-		sceneStart = itemRect.y()+itemRect.height()-verticalPadding;
-		sceneEnd = itemRect.y()+verticalPadding;
+		//no breaks available -> range goes from the plot beginning to the end of the plot
+		sceneStart = plotSceneStart;
+		sceneEnd = plotSceneEnd;
 		logicalStart = yMin;
 		logicalEnd = yMax;
-		Interval<double> interval (SCALE_MIN, SCALE_MAX);
-		scales << this->createScale(yScale, interval, sceneStart, sceneEnd, logicalStart, logicalEnd);
+
+		if (sceneStart != sceneEnd)
+			scales << this->createScale(yScale, sceneStart, sceneEnd, logicalStart, logicalEnd);
 	} else {
-		foreach(const CartesianPlot::RangeBreak& b, yRangeBreaks.list) {
-			sceneStart = itemRect.y()+itemRect.height()-verticalPadding;
-			sceneEnd = itemRect.y()+verticalPadding;
-			sceneEnd = sceneStart+(sceneEnd-sceneStart)*b.position;
-			logicalStart = yMin;
-			logicalEnd = b.start;
+		int sceneEndLast = plotSceneStart;
+		int logicalEndLast = yMin;
+		for (int i=0; i < yRangeBreaks.list.size(); ++i) {
+			const CartesianPlot::RangeBreak& curBreak = yRangeBreaks.list.at(i);
+			if (!curBreak.isValid())
+				break;
 
-			Interval<double> interval(SCALE_MIN, SCALE_MAX);
-			scales << this->createScale(yScale, interval, sceneStart, sceneEnd, logicalStart, logicalEnd);
+			//current range goes from the end of the previous one (or from the plot beginning) to curBreak.start
+			sceneStart = sceneEndLast;
+			if (i != 0) sceneStart-=breakGap;
+			sceneEnd = plotSceneStart+(plotSceneEnd-plotSceneStart)*curBreak.position;
+			logicalStart = logicalEndLast;
+			logicalEnd = curBreak.start;
 
-			sceneStart = sceneEnd+50;
-			sceneEnd = itemRect.y()+verticalPadding;
-			logicalStart = b.end;
-			logicalEnd = yMax;
-			Interval<double> interval2(SCALE_MIN, SCALE_MAX);
-			scales << this->createScale(yScale, interval2, sceneStart, sceneEnd, logicalStart, logicalEnd);
+			if (sceneStart != sceneEnd)
+				scales << this->createScale(yScale, sceneStart, sceneEnd, logicalStart, logicalEnd);
+
+			sceneEndLast = sceneEnd;
+			logicalEndLast = curBreak.end;
 		}
+
+		//add the remaining range going from the last available range break to the end of the plot (=end of the y-data range)
+		sceneStart = sceneEndLast-breakGap;
+		sceneEnd = plotSceneEnd;
+		logicalStart = logicalEndLast;
+		logicalEnd = yMax;
+
+		if (sceneStart!=sceneEnd)
+			scales << this->createScale(yScale, sceneStart, sceneEnd, logicalStart, logicalEnd);
 	}
 
-	cSystem ->setYScales(scales);
+	cSystem->setYScales(scales);
 
 	//calculate the changes in x and y and save the current values for xMin, xMax, yMin, yMax
 	float deltaXMin = 0;
@@ -1414,17 +1489,17 @@ void CartesianPlotPrivate::retransformScales() {
 
 	//adjust auto-scale axes
 	QList<Axis*> childElements = q->children<Axis>();
-	foreach(Axis* axis, childElements) {
+	foreach (Axis* axis, childElements) {
 		if (!axis->autoScale())
 			continue;
 
 		if (axis->orientation() == Axis::AxisHorizontal) {
-			if (deltaXMax!=0) {
+			if (deltaXMax != 0) {
 				axis->setUndoAware(false);
 				axis->setEnd(xMax);
 				axis->setUndoAware(true);
 			}
-			if (deltaXMin!=0) {
+			if (deltaXMin != 0) {
 				axis->setUndoAware(false);
 				axis->setStart(xMin);
 				axis->setUndoAware(true);
@@ -1434,12 +1509,12 @@ void CartesianPlotPrivate::retransformScales() {
 // 				axis->setOffset(axis->offset() + deltaYMin, false);
 // 			}
 		} else {
-			if (deltaYMax!=0) {
+			if (deltaYMax != 0) {
 				axis->setUndoAware(false);
 				axis->setEnd(yMax);
 				axis->setUndoAware(true);
 			}
-			if (deltaYMin!=0) {
+			if (deltaYMin != 0) {
 				axis->setUndoAware(false);
 				axis->setStart(yMin);
 				axis->setUndoAware(true);
@@ -1447,17 +1522,17 @@ void CartesianPlotPrivate::retransformScales() {
 
 			//TODO;
 // 			if (axis->position() == Axis::AxisCustom && deltaXMin != 0) {
+
 // 				axis->setOffset(axis->offset() + deltaXMin, false);
 // 			}
 		}
 	}
-
 	// call retransform() on the parent to trigger the update of all axes and curves
 	q->retransform();
 }
 
 /*!
- * don't allow any negative values on for the x range when log or sqrt scalings are used
+ * don't allow any negative values for the x range when log or sqrt scalings are used
  */
 void CartesianPlotPrivate::checkXRange() {
 	double min = 0.01;
@@ -1472,7 +1547,7 @@ void CartesianPlotPrivate::checkXRange() {
 }
 
 /*!
- * don't allow any negative values on for the y range when log or sqrt scalings are used
+ * don't allow any negative values for the y range when log or sqrt scalings are used
  */
 void CartesianPlotPrivate::checkYRange() {
 	double min = 0.01;
@@ -1486,10 +1561,12 @@ void CartesianPlotPrivate::checkYRange() {
 	}
 }
 
-CartesianCoordinateSystem::Scale* CartesianPlotPrivate::createScale(CartesianPlot::Scale type, Interval<double>& interval,
-	double sceneStart, double sceneEnd,double logicalStart, double logicalEnd) {
+CartesianScale* CartesianPlotPrivate::createScale(CartesianPlot::Scale type, double sceneStart, double sceneEnd, double logicalStart, double logicalEnd) {
+// 	Interval<double> interval (logicalStart-0.01, logicalEnd+0.01); //TODO: move this to CartesianScale
+	Interval<double> interval (-1E15, 1E15);
+// 	Interval<double> interval (logicalStart, logicalEnd);
 	if (type == CartesianPlot::ScaleLinear) {
-		return CartesianCoordinateSystem::Scale::createLinearScale(interval, sceneStart, sceneEnd, logicalStart, logicalEnd);
+		return CartesianScale::createLinearScale(interval, sceneStart, sceneEnd, logicalStart, logicalEnd);
 	} else {
 		float base;
 		if (type == CartesianPlot::ScaleLog10)
@@ -1499,7 +1576,7 @@ CartesianCoordinateSystem::Scale* CartesianPlotPrivate::createScale(CartesianPlo
 		else
 			base = 2.71828;
 
-		return CartesianCoordinateSystem::Scale::createLogScale(interval, sceneStart, sceneEnd, logicalStart, logicalEnd, base);
+		return CartesianScale::createLogScale(interval, sceneStart, sceneEnd, logicalStart, logicalEnd, base);
 	}
 }
 
@@ -1695,11 +1772,13 @@ void CartesianPlotPrivate::hoverMoveEvent(QGraphicsSceneHoverEvent* event) {
 }
 
 void CartesianPlotPrivate::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget * widget) {
+	DEBUG("CartesianPlotPrivate::paint()");
+
 	if (!isVisible())
 		return;
 
 	painter->setPen(QPen(Qt::black, 3));
-	if ( (mouseMode == CartesianPlot::ZoomXSelectionMode || mouseMode == CartesianPlot::ZoomYSelectionMode)
+	if ((mouseMode == CartesianPlot::ZoomXSelectionMode || mouseMode == CartesianPlot::ZoomYSelectionMode)
 			&& (!m_selectionBandIsShown)) {
 		painter->drawLine(m_selectionStartLine);
 	}
@@ -1715,6 +1794,7 @@ void CartesianPlotPrivate::paint(QPainter *painter, const QStyleOptionGraphicsIt
 	}
 
 	WorksheetElementContainerPrivate::paint(painter, option, widget);
+	DEBUG("CartesianPlotPrivate::paint() DONE");
 }
 
 //##############################################################################
@@ -1729,6 +1809,13 @@ void CartesianPlot::save(QXmlStreamWriter* writer) const {
 	writeBasicAttributes(writer);
 	writeCommentElement(writer);
 
+	//applied theme
+	if (!m_themeName.isEmpty()){
+		writer->writeStartElement( "theme" );
+		writer->writeAttribute("name", m_themeName);
+		writer->writeEndElement();
+	}
+
 	//geometry
 	writer->writeStartElement( "geometry" );
 	writer->writeAttribute( "x", QString::number(d->rect.x()) );
@@ -1806,6 +1893,7 @@ bool CartesianPlot::load(XmlStreamReader* reader) {
 	QString attributeWarning = i18n("Attribute '%1' missing or empty, default value is used");
 	QXmlStreamAttributes attribs;
 	QString str;
+	QString tmpThemeName;
 
 	while (!reader->atEnd()) {
 		reader->readNext();
@@ -1818,6 +1906,9 @@ bool CartesianPlot::load(XmlStreamReader* reader) {
 		if (reader->name() == "comment") {
 			if (!readCommentElement(reader))
 				return false;
+		} else if (reader->name() == "theme") {
+			attribs = reader->attributes();
+			tmpThemeName = attribs.value("name").toString();
 		} else if (reader->name() == "geometry") {
 			attribs = reader->attributes();
 
@@ -2029,6 +2120,30 @@ bool CartesianPlot::load(XmlStreamReader* reader) {
 				removeChild(curve);
 				return false;
 			}
+		} else if (reader->name() == "xyDataReductionCurve") {
+			XYDataReductionCurve* curve = addDataReductionCurve();
+			if (!curve->load(reader)) {
+				removeChild(curve);
+				return false;
+			}
+		} else if (reader->name() == "xyDifferentiationCurve") {
+			XYDifferentiationCurve* curve = addDifferentiationCurve();
+			if (!curve->load(reader)) {
+				removeChild(curve);
+				return false;
+			}
+		} else if (reader->name() == "xyIntegrationCurve") {
+			XYIntegrationCurve* curve = addIntegrationCurve();
+			if (!curve->load(reader)) {
+				removeChild(curve);
+				return false;
+			}
+		} else if (reader->name() == "xyInterpolationCurve") {
+			XYInterpolationCurve* curve = addInterpolationCurve();
+			if (!curve->load(reader)) {
+				removeChild(curve);
+				return false;
+			}
 		} else if (reader->name() == "xyFitCurve") {
 			XYFitCurve* curve = addFitCurve();
 			if (!curve->load(reader)) {
@@ -2047,12 +2162,6 @@ bool CartesianPlot::load(XmlStreamReader* reader) {
 				removeChild(curve);
 				return false;
 			}
-		} else if (reader->name() == "xyInterpolationCurve") {
-			XYInterpolationCurve* curve = addInterpolationCurve();
-			if (!curve->load(reader)) {
-				removeChild(curve);
-				return false;
-			}
 		} else if (reader->name() == "xySmoothCurve") {
 			XYSmoothCurve* curve = addSmoothCurve();
 			if (!curve->load(reader)) {
@@ -2088,5 +2197,106 @@ bool CartesianPlot::load(XmlStreamReader* reader) {
 		m_title->graphicsItem()->setParentItem(m_plotArea->graphicsItem());
 	}
 
+	//if a theme was used, assign the value to the private member at the very end of load()
+	//so we don't try to load the theme in applyThemeOnNewCurve() when adding curves on project load and calculate the palette
+	if (!tmpThemeName.isEmpty()){
+		KConfig config( ThemeHandler::themeFilePath(tmpThemeName), KConfig::SimpleConfig );
+		//TODO: check whether the theme config really exists
+		m_themeName = tmpThemeName;
+		this->setColorPalette(config);
+	}
+
 	return true;
 }
+
+//##############################################################################
+//#########################  Theme management ##################################
+//##############################################################################
+void CartesianPlot::loadTheme(const QString& theme) {
+	KConfig config(ThemeHandler::themeFilePath(theme), KConfig::SimpleConfig);
+	loadTheme(config);
+}
+
+void CartesianPlot::loadTheme(KConfig& config) {
+	const QString str = config.name();
+	m_themeName = str.right(str.length() - str.lastIndexOf(QDir::separator()) - 1);
+	beginMacro( i18n("%1: Load theme %2.", AbstractAspect::name(), m_themeName) );
+
+	//load the color palettes for the curves
+	this->setColorPalette(config);
+
+	//load the theme for all the children
+	const QList<WorksheetElement*>& childElements = children<WorksheetElement>(AbstractAspect::IncludeHidden);
+	foreach (WorksheetElement* child, childElements)
+		child->loadThemeConfig(config);
+
+	Q_D(CartesianPlot);
+	d->update(this->rect());
+
+	endMacro();
+}
+
+void CartesianPlot::saveTheme(KConfig &config) {
+	const QList<Axis*>& axisElements = children<Axis>(AbstractAspect::IncludeHidden);
+	const QList<PlotArea*>& plotAreaElements = children<PlotArea>(AbstractAspect::IncludeHidden);
+	const QList<TextLabel*>& textLabelElements = children<TextLabel>(AbstractAspect::IncludeHidden);
+	const QList<XYCurve*>& xyCurveElements = children<XYCurve>(AbstractAspect::IncludeHidden);
+
+	axisElements.at(0)->saveThemeConfig(config);
+	plotAreaElements.at(0)->saveThemeConfig(config);
+	textLabelElements.at(0)->saveThemeConfig(config);
+
+	foreach(XYCurve *child, xyCurveElements)
+		child->saveThemeConfig(config);
+}
+
+//Generating colors from 5-color theme palette
+void CartesianPlot::setColorPalette(const KConfig& config) {
+	KConfigGroup group = config.group("Theme");
+
+	//read the five colors defining the palette
+	m_themeColorPalette.append(group.readEntry("ThemePaletteColor1", QColor()));
+	m_themeColorPalette.append(group.readEntry("ThemePaletteColor2", QColor()));
+	m_themeColorPalette.append(group.readEntry("ThemePaletteColor3", QColor()));
+	m_themeColorPalette.append(group.readEntry("ThemePaletteColor4", QColor()));
+	m_themeColorPalette.append(group.readEntry("ThemePaletteColor5", QColor()));
+
+	//generate 30 additional shades if the color palette contains more than one color
+	if(m_themeColorPalette.at(0) != m_themeColorPalette.at(1)) {
+		QColor c;
+
+		//3 factors to create shades from theme's palette
+		float fac[3] = {0.25,0.45,0.65};
+
+		//Generate 15 lighter shades
+		for(int i = 0; i < 5; i++) {
+			for(int j = 1; j < 4; j++) {
+				c.setRed( m_themeColorPalette.at(i).red()*(1-fac[j-1]) );
+				c.setGreen( m_themeColorPalette.at(i).green()*(1-fac[j-1]) );
+				c.setBlue( m_themeColorPalette.at(i).blue()*(1-fac[j-1]) );
+				m_themeColorPalette.append(c);
+			}
+		}
+
+		//Generate 15 darker shades
+		for(int i = 0; i < 5; i++) {
+			for(int j = 4; j < 7; j++) {
+				c.setRed( m_themeColorPalette.at(i).red()+((255-m_themeColorPalette.at(i).red())*fac[j-4]) );
+				c.setGreen( m_themeColorPalette.at(i).green()+((255-m_themeColorPalette.at(i).green())*fac[j-4]) );
+				c.setBlue( m_themeColorPalette.at(i).blue()+((255-m_themeColorPalette.at(i).blue())*fac[j-4]) );
+				m_themeColorPalette.append(c);
+			}
+		}
+	}
+}
+
+const QList<QColor>& CartesianPlot::themeColorPalette() const {
+	return m_themeColorPalette;
+}
+
+void CartesianPlot::applyThemeOnNewCurve(XYCurve* curve) {
+	if (!m_themeName.isEmpty()) {
+		KConfig config( ThemeHandler::themeFilePath(m_themeName), KConfig::SimpleConfig );
+		curve->loadThemeConfig(config);
+	}
+}
