@@ -40,15 +40,15 @@
 #include "backend/worksheet/plots/cartesian/CartesianCoordinateSystem.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlot.h"
 #include "backend/lib/commandtemplates.h"
+#include "backend/core/Project.h"
+#include "backend/spreadsheet/Spreadsheet.h"
 #include "backend/worksheet/Worksheet.h"
 #include "backend/lib/XmlStreamReader.h"
+#include "backend/lib/macros.h"
 
 #include <QPainter>
 #include <QGraphicsSceneContextMenuEvent>
 #include <QMenu>
-#ifndef NDEBUG
-#include <QDebug>
-#endif
 // #include <QElapsedTimer>
 
 #include <KIcon>
@@ -141,7 +141,7 @@ void XYCurve::init() {
 	d->errorBarsCapSize = group.readEntry( "ErrorBarsCapSize", Worksheet::convertToSceneUnits(10, Worksheet::Point) );
 	d->errorBarsPen.setStyle( (Qt::PenStyle)group.readEntry("ErrorBarsStyle", (int)Qt::SolidLine) );
 	d->errorBarsPen.setColor( group.readEntry("ErrorBarsColor", QColor(Qt::black)) );
-	d->errorBarsPen.setWidthF( group.readEntry("ErrorBarsWidth", Worksheet::convertToSceneUnits(0.0, Worksheet::Point)) );
+	d->errorBarsPen.setWidthF( group.readEntry("ErrorBarsWidth", Worksheet::convertToSceneUnits(1.0, Worksheet::Point)) );
 	d->errorBarsOpacity = group.readEntry("ErrorBarsOpacity", 1.0);
 
 	this->initActions();
@@ -151,6 +151,9 @@ void XYCurve::initActions() {
 	visibilityAction = new QAction(i18n("visible"), this);
 	visibilityAction->setCheckable(true);
 	connect(visibilityAction, SIGNAL(triggered()), this, SLOT(visibilityChanged()));
+
+	navigateToAction = new QAction(KIcon("go-next-view"), "", this);
+	connect(navigateToAction, SIGNAL(triggered()), this, SLOT(navigateTo()));
 }
 
 QMenu* XYCurve::createContextMenu() {
@@ -158,6 +161,21 @@ QMenu* XYCurve::createContextMenu() {
 	QAction* firstAction = menu->actions().at(1); //skip the first action because of the "title-action"
 	visibilityAction->setChecked(isVisible());
 	menu->insertAction(firstAction, visibilityAction);
+
+	//"Navigate to spreadsheet"-action, show only if x- or y-columns have data from a spreadsheet
+	AbstractAspect* parentSpreadsheet = 0;
+	if (xColumn() && dynamic_cast<Spreadsheet*>(xColumn()->parentAspect()) )
+		parentSpreadsheet = xColumn()->parentAspect();
+	else if (yColumn() && dynamic_cast<Spreadsheet*>(yColumn()->parentAspect()) )
+		parentSpreadsheet = yColumn()->parentAspect();
+
+	if (parentSpreadsheet) {
+		navigateToAction->setText(i18n("Navigate to \"%1\"", parentSpreadsheet->name()));
+		navigateToAction->setData(parentSpreadsheet->path());
+		menu->insertAction(visibilityAction, navigateToAction);
+		menu->insertSeparator(visibilityAction);
+	}
+
 	return menu;
 }
 
@@ -344,7 +362,7 @@ void XYCurve::setLinePen(const QPen &pen) {
 		exec(new XYCurveSetLinePenCmd(d, pen, i18n("%1: set line style")));
 }
 
-STD_SETTER_CMD_IMPL_F_S(XYCurve, SetLineOpacity, qreal, lineOpacity, update);
+STD_SETTER_CMD_IMPL_F_S(XYCurve, SetLineOpacity, qreal, lineOpacity, updatePixmap);
 void XYCurve::setLineOpacity(qreal opacity) {
 	Q_D(XYCurve);
 	if (opacity != d->lineOpacity)
@@ -470,21 +488,21 @@ void XYCurve::setValuesOpacity(qreal opacity) {
 STD_SETTER_CMD_IMPL_F_S(XYCurve, SetValuesPrefix, QString, valuesPrefix, updateValues)
 void XYCurve::setValuesPrefix(const QString& prefix) {
 	Q_D(XYCurve);
-	if (prefix!= d->valuesPrefix)
+	if (prefix != d->valuesPrefix)
 		exec(new XYCurveSetValuesPrefixCmd(d, prefix, i18n("%1: set values prefix")));
 }
 
 STD_SETTER_CMD_IMPL_F_S(XYCurve, SetValuesSuffix, QString, valuesSuffix, updateValues)
 void XYCurve::setValuesSuffix(const QString& suffix) {
 	Q_D(XYCurve);
-	if (suffix!= d->valuesSuffix)
+	if (suffix != d->valuesSuffix)
 		exec(new XYCurveSetValuesSuffixCmd(d, suffix, i18n("%1: set values suffix")));
 }
 
 STD_SETTER_CMD_IMPL_F_S(XYCurve, SetValuesFont, QFont, valuesFont, updateValues)
 void XYCurve::setValuesFont(const QFont& font) {
 	Q_D(XYCurve);
-	if (font!= d->valuesFont)
+	if (font != d->valuesFont)
 		exec(new XYCurveSetValuesFontCmd(d, font, i18n("%1: set values font")));
 }
 
@@ -534,21 +552,21 @@ void XYCurve::setFillingBrushStyle(Qt::BrushStyle style) {
 STD_SETTER_CMD_IMPL_F_S(XYCurve, SetFillingFirstColor, QColor, fillingFirstColor, updatePixmap)
 void XYCurve::setFillingFirstColor(const QColor& color) {
 	Q_D(XYCurve);
-	if (color!= d->fillingFirstColor)
+	if (color != d->fillingFirstColor)
 		exec(new XYCurveSetFillingFirstColorCmd(d, color, i18n("%1: set filling first color")));
 }
 
 STD_SETTER_CMD_IMPL_F_S(XYCurve, SetFillingSecondColor, QColor, fillingSecondColor, updatePixmap)
 void XYCurve::setFillingSecondColor(const QColor& color) {
 	Q_D(XYCurve);
-	if (color!= d->fillingSecondColor)
+	if (color != d->fillingSecondColor)
 		exec(new XYCurveSetFillingSecondColorCmd(d, color, i18n("%1: set filling second color")));
 }
 
 STD_SETTER_CMD_IMPL_F_S(XYCurve, SetFillingFileName, QString, fillingFileName, updatePixmap)
 void XYCurve::setFillingFileName(const QString& fileName) {
 	Q_D(XYCurve);
-	if (fileName!= d->fillingFileName)
+	if (fileName != d->fillingFileName)
 		exec(new XYCurveSetFillingFileNameCmd(d, fileName, i18n("%1: set filling image")));
 }
 
@@ -663,18 +681,23 @@ void XYCurve::suppressRetransform(bool b) {
 //#################################  SLOTS  ####################################
 //##############################################################################
 void XYCurve::retransform() {
+	DEBUG("XYCurve::retransform()");
+	Q_D(XYCurve);
+
 	WAIT_CURSOR;
 	QApplication::processEvents(QEventLoop::AllEvents, 0);
-	d_ptr->retransform();
+	d->retransform();
 	RESET_CURSOR;
 }
 
 void XYCurve::updateValues() {
-	d_ptr->updateValues();
+	Q_D(XYCurve);
+	d->updateValues();
 }
 
 void XYCurve::updateErrorBars() {
-	d_ptr->updateErrorBars();
+	Q_D(XYCurve);
+	d->updateErrorBars();
 }
 
 //TODO
@@ -763,6 +786,10 @@ void XYCurve::visibilityChanged() {
 	this->setVisible(!d->isVisible());
 }
 
+void XYCurve::navigateTo() {
+	project()->navigateTo(navigateToAction->data().toString());
+}
+
 //##############################################################################
 //######################### Private implementation #############################
 //##############################################################################
@@ -803,6 +830,7 @@ bool XYCurvePrivate::swapVisible(bool on) {
   Triggers the update of lines, drop lines, symbols etc.
 */
 void XYCurvePrivate::retransform() {
+	DEBUG("XYCurvePrivate::retransform()");
 	if (m_suppressRetransform)
 		return;
 
@@ -860,7 +888,7 @@ void XYCurvePrivate::retransform() {
 			symbolPointsLogical.append(tempPoint);
 			connectedPointsLogical.push_back(true);
 		} else {
-			if (connectedPointsLogical.size())
+			if (!connectedPointsLogical.empty())
 				connectedPointsLogical[connectedPointsLogical.size()-1] = false;
 		}
 	}
@@ -897,15 +925,13 @@ void XYCurvePrivate::updateLines() {
 		return;
 	}
 
-	const int count=symbolPointsLogical.count();
-#ifndef NDEBUG
-//	qDebug()<<"count ="<<count<<", line type ="<<lineType;
+	const int count = symbolPointsLogical.count();
+//	DEBUG("count ="<<count<<", line type ="<<lineType);
 //	for(int i=0;i<qMin(10,count);i++)
-//		qDebug()<<symbolPointsLogical.at(i);
-#endif
+//		DEBUG(symbolPointsLogical.at(i));
 
 	//nothing to do, if no data points available
-	if (count<=1) {
+	if (count <= 1) {
 		recalcShapeAndBoundingRect();
 		return;
 	}
@@ -917,50 +943,50 @@ void XYCurvePrivate::updateLines() {
 	case XYCurve::NoLine:
 		break;
 	case XYCurve::Line:
-		for (int i=0; i<count-1; i++) {
+		for (int i = 0; i < count - 1; i++) {
 			if (!lineSkipGaps && !connectedPointsLogical[i]) continue;
 			lines.append(QLineF(symbolPointsLogical.at(i), symbolPointsLogical.at(i+1)));
 		}
 		break;
 	case XYCurve::StartHorizontal:
-		for (int i=0; i<count-1; i++) {
+		for (int i = 0; i < count - 1; i++) {
 			if (!lineSkipGaps && !connectedPointsLogical[i]) continue;
-			curPoint=symbolPointsLogical.at(i);
-			nextPoint=symbolPointsLogical.at(i+1);
-			tempPoint1=QPointF(nextPoint.x(), curPoint.y());
+			curPoint = symbolPointsLogical.at(i);
+			nextPoint = symbolPointsLogical.at(i+1);
+			tempPoint1 = QPointF(nextPoint.x(), curPoint.y());
 			lines.append(QLineF(curPoint, tempPoint1));
 			lines.append(QLineF(tempPoint1, nextPoint));
 		}
 		break;
 	case XYCurve::StartVertical:
-		for (int i=0; i<count-1; i++) {
+		for (int i = 0; i < count - 1; i++) {
 			if (!lineSkipGaps && !connectedPointsLogical[i]) continue;
-			curPoint=symbolPointsLogical.at(i);
-			nextPoint=symbolPointsLogical.at(i+1);
-			tempPoint1=QPointF(curPoint.x(), nextPoint.y());
+			curPoint = symbolPointsLogical.at(i);
+			nextPoint = symbolPointsLogical.at(i+1);
+			tempPoint1 = QPointF(curPoint.x(), nextPoint.y());
 			lines.append(QLineF(curPoint, tempPoint1));
 			lines.append(QLineF(tempPoint1,nextPoint));
 		}
 		break;
 	case XYCurve::MidpointHorizontal:
-		for (int i=0; i<count-1; i++) {
+		for (int i = 0; i < count - 1; i++) {
 			if (!lineSkipGaps && !connectedPointsLogical[i]) continue;
-			curPoint=symbolPointsLogical.at(i);
-			nextPoint=symbolPointsLogical.at(i+1);
-			tempPoint1=QPointF(curPoint.x() + (nextPoint.x()-curPoint.x())/2, curPoint.y());
-			tempPoint2=QPointF(curPoint.x() + (nextPoint.x()-curPoint.x())/2, nextPoint.y());
+			curPoint = symbolPointsLogical.at(i);
+			nextPoint = symbolPointsLogical.at(i+1);
+			tempPoint1 = QPointF(curPoint.x() + (nextPoint.x()-curPoint.x())/2, curPoint.y());
+			tempPoint2 = QPointF(curPoint.x() + (nextPoint.x()-curPoint.x())/2, nextPoint.y());
 			lines.append(QLineF(curPoint, tempPoint1));
 			lines.append(QLineF(tempPoint1, tempPoint2));
 			lines.append(QLineF(tempPoint2, nextPoint));
 		}
 		break;
 	case XYCurve::MidpointVertical:
-		for (int i=0; i<count-1; i++) {
+		for (int i = 0; i < count - 1; i++) {
 			if (!lineSkipGaps && !connectedPointsLogical[i]) continue;
-			curPoint=symbolPointsLogical.at(i);
-			nextPoint=symbolPointsLogical.at(i+1);
-			tempPoint1=QPointF(curPoint.x(), curPoint.y() + (nextPoint.y()-curPoint.y())/2);
-			tempPoint2=QPointF(nextPoint.x(), curPoint.y() + (nextPoint.y()-curPoint.y())/2);
+			curPoint = symbolPointsLogical.at(i);
+			nextPoint = symbolPointsLogical.at(i+1);
+			tempPoint1 = QPointF(curPoint.x(), curPoint.y() + (nextPoint.y()-curPoint.y())/2);
+			tempPoint2 = QPointF(nextPoint.x(), curPoint.y() + (nextPoint.y()-curPoint.y())/2);
 			lines.append(QLineF(curPoint, tempPoint1));
 			lines.append(QLineF(tempPoint1, tempPoint2));
 			lines.append(QLineF(tempPoint2, nextPoint));
@@ -968,32 +994,32 @@ void XYCurvePrivate::updateLines() {
 		break;
 	case XYCurve::Segments2: {
 		int skip=0;
-		for (int i=0; i<count-1; i++) {
-			if (skip!=1) {
+		for (int i = 0; i < count - 1; i++) {
+			if (skip != 1) {
 				if (!lineSkipGaps && !connectedPointsLogical[i]) {
-					skip=0;
+					skip = 0;
 					continue;
 				}
 				lines.append(QLineF(symbolPointsLogical.at(i), symbolPointsLogical.at(i+1)));
 				skip++;
 			} else {
-				skip=0;
+				skip = 0;
 			}
 		}
 		break;
 	}
 	case XYCurve::Segments3: {
-		int skip=0;
-		for (int i=0; i<count-1; i++) {
-			if (skip!=2) {
+		int skip = 0;
+		for (int i = 0; i < count - 1; i++) {
+			if (skip != 2) {
 				if (!lineSkipGaps && !connectedPointsLogical[i]) {
-					skip=0;
+					skip = 0;
 					continue;
 				}
 				lines.append(QLineF(symbolPointsLogical.at(i), symbolPointsLogical.at(i+1)));
 				skip++;
 			} else {
-				skip=0;
+				skip = 0;
 			}
 		}
 		break;
@@ -1004,35 +1030,34 @@ void XYCurvePrivate::updateLines() {
 	case XYCurve::SplineAkimaPeriodic: {
 		//TODO: optimize! try to omit the copying from the column to the arrays of doubles.
 		//TODO: forward the error message to the UI.
-		gsl_interp_accel *acc  = gsl_interp_accel_alloc();
-		gsl_spline *spline=0;
+		gsl_interp_accel *acc = gsl_interp_accel_alloc();
+		gsl_spline *spline = 0;
 
 		double x[count],  y[count];
-		for (int i=0; i<count; i++) {
-			x[i]=symbolPointsLogical.at(i).x();
-			y[i]=symbolPointsLogical.at(i).y();
+		for (int i = 0; i < count; i++) {
+			x[i] = symbolPointsLogical.at(i).x();
+			y[i] = symbolPointsLogical.at(i).y();
 		}
 
 		gsl_set_error_handler_off();
-		if (lineType==XYCurve::SplineCubicNatural) {
+		if (lineType == XYCurve::SplineCubicNatural) {
 			spline = gsl_spline_alloc(gsl_interp_cspline, count);
-		} else if (lineType==XYCurve::SplineCubicPeriodic) {
+		} else if (lineType == XYCurve::SplineCubicPeriodic) {
 			spline = gsl_spline_alloc(gsl_interp_cspline_periodic, count);
-		} else if (lineType==XYCurve::SplineAkimaNatural) {
+		} else if (lineType == XYCurve::SplineAkimaNatural) {
 			spline = gsl_spline_alloc(gsl_interp_akima, count);
-		} else if (lineType==XYCurve::SplineAkimaPeriodic) {
+		} else if (lineType == XYCurve::SplineAkimaPeriodic) {
 			spline = gsl_spline_alloc(gsl_interp_akima_periodic, count);
 		}
 
 		if (!spline) {
 			QString msg;
-			if ( (lineType==XYCurve::SplineAkimaNatural || lineType==XYCurve::SplineAkimaPeriodic) && count<5)
-				msg=i18n("Error: Akima spline interpolation requires a minimum of 5 points.");
+			if ( (lineType == XYCurve::SplineAkimaNatural || lineType == XYCurve::SplineAkimaPeriodic) && count < 5)
+				msg = i18n("Error: Akima spline interpolation requires a minimum of 5 points.");
 			else
-				msg =i18n("Couldn't initialize spline function");
-#ifndef NDEBUG
-			qDebug()<<msg;
-#endif
+				msg = i18n("Couldn't initialize spline function");
+			QDEBUG(msg);
+
 			recalcShapeAndBoundingRect();
 			return;
 		}
@@ -1045,9 +1070,8 @@ void XYCurvePrivate::updateLines() {
 				gslError = "x values must be monotonically increasing.";
 			else
 				gslError = gsl_strerror (status);
-#ifndef NDEBUG
-			qDebug() << "Error in spline calculation. " << gslError;
-#endif
+			QDEBUG("Error in spline calculation. " << gslError);
+
 			recalcShapeAndBoundingRect();
 			return;
 		}
@@ -1056,19 +1080,19 @@ void XYCurvePrivate::updateLines() {
 		std::vector<double> xinterp, yinterp;
 		double step;
 		double xi, yi, x1, x2;
-		for (int i=0; i<count-1; i++) {
+		for (int i = 0; i < count - 1; i++) {
 			x1 = x[i];
 			x2 = x[i+1];
-			step=fabs(x2-x1)/(lineInterpolationPointsCount+1);
+			step=fabs(x2 - x1)/(lineInterpolationPointsCount + 1);
 
-			for (xi=x1; xi<x2; xi += step) {
-				yi = gsl_spline_eval (spline, xi, acc);
+			for (xi = x1; xi < x2; xi += step) {
+				yi = gsl_spline_eval(spline, xi, acc);
 				xinterp.push_back(xi);
 				yinterp.push_back(yi);
 			}
 		}
 
-		for (unsigned int i=0; i<xinterp.size()-1; i++) {
+		for (unsigned int i = 0; i < xinterp.size() - 1; i++) {
 			lines.append(QLineF(xinterp[i], yinterp[i], xinterp[i+1], yinterp[i+1]));
 		}
 		lines.append(QLineF(xinterp[xinterp.size()-1], yinterp[yinterp.size()-1], x[count-1], y[count-1]));
@@ -1341,7 +1365,7 @@ void XYCurvePrivate::updateFilling() {
 
 	//if there're no interpolation lines available (XYCurve::NoLine selected), create line-interpolation,
 	//use already available lines otherwise.
-	if (lines.size()) {
+	if (!lines.isEmpty()) {
 		fillLines = lines;
 	} else {
 		for (int i=0; i<symbolPointsLogical.count()-1; i++) {
@@ -1349,11 +1373,11 @@ void XYCurvePrivate::updateFilling() {
 			fillLines.append(QLineF(symbolPointsLogical.at(i), symbolPointsLogical.at(i+1)));
 		}
 		fillLines = cSystem->mapLogicalToScene(fillLines);
-	}
 
-	//no lines available (no points), nothing to do
-	if (!fillLines.size())
-		return;
+		//no lines available (no points), nothing to do
+		if (fillLines.isEmpty())
+			return;
+	}
 
 	//create polygon(s):
 	//1. Depending on the current zoom-level, only a subset of the curve may be visible in the plot
@@ -1649,14 +1673,14 @@ void XYCurvePrivate::updateErrorBars() {
 		}
 
 		//error bars for y
-		if (yErrorType!=XYCurve::NoError) {
+		if (yErrorType != XYCurve::NoError) {
 			//determine the values for the errors
 			if (yErrorPlusColumn && yErrorPlusColumn->isValid(i) && !yErrorPlusColumn->isMasked(i))
 				errorPlus = yErrorPlusColumn->valueAt(i);
 			else
 				errorPlus = 0;
 
-			if (yErrorType==XYCurve::SymmetricError) {
+			if (yErrorType == XYCurve::SymmetricError) {
 				errorMinus = errorPlus;
 			} else {
 				if (yErrorMinusColumn && yErrorMinusColumn->isValid(i) && !yErrorMinusColumn->isMasked(i) )
@@ -1674,10 +1698,10 @@ void XYCurvePrivate::updateErrorBars() {
 			case XYCurve::ErrorBarsWithEnds:
 				lines.append(QLineF(QPointF(point.x(), point.y()-errorMinus),
 						QPointF(point.x(), point.y()+errorPlus)));
-				if (errorMinus!=0)
+				if (errorMinus != 0)
 					lines.append(QLineF(QPointF(point.x()-capSizeY, point.y()-errorMinus),
 							QPointF(point.x()+capSizeY, point.y()-errorMinus)));
-				if (errorPlus!=0)
+				if (errorPlus != 0)
 					lines.append(QLineF(QPointF(point.x()-capSizeY, point.y()+errorPlus),
 							QPointF(point.x()+capSizeY, point.y()+errorPlus)));
 				break;
@@ -1701,6 +1725,7 @@ void XYCurvePrivate::updateErrorBars() {
   recalculates the outer bounds and the shape of the curve.
 */
 void XYCurvePrivate::recalcShapeAndBoundingRect() {
+	DEBUG("XYCurvePrivate::recalcShapeAndBoundingRect()");
 	if (m_suppressRecalc)
 		return;
 
@@ -1728,7 +1753,7 @@ void XYCurvePrivate::recalcShapeAndBoundingRect() {
 
 	boundingRectangle = curveShape.boundingRect();
 
-	foreach(const QPolygonF& pol, fillPolygons)
+	foreach (const QPolygonF& pol, fillPolygons)
 		boundingRectangle = boundingRectangle.united(pol.boundingRect());
 
 	//TODO: when the selection is painted, line intersections are visible.
@@ -1740,6 +1765,8 @@ void XYCurvePrivate::recalcShapeAndBoundingRect() {
 }
 
 void XYCurvePrivate::draw(QPainter *painter) {
+	DEBUG("XYCurvePrivate::draw()");
+
 	//draw filling
 	if (fillingPosition != XYCurve::NoFilling) {
 		painter->setOpacity(fillingOpacity);
@@ -1782,25 +1809,29 @@ void XYCurvePrivate::draw(QPainter *painter) {
 	//draw values
 	if (valuesType != XYCurve::NoValues) {
 		painter->setOpacity(valuesOpacity);
-		painter->setPen(valuesColor);
-		painter->setBrush(Qt::SolidPattern);
+		//don't use any painter pen, since this will force QPainter to render the text outline which is expensive
+		painter->setPen(Qt::NoPen);
+		painter->setBrush(valuesColor);
 		drawValues(painter);
 	}
+
+	DEBUG("XYCurvePrivate::draw() DONE");
 }
 
 void XYCurvePrivate::updatePixmap() {
+	DEBUG("XYCurvePrivate::updatePixmap()");
 	WAIT_CURSOR;
-	QApplication::processEvents(QEventLoop::AllEvents, 0);
+
 // 	QTime timer;
 // 	timer.start();
 	m_hoverEffectImageIsDirty = true;
 	m_selectionEffectImageIsDirty = true;
-	QPixmap pixmap(boundingRectangle.width(), boundingRectangle.height());
-	if (boundingRectangle.width()==0 || boundingRectangle.width()==0) {
-		m_pixmap = pixmap;
+	if (boundingRectangle.width() == 0 || boundingRectangle.width() == 0) {
+		m_pixmap = QPixmap();
 		RESET_CURSOR;
 		return;
 	}
+	QPixmap pixmap(ceil(boundingRectangle.width()), ceil(boundingRectangle.height()));
 	pixmap.fill(Qt::transparent);
 	QPainter painter(&pixmap);
 	painter.setRenderHint(QPainter::Antialiasing, true);
@@ -1808,10 +1839,14 @@ void XYCurvePrivate::updatePixmap() {
 
 	draw(&painter);
 	painter.end();
-
 	m_pixmap = pixmap;
+
+	//QApplication::processEvents(QEventLoop::AllEvents, 0);
+
 // 	qDebug() << "Update the pixmap: " << timer.elapsed() << "ms";
+	update();
 	RESET_CURSOR;
+	DEBUG("XYCurvePrivate::updatePixmap() DONE");
 }
 
 //TODO: move this to a central place
@@ -1833,7 +1868,7 @@ QImage blurred(const QImage& image, const QRect& rect, int radius, bool alphaOnl
 	int i2 = 3;
 
 	if (alphaOnly)
-		i1 = i2 = (QSysInfo::ByteOrder == QSysInfo::BigEndian ? 0 : 3);
+		i1 = i2 = (QSysInfo::ByteOrder == QSysInfo::LittleEndian)*3;
 
 	for (int col = c1; col <= c2; col++) {
 		p = result.scanLine(r1) + col * 4;
@@ -1887,7 +1922,8 @@ QImage blurred(const QImage& image, const QRect& rect, int radius, bool alphaOnl
   \sa QGraphicsItem::paint().
 */
 void XYCurvePrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget) {
-// 	qDebug()<<"XYCurvePrivate::paint, " + q->name();
+	QDEBUG("XYCurvePrivate::paint() name =" << q->name());
+
 	Q_UNUSED(option);
 	Q_UNUSED(widget);
 	if (!isVisible())
@@ -1899,7 +1935,8 @@ void XYCurvePrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem* op
 	painter->setBrush(Qt::NoBrush);
 	painter->setRenderHint(QPainter::SmoothPixmapTransform, true);
 
-	if ( KGlobal::config()->group("General").readEntry<bool>("DoubleBuffering", true) )
+ 	DEBUG("XYCurvePrivate::paint() calling drawPixmap() or draw() 		XXXXXXXXXXXXXXXXXXXX");
+	if ( KGlobal::config()->group("Settings_Worksheet").readEntry(QLatin1String("DoubleBuffering"), true) )
 		painter->drawPixmap(boundingRectangle.topLeft(), m_pixmap); //draw the cached pixmap (fast)
 	else
 		draw(painter); //draw directly again (slow)
@@ -1940,8 +1977,7 @@ void XYCurvePrivate::paint(QPainter* painter, const QStyleOptionGraphicsItem* op
 }
 
 /*!
-	Drawing of symbolsPath is very slow, so we draw every symbol in the loop
-	which us much faster (factor 10)
+	Drawing of symbolsPath is very slow, so we draw every symbol in the loop which is much faster (factor 10)
 */
 void XYCurvePrivate::drawSymbols(QPainter* painter) {
 	QPainterPath path = Symbol::pathFromStyle(symbolsStyle);
@@ -1978,7 +2014,7 @@ void XYCurvePrivate::drawValues(QPainter* painter) {
 }
 
 void XYCurvePrivate::drawFilling(QPainter* painter) {
-	foreach(const QPolygonF& pol, fillPolygons) {
+	foreach (const QPolygonF& pol, fillPolygons) {
 		QRectF rect = pol.boundingRect();
 		if (fillingType == PlotArea::Color) {
 			switch (fillingColorStyle) {
@@ -2027,28 +2063,28 @@ void XYCurvePrivate::drawFilling(QPainter* painter) {
 				QPixmap pix(fillingFileName);
 				switch (fillingImageStyle) {
 				case PlotArea::ScaledCropped:
-					pix = pix.scaled(rect.size().toSize(),Qt::KeepAspectRatioByExpanding,Qt::SmoothTransformation);
+					pix = pix.scaled(rect.size().toSize(), Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation);
 					painter->setBrush(QBrush(pix));
-					painter->setBrushOrigin(pix.size().width()/2,pix.size().height()/2);
+					painter->setBrushOrigin(pix.size().width()/2, pix.size().height()/2);
 					break;
 				case PlotArea::Scaled:
-					pix = pix.scaled(rect.size().toSize(),Qt::IgnoreAspectRatio,Qt::SmoothTransformation);
+					pix = pix.scaled(rect.size().toSize(), Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
 					painter->setBrush(QBrush(pix));
-					painter->setBrushOrigin(pix.size().width()/2,pix.size().height()/2);
+					painter->setBrushOrigin(pix.size().width()/2, pix.size().height()/2);
 					break;
 				case PlotArea::ScaledAspectRatio:
-					pix = pix.scaled(rect.size().toSize(),Qt::KeepAspectRatio,Qt::SmoothTransformation);
+					pix = pix.scaled(rect.size().toSize(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
 					painter->setBrush(QBrush(pix));
-					painter->setBrushOrigin(pix.size().width()/2,pix.size().height()/2);
+					painter->setBrushOrigin(pix.size().width()/2, pix.size().height()/2);
 					break;
 				case PlotArea::Centered: {
 					QPixmap backpix(rect.size().toSize());
 					backpix.fill();
 					QPainter p(&backpix);
-					p.drawPixmap(QPointF(0,0),pix);
+					p.drawPixmap(QPointF(0, 0), pix);
 					p.end();
 					painter->setBrush(QBrush(backpix));
-					painter->setBrushOrigin(-pix.size().width()/2,-pix.size().height()/2);
+					painter->setBrushOrigin(-pix.size().width()/2, -pix.size().height()/2);
 					break;
 				}
 				case PlotArea::Tiled:
@@ -2056,11 +2092,11 @@ void XYCurvePrivate::drawFilling(QPainter* painter) {
 					break;
 				case PlotArea::CenterTiled:
 					painter->setBrush(QBrush(pix));
-					painter->setBrushOrigin(pix.size().width()/2,pix.size().height()/2);
+					painter->setBrushOrigin(pix.size().width()/2, pix.size().height()/2);
 				}
 			}
 		} else if (fillingType == PlotArea::Pattern) {
-			painter->setBrush(QBrush(fillingFirstColor,fillingBrushStyle));
+			painter->setBrush(QBrush(fillingFirstColor, fillingBrushStyle));
 		}
 
 		painter->drawPolygon(pol);
@@ -2218,110 +2254,38 @@ bool XYCurve::load(XmlStreamReader* reader) {
 		} else if (reader->name() == "lines") {
 			attribs = reader->attributes();
 
-			str = attribs.value("type").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'type'"));
-			else
-				d->lineType = (XYCurve::LineType)str.toInt();
-
-			str = attribs.value("skipGaps").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'skipGps'"));
-			else
-				d->lineSkipGaps = str.toInt();
-
-			str = attribs.value("interpolationPointsCount").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'interpolationPointsCount'"));
-			else
-				d->lineInterpolationPointsCount = str.toInt();
-
+			READ_INT_VALUE("type", lineType, XYCurve::LineType);
+			READ_INT_VALUE("skipGaps", lineSkipGaps, int);
+			READ_INT_VALUE("interpolationPointsCount", lineInterpolationPointsCount, int);
 			READ_QPEN(d->linePen);
-
-			str = attribs.value("opacity").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'opacity'"));
-			else
-				d->lineOpacity = str.toDouble();
+			READ_DOUBLE_VALUE("opacity", lineOpacity);
 		} else if (reader->name() == "dropLines") {
 			attribs = reader->attributes();
 
-			str = attribs.value("type").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'type'"));
-			else
-				d->dropLineType = (XYCurve::DropLineType)str.toInt();
-
+			READ_INT_VALUE("type", dropLineType, XYCurve::DropLineType);
 			READ_QPEN(d->dropLinePen);
+			READ_DOUBLE_VALUE("opacity", dropLineOpacity);
 
-			str = attribs.value("opacity").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'opacity'"));
-			else
-				d->dropLineOpacity = str.toDouble();
 		} else if (reader->name() == "symbols") {
 			attribs = reader->attributes();
 
-			str = attribs.value("symbolsStyle").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'symbolsStyle'"));
-			else
-				d->symbolsStyle = (Symbol::Style)str.toInt();
-
-			str = attribs.value("opacity").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'opacity'"));
-			else
-				d->symbolsOpacity = str.toDouble();
-
-			str = attribs.value("rotation").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'rotation'"));
-			else
-				d->symbolsRotationAngle = str.toDouble();
-
-			str = attribs.value("size").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'size'"));
-			else
-				d->symbolsSize = str.toDouble();
+			READ_INT_VALUE("symbolsStyle", symbolsStyle, Symbol::Style);
+			READ_DOUBLE_VALUE("opacity", symbolsOpacity);
+			READ_DOUBLE_VALUE("rotation", symbolsRotationAngle);
+			READ_DOUBLE_VALUE("size", symbolsSize);
 
 			READ_QBRUSH(d->symbolsBrush);
 			READ_QPEN(d->symbolsPen);
 		} else if (reader->name() == "values") {
 			attribs = reader->attributes();
 
-			str = attribs.value("type").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'type'"));
-			else
-				d->valuesType = (XYCurve::ValuesType)str.toInt();
-
+			READ_INT_VALUE("type", valuesType, XYCurve::ValuesType);
 			READ_COLUMN(valuesColumn);
 
-			str = attribs.value("position").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'position'"));
-			else
-				d->valuesPosition = (XYCurve::ValuesPosition)str.toInt();
-
-			str = attribs.value("distance").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'distance'"));
-			else
-				d->valuesDistance = str.toDouble();
-
-			str = attribs.value("rotation").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'rotation'"));
-			else
-				d->valuesRotationAngle = str.toDouble();
-
-			str = attribs.value("opacity").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'opacity'"));
-			else
-				d->valuesOpacity = str.toDouble();
+			READ_INT_VALUE("position", valuesPosition, XYCurve::ValuesPosition);
+			READ_DOUBLE_VALUE("distance", valuesDistance);
+			READ_DOUBLE_VALUE("rotation", valuesRotationAngle);
+			READ_DOUBLE_VALUE("opacity", valuesOpacity);
 
 			//don't produce any warning if no prefix or suffix is set (empty string is allowd here in xml)
 			d->valuesPrefix = attribs.value("prefix").toString();
@@ -2329,44 +2293,14 @@ bool XYCurve::load(XmlStreamReader* reader) {
 
 			READ_QCOLOR(d->valuesColor);
 			READ_QFONT(d->valuesFont);
-
-			str = attribs.value("opacity").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'opacity'"));
-			else
-				d->valuesOpacity = str.toDouble();
 		} else if (reader->name() == "filling") {
 			attribs = reader->attributes();
 
-			str = attribs.value("position").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("position"));
-			else
-				d->fillingPosition = XYCurve::FillingPosition(str.toInt());
-
-			str = attribs.value("type").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("type"));
-			else
-				d->fillingType = PlotArea::BackgroundType(str.toInt());
-
-			str = attribs.value("colorStyle").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("colorStyle"));
-			else
-				d->fillingColorStyle = PlotArea::BackgroundColorStyle(str.toInt());
-
-			str = attribs.value("imageStyle").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("imageStyle"));
-			else
-				d->fillingImageStyle = PlotArea::BackgroundImageStyle(str.toInt());
-
-			str = attribs.value("brushStyle").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("brushStyle"));
-			else
-				d->fillingBrushStyle = Qt::BrushStyle(str.toInt());
+			READ_INT_VALUE("position", fillingPosition, XYCurve::FillingPosition);
+			READ_INT_VALUE("type", fillingType, PlotArea::BackgroundType);
+			READ_INT_VALUE("colorStyle", fillingColorStyle, PlotArea::BackgroundColorStyle);
+			READ_INT_VALUE("imageStyle", fillingImageStyle, PlotArea::BackgroundImageStyle );
+			READ_INT_VALUE("brushStyle", fillingBrushStyle, Qt::BrushStyle);
 
 			str = attribs.value("firstColor_r").toString();
 			if (str.isEmpty())
@@ -2404,56 +2338,137 @@ bool XYCurve::load(XmlStreamReader* reader) {
 			else
 				d->fillingSecondColor.setBlue(str.toInt());
 
-			str = attribs.value("fileName").toString();
-			d->fillingFileName = str;
-
-			str = attribs.value("opacity").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("opacity"));
-			else
-				d->fillingOpacity = str.toDouble();
+			READ_STRING_VALUE("fileName", fillingFileName);
+			READ_DOUBLE_VALUE("opacity", fillingOpacity);
 		} else if (reader->name() == "errorBars") {
 			attribs = reader->attributes();
 
-			str = attribs.value("xErrorType").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'xErrorType'"));
-			else
-				d->xErrorType = (XYCurve::ErrorType)str.toInt();
-
+			READ_INT_VALUE("xErrorType", xErrorType, XYCurve::ErrorType);
 			READ_COLUMN(xErrorPlusColumn);
 			READ_COLUMN(xErrorMinusColumn);
 
-			str = attribs.value("yErrorType").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'yErrorType'"));
-			else
-				d->yErrorType = (XYCurve::ErrorType)str.toInt();
-
+			READ_INT_VALUE("yErrorType", yErrorType, XYCurve::ErrorType);
 			READ_COLUMN(yErrorPlusColumn);
 			READ_COLUMN(yErrorMinusColumn);
 
-			str = attribs.value("type").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'type'"));
-			else
-				d->errorBarsType = (XYCurve::ErrorBarsType)str.toInt();
-
-			str = attribs.value("capSize").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'capSize'"));
-			else
-				d->errorBarsCapSize = str.toDouble();
+			READ_INT_VALUE("type", errorBarsType, XYCurve::ErrorBarsType);
+			READ_DOUBLE_VALUE("capSize", errorBarsCapSize);
 
 			READ_QPEN(d->errorBarsPen);
 
-			str = attribs.value("opacity").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'opacity'"));
-			else
-				d->errorBarsOpacity = str.toDouble();
+			READ_DOUBLE_VALUE("opacity", errorBarsOpacity);
 		}
 	}
 
 	return true;
 }
+
+//##############################################################################
+//#########################  Theme management ##################################
+//##############################################################################
+void XYCurve::loadThemeConfig(const KConfig& config) {
+	KConfigGroup group = config.group("XYCurve");
+
+	int index = parentAspect()->indexOfChild<XYCurve>(this);
+	const CartesianPlot* plot = dynamic_cast<const CartesianPlot*>(parentAspect());
+	QColor themeColor;
+	if (index<plot->themeColorPalette().size()) {
+		themeColor = plot->themeColorPalette().at(index);
+	} else {
+		if (plot->themeColorPalette().size())
+			themeColor = plot->themeColorPalette().last();
+	}
+
+	QPen p;
+
+	//Line
+	p.setStyle((Qt::PenStyle)group.readEntry("LineStyle", (int)this->linePen().style()));
+	p.setWidthF(group.readEntry("LineWidth", this->linePen().widthF()));
+	p.setColor(themeColor);
+	this->setLinePen(p);
+	this->setLineOpacity(group.readEntry("LineOpacity", this->lineOpacity()));
+
+	//Drop line
+	p.setStyle((Qt::PenStyle)group.readEntry("DropLineStyle",(int) this->dropLinePen().style()));
+	p.setWidthF(group.readEntry("DropLineWidth", this->dropLinePen().widthF()));
+	p.setColor(themeColor);
+	this->setDropLinePen(p);
+	this->setDropLineOpacity(group.readEntry("DropLineOpacity", this->dropLineOpacity()));
+
+	//Symbol
+	this->setSymbolsOpacity(group.readEntry("SymbolOpacity", this->symbolsOpacity()));
+	QBrush brush = symbolsBrush();
+	brush.setColor(themeColor);
+	this->setSymbolsBrush(brush);
+	p = symbolsPen();
+	p.setColor(themeColor);
+	this->setSymbolsPen(p);
+
+	//Values
+	this->setValuesOpacity(group.readEntry("ValuesOpacity", this->valuesOpacity()));
+	this->setValuesColor(group.readEntry("ValuesColor", this->valuesColor()));
+	this->setValuesFont(group.readEntry("ValuesFont", QFont()));
+
+	//Filling
+	this->setFillingBrushStyle((Qt::BrushStyle)group.readEntry("FillingBrushStyle",(int) this->fillingBrushStyle()));
+	this->setFillingColorStyle((PlotArea::BackgroundColorStyle)group.readEntry("FillingColorStyle",(int) this->fillingColorStyle()));
+	this->setFillingOpacity(group.readEntry("FillingOpacity", this->fillingOpacity()));
+	this->setFillingPosition((XYCurve::FillingPosition)group.readEntry("FillingPosition",(int) this->fillingPosition()));
+	this->setFillingSecondColor(group.readEntry("FillingSecondColor",(QColor) this->fillingSecondColor()));
+	this->setFillingFirstColor(themeColor);
+	this->setFillingType((PlotArea::BackgroundType)group.readEntry("FillingType",(int) this->fillingType()));
+
+	//Error Bars
+	p.setStyle((Qt::PenStyle)group.readEntry("ErrorBarsStyle",(int) this->errorBarsPen().style()));
+	p.setWidthF(group.readEntry("ErrorBarsWidth", this->errorBarsPen().widthF()));
+	p.setColor(themeColor);
+	this->setErrorBarsPen(p);
+	this->setErrorBarsOpacity(group.readEntry("ErrorBarsOpacity",this->errorBarsOpacity()));
+}
+
+void XYCurve::saveThemeConfig(const KConfig& config) {
+	KConfigGroup group = config.group("XYCurve");
+
+	//Drop line
+	group.writeEntry("DropLineColor",(QColor) this->dropLinePen().color());
+	group.writeEntry("DropLineStyle",(int) this->dropLinePen().style());
+	group.writeEntry("DropLineWidth", this->dropLinePen().widthF());
+	group.writeEntry("DropLineOpacity",this->dropLineOpacity());
+
+	//Error Bars
+	group.writeEntry("ErrorBarsCapSize",this->errorBarsCapSize());
+	group.writeEntry("ErrorBarsOpacity",this->errorBarsOpacity());
+	group.writeEntry("ErrorBarsColor",(QColor) this->errorBarsPen().color());
+	group.writeEntry("ErrorBarsStyle",(int) this->errorBarsPen().style());
+	group.writeEntry("ErrorBarsWidth", this->errorBarsPen().widthF());
+
+	//Filling
+	group.writeEntry("FillingBrushStyle",(int) this->fillingBrushStyle());
+	group.writeEntry("FillingColorStyle",(int) this->fillingColorStyle());
+	group.writeEntry("FillingOpacity", this->fillingOpacity());
+	group.writeEntry("FillingPosition",(int) this->fillingPosition());
+	group.writeEntry("FillingSecondColor",(QColor) this->fillingSecondColor());
+	group.writeEntry("FillingType",(int) this->fillingType());
+
+	//Line
+	group.writeEntry("LineOpacity", this->lineOpacity());
+	group.writeEntry("LineStyle",(int) this->linePen().style());
+	group.writeEntry("LineWidth", this->linePen().widthF());
+
+	//Symbol
+	group.writeEntry("SymbolOpacity", this->symbolsOpacity());
+
+	//Values
+	group.writeEntry("ValuesOpacity", this->valuesOpacity());
+	group.writeEntry("ValuesColor", (QColor) this->valuesColor());
+	group.writeEntry("ValuesFont", this->valuesFont());
+
+	int index = parentAspect()->indexOfChild<XYCurve>(this);
+	if(index<5) {
+		KConfigGroup themeGroup = config.group("Theme");
+		for(int i = index; i<5; i++) {
+			QString s = "ThemePaletteColor" + QString::number(i+1);
+			themeGroup.writeEntry(s,(QColor) this->linePen().color());
+		}
+	}
+}
