@@ -38,6 +38,7 @@
 #include "backend/core/AbstractColumn.h"
 #include "backend/core/column/Column.h"
 #include "backend/lib/commandtemplates.h"
+#include "backend/lib/macros.h"
 
 #include <cmath>	// isnan
 extern "C" {
@@ -54,9 +55,6 @@ extern "C" {
 #include <KLocale>
 #include <QElapsedTimer>
 #include <QThreadPool>
-#ifndef NDEBUG
-#include <QDebug>
-#endif
 
 XYFourierFilterCurve::XYFourierFilterCurve(const QString& name)
 		: XYCurve(name, new XYFourierFilterCurvePrivate(this)) {
@@ -224,17 +222,22 @@ void XYFourierFilterCurvePrivate::recalculate() {
 	//copy all valid data point for the filter to temporary vectors
 	QVector<double> xdataVector;
 	QVector<double> ydataVector;
+	const double xmin = filterData.xRange.first();
+	const double xmax = filterData.xRange.last();
 	for (int row=0; row<xDataColumn->rowCount(); ++row) {
 		//only copy those data where _all_ values (for x and y, if given) are valid
 		if (!std::isnan(xDataColumn->valueAt(row)) && !std::isnan(yDataColumn->valueAt(row))
 				&& !xDataColumn->isMasked(row) && !yDataColumn->isMasked(row)) {
-			xdataVector.append(xDataColumn->valueAt(row));
-			ydataVector.append(yDataColumn->valueAt(row));
+			// only when inside given range
+			if (xDataColumn->valueAt(row) >= xmin && xDataColumn->valueAt(row) <= xmax) {
+				xdataVector.append(xDataColumn->valueAt(row));
+				ydataVector.append(yDataColumn->valueAt(row));
+			}
 		}
 	}
 
 	//number of data points to filter
-	unsigned int n = ydataVector.size();
+	unsigned int n = xdataVector.size();
 	if (n == 0) {
 		filterResult.available = true;
 		filterResult.valid = false;
@@ -247,8 +250,6 @@ void XYFourierFilterCurvePrivate::recalculate() {
 	//double* xdata = xdataVector.data();
 	double* ydata = ydataVector.data();
 
-	const double min = xDataColumn->minimum();
-	const double max = xDataColumn->maximum();
 
 	// filter settings
 	const nsl_filter_type type = filterData.type;
@@ -256,19 +257,19 @@ void XYFourierFilterCurvePrivate::recalculate() {
 	const unsigned int order = filterData.order;
 	const double cutoff = filterData.cutoff, cutoff2 = filterData.cutoff2;
 	const nsl_filter_cutoff_unit unit = filterData.unit, unit2 = filterData.unit2;
-#ifndef NDEBUG
-	qDebug()<<"n ="<<n;
-	qDebug()<<"type:"<<nsl_filter_type_name[type];
-	qDebug()<<"form (order "<<order<<") :"<<nsl_filter_form_name[form];
-	qDebug()<<"cutoffs ="<<cutoff<<cutoff2;
-	qDebug()<<"unit :"<<nsl_filter_cutoff_unit_name[unit]<<nsl_filter_cutoff_unit_name[unit2];
-#endif
+
+	DEBUG("n ="<<n);
+	DEBUG("type:"<<nsl_filter_type_name[type]);
+	DEBUG("form (order "<<order<<") :"<<nsl_filter_form_name[form]);
+	DEBUG("cutoffs ="<<cutoff<<cutoff2);
+	DEBUG("unit :"<<nsl_filter_cutoff_unit_name[unit]<<nsl_filter_cutoff_unit_name[unit2]);
+
 ///////////////////////////////////////////////////////////
 	// calculate index
 	double cutindex=0, cutindex2=0;
 	switch (unit) {
 	case nsl_filter_cutoff_unit_frequency:
-		cutindex = cutoff*(max-min);
+		cutindex = cutoff*(xmax-xmin);
 		break;
 	case nsl_filter_cutoff_unit_fraction:
 		cutindex = cutoff*n;
@@ -278,7 +279,7 @@ void XYFourierFilterCurvePrivate::recalculate() {
 	}
 	switch (unit2) {
 	case nsl_filter_cutoff_unit_frequency:
-		cutindex2 = cutoff2*(max-min);
+		cutindex2 = cutoff2*(xmax-xmin);
 		break;
 	case nsl_filter_cutoff_unit_fraction:
 		cutindex2 = cutoff2*n;
@@ -292,10 +293,8 @@ void XYFourierFilterCurvePrivate::recalculate() {
 		return;
 	}
 
-#ifndef NDEBUG
-	qDebug()<<"cut off @"<<cutindex<<cutindex2;
-	qDebug()<<"bandwidth ="<<bandwidth;
-#endif
+	DEBUG("cut off @" << cutindex << cutindex2);
+	DEBUG("bandwidth =" << bandwidth);
 
 	// run filter
 	int status = nsl_filter_fourier(ydata, n, type, form, order, cutindex, bandwidth);
@@ -334,6 +333,9 @@ void XYFourierFilterCurve::save(QXmlStreamWriter* writer) const{
 	writer->writeStartElement("filterData");
 	WRITE_COLUMN(d->xDataColumn, xDataColumn);
 	WRITE_COLUMN(d->yDataColumn, yDataColumn);
+	writer->writeAttribute( "autoRange", QString::number(d->filterData.autoRange) );
+	writer->writeAttribute( "xRangeMin", QString::number(d->filterData.xRange.first()) );
+	writer->writeAttribute( "xRangeMax", QString::number(d->filterData.xRange.last()) );
 	writer->writeAttribute( "type", QString::number(d->filterData.type) );
 	writer->writeAttribute( "form", QString::number(d->filterData.form) );
 	writer->writeAttribute( "order", QString::number(d->filterData.order) );
@@ -389,74 +391,25 @@ bool XYFourierFilterCurve::load(XmlStreamReader* reader) {
 			READ_COLUMN(xDataColumn);
 			READ_COLUMN(yDataColumn);
 
-			str = attribs.value("type").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'type'"));
-			else
-				d->filterData.type = (nsl_filter_type)str.toInt();
+			READ_INT_VALUE("autoRange", filterData.autoRange, bool);
+			READ_DOUBLE_VALUE("xRangeMin", filterData.xRange.first());
+			READ_DOUBLE_VALUE("xRangeMax", filterData.xRange.last());
+			READ_INT_VALUE("type", filterData.type, nsl_filter_type);
+			READ_INT_VALUE("form", filterData.form, nsl_filter_form);
+			READ_INT_VALUE("order", filterData.order, int);
+			READ_DOUBLE_VALUE("cutoff", filterData.cutoff);
+			READ_INT_VALUE("unit", filterData.unit, nsl_filter_cutoff_unit);
+			READ_DOUBLE_VALUE("cutoff2", filterData.cutoff2);
+			READ_INT_VALUE("unit2", filterData.unit2, nsl_filter_cutoff_unit);
 
-			str = attribs.value("form").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'form'"));
-			else
-				d->filterData.form = (nsl_filter_form)str.toInt();
-
-			str = attribs.value("order").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'order'"));
-			else
-				d->filterData.order = str.toInt();
-
-			str = attribs.value("cutoff").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'cutoff'"));
-			else
-				d->filterData.cutoff = str.toDouble();
-
-			str = attribs.value("unit").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'unit'"));
-			else
-				d->filterData.unit = (nsl_filter_cutoff_unit)str.toInt();
-
-			str = attribs.value("cutoff2").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'cutoff2'"));
-			else
-				d->filterData.cutoff2 = str.toDouble();
-
-			str = attribs.value("unit2").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'unit2'"));
-			else
-				d->filterData.unit2 = (nsl_filter_cutoff_unit)str.toInt();
 		} else if (reader->name() == "filterResult") {
 
 			attribs = reader->attributes();
 
-			str = attribs.value("available").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'available'"));
-			else
-				d->filterResult.available = str.toInt();
-
-			str = attribs.value("valid").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'valid'"));
-			else
-				d->filterResult.valid = str.toInt();
-			
-			str = attribs.value("status").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'status'"));
-			else
-				d->filterResult.status = str;
-
-			str = attribs.value("time").toString();
-			if (str.isEmpty())
-				reader->raiseWarning(attributeWarning.arg("'time'"));
-			else
-				d->filterResult.elapsedTime = str.toInt();
+			READ_INT_VALUE("available", filterResult.available, int);
+			READ_INT_VALUE("valid", filterResult.valid, int);
+			READ_STRING_VALUE("status", filterResult.status);
+			READ_INT_VALUE("time", filterResult.elapsedTime, int);
 		} else if (reader->name() == "column") {
 			Column* column = new Column("", AbstractColumn::Numeric);
 			if (!column->load(reader)) {
