@@ -31,6 +31,9 @@
 #define MATRIXVIEW_H
 
 #include <QWidget>
+#include <QList>
+#include "backend/datasources/filters/FITSFilter.h"
+#include "kdefrontend/widgets/FITSHeaderEditWidget.h"
 
 class Matrix;
 class MatrixModel;
@@ -69,6 +72,7 @@ class MatrixView : public QWidget {
         void exportToLaTeX(const QString&, const bool verticalHeaders, const bool horizontalHeaders,
                            const bool latexHeaders, const bool gridLines,
                            const bool entire, const bool captions) const;
+        void exportToFits(const QString& fileName, const int exportTo) const;
 	public slots:
 		void createContextMenu(QMenu*) const;
 		void print(QPrinter*) const;
@@ -129,6 +133,7 @@ class MatrixView : public QWidget {
 		QAction* action_fill_function;
 		QAction* action_fill_const;
 
+
 		//Menus
 		QMenu* m_selectionMenu;
 		QMenu* m_columnMenu;
