@@ -3,7 +3,7 @@
     Project              : LabPlot
     Description          : Worksheet view
     --------------------------------------------------------------------
-    Copyright            : (C) 2009-2016 Alexander Semke (alexander.semke@web.de)
+    Copyright            : (C) 2009-2017 Alexander Semke (alexander.semke@web.de)
     Copyright            : (C) 2016 Stefan-Gerlach (stefan.gerlach@uni.kn)
 
  ***************************************************************************/
@@ -29,9 +29,11 @@
 #include "commonfrontend/worksheet/WorksheetView.h"
 #include "backend/worksheet/plots/cartesian/Axis.h"
 #include "backend/worksheet/plots/cartesian/XYCurve.h"
+#include "backend/worksheet/plots/cartesian/XYCurvePrivate.h"
 #include "backend/worksheet/TextLabel.h"
 #include "kdefrontend/worksheet/GridDialog.h"
-
+#include "kdefrontend/worksheet/PresenterWidget.h"
+#include "kdefrontend/worksheet/DynamicPresenterWidget.h"
 #include <QApplication>
 #include <QMenu>
 #include <QToolBar>
@@ -44,10 +46,13 @@
 #include <QMessageBox>
 #include <QGraphicsOpacityEffect>
 #include <QTimeLine>
+#include <QClipboard>
 
 #include <KAction>
 #include <KLocale>
 #include <KMessageBox>
+#include <KConfigGroup>
+#include <KGlobal>
 
 #include <limits>
 
@@ -104,7 +109,7 @@ WorksheetView::WorksheetView(Worksheet* worksheet) : QGraphicsView(),
 	handleCartesianPlotActions();
 
 	changeZoom(zoomOriginAction);
-	currentZoomAction=zoomInViewAction;
+	currentZoomAction = zoomInViewAction;
 
 	currentMagnificationAction = noMagnificationAction;
 
@@ -117,6 +122,17 @@ WorksheetView::WorksheetView(Worksheet* worksheet) : QGraphicsView(),
 	connect(m_worksheet, SIGNAL(useViewSizeRequested()), this, SLOT(useViewSizeRequested()) );
 	connect(m_worksheet, SIGNAL(layoutChanged(Worksheet::Layout)), this, SLOT(layoutChanged(Worksheet::Layout)) );
 	connect(scene(), SIGNAL(selectionChanged()), this, SLOT(selectionChanged()) );
+
+	//resize the view to make the complete scene visible.
+	//no need to resize the view when the project is being opened,
+	//all views will be resized to the stored values at the end
+	if (!m_worksheet->isLoading()) {
+		float w = Worksheet::convertFromSceneUnits(sceneRect().width(), Worksheet::Inch);
+		float h = Worksheet::convertFromSceneUnits(sceneRect().height(), Worksheet::Inch);
+		w *= QApplication::desktop()->physicalDpiX();
+		h *= QApplication::desktop()->physicalDpiY();
+		resize(w*1.1, h*1.1);
+	}
 }
 
 void WorksheetView::initActions() {
@@ -232,6 +248,8 @@ void WorksheetView::initActions() {
 	snapToGridAction = new KAction(i18n("snap to grid"), this);
 	snapToGridAction->setCheckable(true);
 
+	showPresenterMode = new KAction(KIcon("view-fullscreen"), i18n("Show in presenter mode"), this);
+
 	//check the action corresponding to the currently active layout in worksheet
 	this->layoutChanged(m_worksheet->layout());
 
@@ -243,6 +261,8 @@ void WorksheetView::initActions() {
 	connect(gridActionGroup, SIGNAL(triggered(QAction*)), this, SLOT(changeGrid(QAction*)));
 	connect(snapToGridAction, SIGNAL(triggered()), this, SLOT(changeSnapToGrid()));
 
+	connect(showPresenterMode, SIGNAL(triggered()), this, SLOT(presenterMode()));
+
 
 	//action for cartesian plots
 	QActionGroup* cartesianPlotActionModeActionGroup = new QActionGroup(this);
@@ -274,6 +294,10 @@ void WorksheetView::initActions() {
 	QActionGroup* cartesianPlotAddNewActionGroup = new QActionGroup(this);
 	addCurveAction = new KAction(KIcon("labplot-xy-curve"), i18n("xy-curve"), cartesianPlotAddNewActionGroup);
 	addEquationCurveAction = new KAction(KIcon("labplot-xy-equation-curve"), i18n("xy-curve from a mathematical equation"), cartesianPlotAddNewActionGroup);
+	addDataOperationCurveAction = new KAction(i18n("xy-curve from a data operation"), cartesianPlotAddNewActionGroup);
+	addDataReductionCurveAction = new KAction(i18n("xy-curve from a data reduction"), cartesianPlotAddNewActionGroup);
+	addDifferentiationCurveAction = new KAction(i18n("xy-curve from a differentiation"), cartesianPlotAddNewActionGroup);
+	addIntegrationCurveAction = new KAction(i18n("xy-curve from an integration"), cartesianPlotAddNewActionGroup);
 // no icons yet
 	addInterpolationCurveAction = new KAction(i18n("xy-curve from an interpolation"), cartesianPlotAddNewActionGroup);
 	addSmoothCurveAction = new KAction(i18n("xy-curve from a smooth"), cartesianPlotAddNewActionGroup);
@@ -288,9 +312,12 @@ void WorksheetView::initActions() {
 	addHorizontalAxisAction = new KAction(KIcon("labplot-axis-horizontal"), i18n("horizontal axis"), cartesianPlotAddNewActionGroup);
 	addVerticalAxisAction = new KAction(KIcon("labplot-axis-vertical"), i18n("vertical axis"), cartesianPlotAddNewActionGroup);
 	addCustomPointAction = new KAction(KIcon("draw-cross"), i18n("custom point"), cartesianPlotAddNewActionGroup);
-	connect(cartesianPlotAddNewActionGroup, SIGNAL(triggered(QAction*)), SLOT(cartesianPlotAddNew(QAction*)));
 
 	// Analysis menu
+	addDataOperationAction = new KAction(i18n("Data operation"), cartesianPlotAddNewActionGroup);
+	addDataReductionAction = new KAction(i18n("Data reduction"), cartesianPlotAddNewActionGroup);
+	addDifferentiationAction = new KAction(i18n("Differentiation"), cartesianPlotAddNewActionGroup);
+	addIntegrationAction = new KAction(i18n("Integration"), cartesianPlotAddNewActionGroup);
 // no icons yet
 	addInterpolationAction = new KAction(i18n("Interpolation"), cartesianPlotAddNewActionGroup);
 	addSmoothAction = new KAction(i18n("Smooth"), cartesianPlotAddNewActionGroup);
@@ -302,6 +329,8 @@ void WorksheetView::initActions() {
 //	addFourierFilterAction = new KAction(KIcon("labplot-xy-fourier_filter-curve"), i18n("Fourier filter"), cartesianPlotAddNewActionGroup);
 //	addFourierTransformAction = new KAction(KIcon("labplot-xy-fourier_transform-curve"), i18n("Fourier transform"), cartesianPlotAddNewActionGroup);
 
+	connect(cartesianPlotAddNewActionGroup, SIGNAL(triggered(QAction*)), SLOT(cartesianPlotAddNew(QAction*)));
+
 	QActionGroup* cartesianPlotNavigationGroup = new QActionGroup(this);
 	scaleAutoAction = new KAction(KIcon("labplot-auto-scale-all"), i18n("auto scale"), cartesianPlotNavigationGroup);
 	scaleAutoAction->setData(CartesianPlot::ScaleAuto);
@@ -404,6 +433,10 @@ void WorksheetView::initMenus() {
 	m_cartesianPlotAddNewMenu = new QMenu(i18n("Add new"), this);
 	m_cartesianPlotAddNewMenu->addAction(addCurveAction);
 	m_cartesianPlotAddNewMenu->addAction(addEquationCurveAction);
+	m_cartesianPlotAddNewMenu->addAction(addDataOperationCurveAction);
+	m_cartesianPlotAddNewMenu->addAction(addDataReductionCurveAction);
+	m_cartesianPlotAddNewMenu->addAction(addDifferentiationCurveAction);
+	m_cartesianPlotAddNewMenu->addAction(addIntegrationCurveAction);
 	m_cartesianPlotAddNewMenu->addAction(addInterpolationCurveAction);
 	m_cartesianPlotAddNewMenu->addAction(addSmoothCurveAction);
 	m_cartesianPlotAddNewMenu->addAction(addFitCurveAction);
@@ -447,11 +480,11 @@ void WorksheetView::initMenus() {
 	m_cartesianPlotMenu->addSeparator();
 	m_cartesianPlotMenu->addMenu(m_cartesianPlotActionModeMenu);
 
-	// Filter menu?
-	//m_filterMenu = new QMenu(i18n("Filter"));
-	//TODO: filter icon
-	//m_filterMenu->setIcon(KIcon("zoom-draw"));
-	//m_filterMenu->addAction(addFourierFilterAction);
+	// Data manipulation menu
+	m_dataManipulationMenu = new QMenu(i18n("Data Manipulation"));
+	m_dataManipulationMenu->setIcon(KIcon("zoom-draw"));
+	m_dataManipulationMenu->addAction(addDataOperationAction);
+	m_dataManipulationMenu->addAction(addDataReductionAction);
 }
 
 /*!
@@ -468,7 +501,7 @@ void WorksheetView::createContextMenu(QMenu* menu) const {
 	// if we're populating the context menu for the project explorer, then
 	//there're already actions available there. Skip the first title-action
 	//and insert the action at the beginning of the menu.
-	if (menu->actions().size()>1)
+	if (menu->actions().size() > 1)
 		firstAction = menu->actions().at(1);
 
 	menu->insertMenu(firstAction, m_addNewMenu);
@@ -481,20 +514,23 @@ void WorksheetView::createContextMenu(QMenu* menu) const {
 	menu->insertSeparator(firstAction);
 	menu->insertMenu(firstAction, m_cartesianPlotMenu);
 	menu->insertSeparator(firstAction);
+	menu->insertAction(firstAction, showPresenterMode);
+	menu->insertSeparator(firstAction);
 }
 
 void WorksheetView::createAnalysisMenu(QMenu* menu) const {
 	Q_ASSERT(menu);
 
+	// Data manipulation menu
+	menu->insertMenu(0, m_dataManipulationMenu);
+
+	menu->addAction(addDifferentiationAction);
+	menu->addAction(addIntegrationAction);
 	menu->addAction(addInterpolationAction);
 	menu->addAction(addSmoothAction);
 	menu->addAction(addFitAction);
 	menu->addAction(addFourierFilterAction);
 	menu->addAction(addFourierTransformAction);
-	// Filter menu?
-	//menu->insertMenu(0,m_filterMenu);
-
-	//TODO: more to come
 }
 
 void WorksheetView::fillToolBar(QToolBar* toolBar) {
@@ -538,6 +574,10 @@ void WorksheetView::fillCartesianPlotToolBar(QToolBar* toolBar) {
 	toolBar->addAction(addCurveAction);
 	toolBar->addAction(addEquationCurveAction);
 // don't over populate the tool bar
+//	toolBar->addAction(addDifferentiationCurveAction);
+//	toolBar->addAction(addIntegrationCurveAction);
+//	toolBar->addAction(addDataOperationCurveAction);
+//	toolBar->addAction(addDataReductionCurveAction);
 //	toolBar->addAction(addInterpolationCurveAction);
 //	toolBar->addAction(addSmoothCurveAction);
 //	toolBar->addAction(addFitCurveAction);
@@ -592,44 +632,44 @@ void WorksheetView::drawBackgroundItems(QPainter* painter, const QRectF& scene_r
 	if (m_worksheet->backgroundType() == PlotArea::Color) {
 		switch (m_worksheet->backgroundColorStyle()) {
 		case PlotArea::SingleColor: {
-			painter->setBrush(QBrush(m_worksheet->backgroundFirstColor()));
-			break;
-		}
+				painter->setBrush(QBrush(m_worksheet->backgroundFirstColor()));
+				break;
+			}
 		case PlotArea::HorizontalLinearGradient: {
-			QLinearGradient linearGrad(scene_rect.topLeft(), scene_rect.topRight());
-			linearGrad.setColorAt(0, m_worksheet->backgroundFirstColor());
-			linearGrad.setColorAt(1, m_worksheet->backgroundSecondColor());
-			painter->setBrush(QBrush(linearGrad));
-			break;
-		}
+				QLinearGradient linearGrad(scene_rect.topLeft(), scene_rect.topRight());
+				linearGrad.setColorAt(0, m_worksheet->backgroundFirstColor());
+				linearGrad.setColorAt(1, m_worksheet->backgroundSecondColor());
+				painter->setBrush(QBrush(linearGrad));
+				break;
+			}
 		case PlotArea::VerticalLinearGradient: {
-			QLinearGradient linearGrad(scene_rect.topLeft(), scene_rect.bottomLeft());
-			linearGrad.setColorAt(0, m_worksheet->backgroundFirstColor());
-			linearGrad.setColorAt(1, m_worksheet->backgroundSecondColor());
-			painter->setBrush(QBrush(linearGrad));
-			break;
-		}
+				QLinearGradient linearGrad(scene_rect.topLeft(), scene_rect.bottomLeft());
+				linearGrad.setColorAt(0, m_worksheet->backgroundFirstColor());
+				linearGrad.setColorAt(1, m_worksheet->backgroundSecondColor());
+				painter->setBrush(QBrush(linearGrad));
+				break;
+			}
 		case PlotArea::TopLeftDiagonalLinearGradient: {
-			QLinearGradient linearGrad(scene_rect.topLeft(), scene_rect.bottomRight());
-			linearGrad.setColorAt(0, m_worksheet->backgroundFirstColor());
-			linearGrad.setColorAt(1, m_worksheet->backgroundSecondColor());
-			painter->setBrush(QBrush(linearGrad));
-			break;
-		}
+				QLinearGradient linearGrad(scene_rect.topLeft(), scene_rect.bottomRight());
+				linearGrad.setColorAt(0, m_worksheet->backgroundFirstColor());
+				linearGrad.setColorAt(1, m_worksheet->backgroundSecondColor());
+				painter->setBrush(QBrush(linearGrad));
+				break;
+			}
 		case PlotArea::BottomLeftDiagonalLinearGradient: {
-			QLinearGradient linearGrad(scene_rect.bottomLeft(), scene_rect.topRight());
-			linearGrad.setColorAt(0, m_worksheet->backgroundFirstColor());
-			linearGrad.setColorAt(1, m_worksheet->backgroundSecondColor());
-			painter->setBrush(QBrush(linearGrad));
-			break;
-		}
+				QLinearGradient linearGrad(scene_rect.bottomLeft(), scene_rect.topRight());
+				linearGrad.setColorAt(0, m_worksheet->backgroundFirstColor());
+				linearGrad.setColorAt(1, m_worksheet->backgroundSecondColor());
+				painter->setBrush(QBrush(linearGrad));
+				break;
+			}
 		case PlotArea::RadialGradient: {
-			QRadialGradient radialGrad(scene_rect.center(), scene_rect.width()/2);
-			radialGrad.setColorAt(0, m_worksheet->backgroundFirstColor());
-			radialGrad.setColorAt(1, m_worksheet->backgroundSecondColor());
-			painter->setBrush(QBrush(radialGrad));
-			break;
-		}
+				QRadialGradient radialGrad(scene_rect.center(), scene_rect.width()/2);
+				radialGrad.setColorAt(0, m_worksheet->backgroundFirstColor());
+				radialGrad.setColorAt(1, m_worksheet->backgroundSecondColor());
+				painter->setBrush(QBrush(radialGrad));
+				break;
+			}
 			//default:
 			//	painter->setBrush(QBrush(m_worksheet->backgroundFirstColor()));
 		}
@@ -755,9 +795,8 @@ void WorksheetView::wheelEvent(QWheelEvent *event) {
 			scale(1.2, 1.2);
 		else if (event->delta() < 0)
 			scale(1.0/1.2, 1.0/1.2);
-	} else {
+	} else
 		QGraphicsView::wheelEvent(event);
-	}
 }
 
 void WorksheetView::mousePressEvent(QMouseEvent* event) {
@@ -771,13 +810,36 @@ void WorksheetView::mousePressEvent(QMouseEvent* event) {
 	if (event->button() == Qt::LeftButton && m_mouseMode == ZoomSelectionMode) {
 		m_selectionStart = event->pos();
 		m_selectionBandIsShown = true;
+		QGraphicsView::mousePressEvent(event);
+		return;
+	}
+
+	//to select curves having overlapping bounding boxes we need to check whether the cursor
+	//is inside of item's shapes and not inside of the bounding boxes (Qt's default behaviour).
+	QList<QGraphicsItem*> itemsList = items(event->pos());
+	foreach(QGraphicsItem* item, itemsList) {
+		if (!dynamic_cast<XYCurvePrivate*>(item))
+			continue;
+
+		if ( item->shape().contains(item->mapFromScene(mapToScene(event->pos()))) ) {
+			//deselect currently selected items
+			QList<QGraphicsItem*> selectedItems = scene()->selectedItems();
+			foreach(QGraphicsItem* selectedItem, selectedItems)
+				selectedItem->setSelected(false);
+
+			//select the item under the cursor and update the current selection
+			item->setSelected(true);
+			selectionChanged();
+
+			return;
+		}
 	}
 
 	// select the worksheet in the project explorer if the view was clicked
 	// and there is no selection currently. We need this for the case when
 	// there is a single worksheet in the project and we change from the project-node
 	// in the project explorer to the worksheet-node by clicking the view.
-	if ( scene()->selectedItems().empty() )
+	if ( scene()->selectedItems().isEmpty() )
 		m_worksheet->setSelectedInView(true);
 
 	QGraphicsView::mousePressEvent(event);
@@ -790,9 +852,10 @@ void WorksheetView::mouseReleaseEvent(QMouseEvent* event) {
 
 		//don't zoom if very small region was selected, avoid occasional/unwanted zooming
 		m_selectionEnd = event->pos();
-		if ( abs(m_selectionEnd.x()-m_selectionStart.x())>20 && abs(m_selectionEnd.y()-m_selectionStart.y())>20 )
+		if ( abs(m_selectionEnd.x() - m_selectionStart.x()) > 20 && abs(m_selectionEnd.y() - m_selectionStart.y()) > 20 )
 			fitInView(mapToScene(QRect(m_selectionStart, m_selectionEnd).normalized()).boundingRect(), Qt::KeepAspectRatio);
 	}
+
 	QGraphicsView::mouseReleaseEvent(event);
 }
 
@@ -809,19 +872,17 @@ void WorksheetView::mouseMoveEvent(QMouseEvent* event) {
 
 		//set the cursor appearance according to the current mouse mode for the cartesian plots
 		if (plot) {
-			if (m_cartesianPlotMouseMode == CartesianPlot::ZoomSelectionMode) {
+			if (m_cartesianPlotMouseMode == CartesianPlot::ZoomSelectionMode)
 				setCursor(Qt::CrossCursor);
-			} else if (m_cartesianPlotMouseMode == CartesianPlot::ZoomXSelectionMode) {
+			else if (m_cartesianPlotMouseMode == CartesianPlot::ZoomXSelectionMode)
 				setCursor(Qt::SizeHorCursor);
-			} else if (m_cartesianPlotMouseMode == CartesianPlot::ZoomYSelectionMode) {
+			else if (m_cartesianPlotMouseMode == CartesianPlot::ZoomYSelectionMode)
 				setCursor(Qt::SizeVerCursor);
-			}
-		} else {
+		} else
 			setCursor(Qt::ArrowCursor);
-		}
-	} else if (m_mouseMode == SelectionMode && m_cartesianPlotMouseMode == CartesianPlot::SelectionMode ) {
+	} else if (m_mouseMode == SelectionMode && m_cartesianPlotMouseMode == CartesianPlot::SelectionMode )
 		setCursor(Qt::ArrowCursor);
-	} else if (m_selectionBandIsShown) {
+	else if (m_selectionBandIsShown) {
 		QRect rect = QRect(m_selectionStart, m_selectionEnd).normalized();
 		m_selectionEnd = event->pos();
 		rect = rect.united(QRect(m_selectionStart, m_selectionEnd).normalized());
@@ -864,15 +925,14 @@ void WorksheetView::mouseMoveEvent(QMouseEvent* event) {
 		m_magnificationWindow->setPos(pos.x()- px.width()/2, pos.y()- px.height()/2);
 
 		m_magnificationWindow->setVisible(true);
-	} else if (m_magnificationWindow) {
+	} else if (m_magnificationWindow)
 		m_magnificationWindow->setVisible(false);
-	}
 
 	QGraphicsView::mouseMoveEvent(event);
 }
 
 void WorksheetView::contextMenuEvent(QContextMenuEvent* e) {
-	if ( (m_magnificationWindow && m_magnificationWindow->isVisible() && items(e->pos()).size()==1) || !itemAt(e->pos()) ) {
+	if ( (m_magnificationWindow && m_magnificationWindow->isVisible() && items(e->pos()).size() == 1) || !itemAt(e->pos()) ) {
 		//no item or only the magnification window under the cursor -> show the context menu for the worksheet
 		QMenu *menu = new QMenu(this);
 		this->createContextMenu(menu);
@@ -917,51 +977,50 @@ void WorksheetView::processResize() {
 }
 
 void WorksheetView::changeZoom(QAction* action) {
-	if (action==zoomInViewAction) {
+	if (action == zoomInViewAction)
 		scale(1.2, 1.2);
-	} else if (action==zoomOutViewAction) {
+	else if (action == zoomOutViewAction)
 		scale(1.0/1.2, 1.0/1.2);
-	} else if (action==zoomOriginAction) {
+	else if (action == zoomOriginAction) {
 		static const float hscale = QApplication::desktop()->physicalDpiX()/(Worksheet::convertToSceneUnits(1,Worksheet::Inch));
 		static const float vscale = QApplication::desktop()->physicalDpiY()/(Worksheet::convertToSceneUnits(1,Worksheet::Inch));
 		setTransform(QTransform::fromScale(hscale, vscale));
-	} else if (action==zoomFitPageWidthAction) {
+	} else if (action == zoomFitPageWidthAction) {
 		float scaleFactor = viewport()->width()/scene()->sceneRect().width();
 		setTransform(QTransform::fromScale(scaleFactor, scaleFactor));
-	} else if (action==zoomFitPageHeightAction) {
+	} else if (action == zoomFitPageHeightAction) {
 		float scaleFactor = viewport()->height()/scene()->sceneRect().height();
 		setTransform(QTransform::fromScale(scaleFactor, scaleFactor));
-	} else if (action==zoomFitSelectionAction) {
+	} else if (action == zoomFitSelectionAction)
 		fitInView(scene()->selectionArea().boundingRect(),Qt::KeepAspectRatio);
-	}
-	currentZoomAction=action;
+	currentZoomAction = action;
 	if (tbZoom)
 		tbZoom->setDefaultAction(action);
 }
 
 void WorksheetView::magnificationChanged(QAction* action) {
-	if (action==noMagnificationAction)
+	if (action == noMagnificationAction)
 		magnificationFactor = 0;
-	else if (action==twoTimesMagnificationAction)
+	else if (action == twoTimesMagnificationAction)
 		magnificationFactor = 2;
-	else if (action==threeTimesMagnificationAction)
+	else if (action == threeTimesMagnificationAction)
 		magnificationFactor = 3;
-	else if (action==fourTimesMagnificationAction)
+	else if (action == fourTimesMagnificationAction)
 		magnificationFactor = 4;
-	else if (action==fiveTimesMagnificationAction)
+	else if (action == fiveTimesMagnificationAction)
 		magnificationFactor = 5;
 
-	currentMagnificationAction=action;
+	currentMagnificationAction = action;
 	if (tbMagnification)
 		tbMagnification->setDefaultAction(action);
 }
 
 void WorksheetView::mouseModeChanged(QAction* action) {
-	if (action==selectionModeAction) {
+	if (action == selectionModeAction) {
 		m_mouseMode = SelectionMode;
 		setInteractive(true);
 		setDragMode(QGraphicsView::NoDrag);
-	} else if (action==navigationModeAction) {
+	} else if (action == navigationModeAction) {
 		m_mouseMode = NavigationMode;
 		setInteractive(false);
 		setDragMode(QGraphicsView::ScrollHandDrag);
@@ -975,35 +1034,35 @@ void WorksheetView::mouseModeChanged(QAction* action) {
 //"Add new" related slots
 void WorksheetView::addNew(QAction* action) {
 	WorksheetElement* aspect = 0;
-	if ( action == addCartesianPlot1Action ) {
+	if (action == addCartesianPlot1Action) {
 		CartesianPlot* plot = new CartesianPlot(i18n("xy-plot"));
 		plot->initDefault(CartesianPlot::FourAxes);
 		plot->setMouseMode(m_cartesianPlotMouseMode);
 		aspect = plot;
 		if (tbNewCartesianPlot)
 			tbNewCartesianPlot->setDefaultAction(addCartesianPlot1Action);
-	} else if ( action == addCartesianPlot2Action ) {
+	} else if (action == addCartesianPlot2Action) {
 		CartesianPlot* plot = new CartesianPlot(i18n("xy-plot"));
 		plot->initDefault(CartesianPlot::TwoAxes);
 		plot->setMouseMode(m_cartesianPlotMouseMode);
 		aspect = plot;
 		if (tbNewCartesianPlot)
 			tbNewCartesianPlot->setDefaultAction(addCartesianPlot2Action);
-	} else if ( action == addCartesianPlot3Action ) {
+	} else if (action == addCartesianPlot3Action) {
 		CartesianPlot* plot = new CartesianPlot(i18n("xy-plot"));
 		plot->initDefault(CartesianPlot::TwoAxesCentered);
 		plot->setMouseMode(m_cartesianPlotMouseMode);
 		aspect = plot;
 		if (tbNewCartesianPlot)
 			tbNewCartesianPlot->setDefaultAction(addCartesianPlot3Action);
-	} else if ( action == addCartesianPlot4Action ) {
+	} else if (action == addCartesianPlot4Action) {
 		CartesianPlot* plot = new CartesianPlot(i18n("xy-plot"));
 		plot->initDefault(CartesianPlot::TwoAxesCenteredZero);
 		plot->setMouseMode(m_cartesianPlotMouseMode);
 		aspect = plot;
 		if (tbNewCartesianPlot)
 			tbNewCartesianPlot->setDefaultAction(addCartesianPlot4Action);
-	} else if ( action == addTextLabelAction ) {
+	} else if (action == addTextLabelAction) {
 		TextLabel* l = new TextLabel(i18n("text label"));
 		l->setText(i18n("text label"));
 		aspect = l;
@@ -1043,14 +1102,12 @@ void WorksheetView::addNew(QAction* action) {
 void WorksheetView::selectAllElements() {
 	//deselect all previously selected items since there can be some non top-level items belong them
 	m_suppressSelectionChangedEvent = true;
-	QList<QGraphicsItem*> items = scene()->selectedItems();
-	foreach ( QGraphicsItem* item , m_selectedItems ) {
+	foreach (QGraphicsItem* item, m_selectedItems)
 		m_worksheet->setItemSelectedInView(item, false);
-	}
 
 	//select top-level items
-	items = scene()->items();
-	foreach(QGraphicsItem* item, items) {
+	QList<QGraphicsItem*> items = scene()->items();
+	foreach (QGraphicsItem* item, items) {
 		if (!item->parentItem())
 			item->setSelected(true);
 	}
@@ -1062,22 +1119,20 @@ void WorksheetView::selectAllElements() {
  * deletes selected worksheet elements
  */
 void WorksheetView::deleteElement() {
-	QList<QGraphicsItem*> items = scene()->selectedItems();
-	if (items.size()==0)
+	if (m_selectedItems.isEmpty())
 		return;
 
 	int rc = KMessageBox::warningYesNo( this,
-	                                    i18np("Do you really want to delete the selected object?", "Do you really want to delete the selected %1 objects?", items.size()),
+	                                    i18np("Do you really want to delete the selected object?", "Do you really want to delete the selected %1 objects?", m_selectedItems.size()),
 	                                    i18n("Delete selected objects"));
 
-	if (rc==KMessageBox::No)
+	if (rc == KMessageBox::No)
 		return;
 
 	m_suppressSelectionChangedEvent = true;
 	m_worksheet->beginMacro(i18n("%1: Remove selected worksheet elements.", m_worksheet->name()));
-	foreach ( QGraphicsItem* item , m_selectedItems ) {
+	foreach (QGraphicsItem* item, m_selectedItems)
 		m_worksheet->deleteAspectFromGraphicsItem(item);
-	}
 	m_worksheet->endMacro();
 	m_suppressSelectionChangedEvent = false;
 }
@@ -1113,7 +1168,7 @@ void WorksheetView::fadeIn(qreal value) {
 
 void WorksheetView::fadeOut(qreal value) {
 	QGraphicsOpacityEffect* effect = new QGraphicsOpacityEffect();
-	effect->setOpacity(1-value);
+	effect->setOpacity(1 - value);
 	lastAddedWorksheetElement->graphicsItem()->setGraphicsEffect(effect);
 }
 
@@ -1122,7 +1177,7 @@ void WorksheetView::fadeOut(qreal value) {
  * sets the layout in Worksheet and enables/disables the layout actions.
  */
 void WorksheetView::changeLayout(QAction* action) {
-	if (action==breakLayoutAction) {
+	if (action == breakLayoutAction) {
 		verticalLayoutAction->setEnabled(true);
 		verticalLayoutAction->setChecked(false);
 
@@ -1262,7 +1317,7 @@ void WorksheetView::selectionChanged() {
 	}
 
 	//select new items
-	if (items.size() == 0 && invisibleDeselected == false) {
+	if (items.isEmpty() && invisibleDeselected == false) {
 		//no items selected -> select the worksheet again.
 		m_worksheet->setSelectedInView(true);
 
@@ -1290,7 +1345,8 @@ void WorksheetView::handleCartesianPlotActions() {
 	bool plot = false;
 	if (m_cartesianPlotActionMode == ApplyActionToSelection) {
 		//check whether we have cartesian plots selected
-		foreach (QGraphicsItem* item , m_selectedItems) {
+		foreach (QGraphicsItem* item, m_selectedItems) {
+			//TODO: or if a children of a plot is selected
 			if (item->data(0).toInt() == WorksheetElement::NameCartesianPlot) {
 				plot = true;
 				break;
@@ -1308,6 +1364,10 @@ void WorksheetView::handleCartesianPlotActions() {
 
 	addCurveAction->setEnabled(plot);
 	addEquationCurveAction->setEnabled(plot);
+	addDataOperationCurveAction->setEnabled(false);
+	addDataReductionCurveAction->setEnabled(plot);
+	addDifferentiationCurveAction->setEnabled(plot);
+	addIntegrationCurveAction->setEnabled(plot);
 	addInterpolationCurveAction->setEnabled(plot);
 	addSmoothCurveAction->setEnabled(plot);
 	addFitCurveAction->setEnabled(plot);
@@ -1331,8 +1391,12 @@ void WorksheetView::handleCartesianPlotActions() {
 	shiftUpYAction->setEnabled(plot);
 	shiftDownYAction->setEnabled(plot);
 
-	// analysis functions
-	//m_filterMenu->setEnabled(plot);
+	// analysis menu
+	//TODO: enable also if children of plots are selected
+	addDataOperationAction->setEnabled(false);
+	m_dataManipulationMenu->setEnabled(plot);
+	addDifferentiationAction->setEnabled(plot);
+	addIntegrationAction->setEnabled(plot);
 	addInterpolationAction->setEnabled(plot);
 	addSmoothAction->setEnabled(plot);
 	addFitAction->setEnabled(plot);
@@ -1344,21 +1408,19 @@ void WorksheetView::exportToFile(const QString& path, const ExportFormat format,
 	QRectF sourceRect;
 
 	//determine the rectangular to print
-	if (area==WorksheetView::ExportBoundingBox) {
+	if (area == WorksheetView::ExportBoundingBox)
 		sourceRect = scene()->itemsBoundingRect();
-	} else if (area==WorksheetView::ExportSelection) {
+	else if (area == WorksheetView::ExportSelection) {
 		//TODO doesn't work: rect = scene()->selectionArea().boundingRect();
-		foreach(QGraphicsItem* item, m_selectedItems) {
+		foreach (QGraphicsItem* item, m_selectedItems)
 			sourceRect = sourceRect.united( item->mapToScene(item->boundingRect()).boundingRect() );
-		}
-	} else {
+	} else
 		sourceRect = scene()->sceneRect();
-	}
 
 	//print
-	if (format==WorksheetView::Pdf || format==WorksheetView::Eps) {
+	if (format == WorksheetView::Pdf || format == WorksheetView::Eps) {
 		QPrinter printer(QPrinter::HighResolution);
-		if (format==WorksheetView::Pdf)
+		if (format == WorksheetView::Pdf)
 			printer.setOutputFormat(QPrinter::PdfFormat);
 		else
 			printer.setOutputFormat(QPrinter::PostScriptFormat);
@@ -1369,7 +1431,7 @@ void WorksheetView::exportToFile(const QString& path, const ExportFormat format,
 		printer.setPaperSize( QSizeF(w, h), QPrinter::Millimeter);
 		printer.setPageMargins(0,0,0,0, QPrinter::Millimeter);
 		printer.setPrintRange(QPrinter::PageRange);
-		printer.setCreator( QLatin1String("LabPlot ") + LVERSION );
+		printer.setCreator(QLatin1String("LabPlot ") + LVERSION);
 
 		QPainter painter(&printer);
 		painter.setRenderHint(QPainter::Antialiasing);
@@ -1377,7 +1439,7 @@ void WorksheetView::exportToFile(const QString& path, const ExportFormat format,
 		painter.begin(&printer);
 		exportPaint(&painter, targetRect, sourceRect, background);
 		painter.end();
-	} else if (format==WorksheetView::Svg) {
+	} else if (format == WorksheetView::Svg) {
 		QSvgGenerator generator;
 		generator.setFileName(path);
 		int w = Worksheet::convertFromSceneUnits(sourceRect.width(), Worksheet::Millimeter);
@@ -1410,10 +1472,41 @@ void WorksheetView::exportToFile(const QString& path, const ExportFormat format,
 		exportPaint(&painter, targetRect, sourceRect, background);
 		painter.end();
 
-		image.save(path, "png");
+		image.save(path, "PNG");
 	}
 }
 
+void WorksheetView::exportToClipboard() {
+#ifndef QT_NO_CLIPBOARD
+	QRectF sourceRect;
+
+	if (m_selectedItems.size() == 0)
+		sourceRect = scene()->itemsBoundingRect();
+	else {
+		//export selection
+		foreach (QGraphicsItem* item, m_selectedItems)
+			sourceRect = sourceRect.united( item->mapToScene(item->boundingRect()).boundingRect() );
+	}
+
+	int w = Worksheet::convertFromSceneUnits(sourceRect.width(), Worksheet::Millimeter);
+	int h = Worksheet::convertFromSceneUnits(sourceRect.height(), Worksheet::Millimeter);
+	w = w*QApplication::desktop()->physicalDpiX()/25.4;
+	h = h*QApplication::desktop()->physicalDpiY()/25.4;
+	QImage image(QSize(w, h), QImage::Format_ARGB32_Premultiplied);
+	image.fill(Qt::transparent);
+	QRectF targetRect(0, 0, w, h);
+
+	QPainter painter;
+	painter.begin(&image);
+	painter.setRenderHint(QPainter::Antialiasing);
+	exportPaint(&painter, targetRect, sourceRect, true);
+	painter.end();
+
+	QClipboard* clipboard = QApplication::clipboard();
+	clipboard->setImage(image, QClipboard::Clipboard);
+#endif
+}
+
 void WorksheetView::exportPaint(QPainter* painter, const QRectF& targetRect, const QRectF& sourceRect, const bool background) {
 	//draw the background
 	if (background) {
@@ -1456,7 +1549,7 @@ void WorksheetView::updateBackground() {
  * enables the corresponding action
  */
 void WorksheetView::layoutChanged(Worksheet::Layout layout) {
-	if (layout==Worksheet::NoLayout) {
+	if (layout == Worksheet::NoLayout) {
 		verticalLayoutAction->setEnabled(true);
 		verticalLayoutAction->setChecked(false);
 
@@ -1473,9 +1566,9 @@ void WorksheetView::layoutChanged(Worksheet::Layout layout) {
 		gridLayoutAction->setEnabled(false);
 		breakLayoutAction->setEnabled(true);
 
-		if (layout==Worksheet::VerticalLayout)
+		if (layout == Worksheet::VerticalLayout)
 			verticalLayoutAction->setChecked(true);
-		else if (layout==Worksheet::HorizontalLayout)
+		else if (layout == Worksheet::HorizontalLayout)
 			horizontalLayoutAction->setChecked(true);
 		else
 			gridLayoutAction->setChecked(true);
@@ -1496,79 +1589,160 @@ void WorksheetView::cartesianPlotActionModeChanged(QAction* action) {
 }
 
 void WorksheetView::cartesianPlotMouseModeChanged(QAction* action) {
-	if (action==cartesianPlotSelectionModeAction) {
+	if (action == cartesianPlotSelectionModeAction)
 		m_cartesianPlotMouseMode = CartesianPlot::SelectionMode;
-	} else if (action==cartesianPlotZoomSelectionModeAction) {
+	else if (action == cartesianPlotZoomSelectionModeAction)
 		m_cartesianPlotMouseMode = CartesianPlot::ZoomSelectionMode;
-	} else if (action==cartesianPlotZoomXSelectionModeAction) {
+	else if (action == cartesianPlotZoomXSelectionModeAction)
 		m_cartesianPlotMouseMode = CartesianPlot::ZoomXSelectionMode;
-	} else if (action==cartesianPlotZoomYSelectionModeAction) {
+	else if (action == cartesianPlotZoomYSelectionModeAction)
 		m_cartesianPlotMouseMode = CartesianPlot::ZoomYSelectionMode;
-	}
 
-	foreach(CartesianPlot* plot, m_worksheet->children<CartesianPlot>() ) {
+	foreach (CartesianPlot* plot, m_worksheet->children<CartesianPlot>() )
 		plot->setMouseMode(m_cartesianPlotMouseMode);
-	}
 }
 
 void WorksheetView::cartesianPlotAddNew(QAction* action) {
+	QList<CartesianPlot*> plots = m_worksheet->children<CartesianPlot>();
+	QDEBUG("WorksheetView::cartesianPlotAddNew() plots =" << plots << "mode =" << m_cartesianPlotActionMode);
 	if (m_cartesianPlotActionMode == ApplyActionToSelection) {
-		foreach(CartesianPlot* plot, m_worksheet->children<CartesianPlot>() ) {
-			if (m_selectedItems.indexOf(plot->graphicsItem())!=-1)
+		DEBUG("ApplyActionToSelection");
+		int selectedPlots = 0;
+		foreach (CartesianPlot* plot, plots) {
+			if (m_selectedItems.indexOf(plot->graphicsItem()) != -1)
+				++selectedPlots;
+		}
+
+		if  (selectedPlots > 1)
+			m_worksheet->beginMacro(i18n("%1: Add curve to %2 plots", m_worksheet->name(), selectedPlots));
+
+		foreach (CartesianPlot* plot, plots) {
+			//TODO: or if any children of a plot is selected
+			if (m_selectedItems.indexOf(plot->graphicsItem()) != -1)
 				this->cartesianPlotAdd(plot, action);
 		}
+
+		if (selectedPlots > 1)
+			m_worksheet->endMacro();
 	} else {
-		foreach(CartesianPlot* plot, m_worksheet->children<CartesianPlot>() )
+		DEBUG("not ApplyActionToSelection");
+		if  (plots.size() > 1)
+			m_worksheet->beginMacro(i18n("%1: Add curve to %2 plots", m_worksheet->name(), plots.size()));
+
+		foreach (CartesianPlot* plot, plots)
 			this->cartesianPlotAdd(plot, action);
+
+		if  (plots.size() > 1)
+			m_worksheet->endMacro();
 	}
 }
 
 void WorksheetView::cartesianPlotAdd(CartesianPlot* plot, QAction* action) {
-	if (action==addCurveAction)
+	DEBUG("WorksheetView::cartesianPlotAdd()");
+	if (action == addCurveAction)
 		plot->addCurve();
-	else if (action==addEquationCurveAction)
+	else if (action == addEquationCurveAction)
 		plot->addEquationCurve();
-	else if (action==addFitCurveAction)
-		plot->addFitCurve();
-	else if (action==addFourierFilterCurveAction)
-		plot->addFourierFilterCurve();
-	else if (action==addFourierTransformCurveAction)
-		plot->addFourierTransformCurve();
-	else if (action==addInterpolationCurveAction)
+	else if (action == addDataReductionCurveAction)
+		plot->addDataReductionCurve();
+	else if (action == addDifferentiationCurveAction)
+		plot->addDifferentiationCurve();
+	else if (action == addIntegrationCurveAction)
+		plot->addIntegrationCurve();
+	else if (action == addInterpolationCurveAction)
 		plot->addInterpolationCurve();
-	else if (action==addSmoothCurveAction)
+	else if (action == addFitCurveAction)
+		plot->addFitCurve();
+	else if (action == addFourierFilterCurveAction)
+		plot->addFourierFilterCurve();
+	else if (action == addFourierTransformCurveAction)
+		plot->addFourierTransformCurve();
+	else if (action == addSmoothCurveAction)
 		plot->addSmoothCurve();
-	else if (action==addLegendAction)
+	else if (action == addLegendAction)
 		plot->addLegend();
-	else if (action==addHorizontalAxisAction)
+	else if (action == addHorizontalAxisAction)
 		plot->addHorizontalAxis();
-	else if (action==addVerticalAxisAction)
+	else if (action == addVerticalAxisAction)
 		plot->addVerticalAxis();
-	else if (action==addCustomPointAction)
+	else if (action == addCustomPointAction)
 		plot->addCustomPoint();
 // analysis actions
-	else if (action==addFitAction)
-		plot->addFitCurve();
-	else if (action==addFourierFilterAction)
-		plot->addFourierFilterCurve();
-	else if (action==addFourierTransformAction)
-		plot->addFourierTransformCurve();
-	else if (action==addInterpolationAction)
+	else if (action == addDataReductionAction)
+		plot->addDataReductionCurve();
+	else if (action == addDifferentiationAction)
+		plot->addDifferentiationCurve();
+	else if (action == addIntegrationAction)
+		plot->addIntegrationCurve();
+	else if (action == addInterpolationAction)
 		plot->addInterpolationCurve();
-	else if (action==addSmoothAction)
+	else if (action == addFitAction)
+		plot->addFitCurve();
+	else if (action == addFourierFilterAction)
+		plot->addFourierFilterCurve();
+	else if (action == addFourierTransformAction)
+		plot->addFourierTransformCurve();
+	else if (action == addSmoothAction)
 		plot->addSmoothCurve();
 }
 
 void WorksheetView::cartesianPlotNavigationChanged(QAction* action) {
 	CartesianPlot::NavigationOperation op = (CartesianPlot::NavigationOperation)action->data().toInt();
 	if (m_cartesianPlotActionMode == ApplyActionToSelection) {
-		foreach(CartesianPlot* plot, m_worksheet->children<CartesianPlot>() ) {
-			if (m_selectedItems.indexOf(plot->graphicsItem())!=-1)
+		foreach (CartesianPlot* plot, m_worksheet->children<CartesianPlot>() ) {
+			if (m_selectedItems.indexOf(plot->graphicsItem()) != -1)
 				plot->navigate(op);
 		}
 	} else {
-		foreach(CartesianPlot* plot, m_worksheet->children<CartesianPlot>() ) {
+		foreach (CartesianPlot* plot, m_worksheet->children<CartesianPlot>() )
 			plot->navigate(op);
-		}
 	}
 }
+
+void WorksheetView::presenterMode() {
+	KConfigGroup group = KGlobal::config()->group(QLatin1String("Settings_Worksheet"));
+
+	//show dynamic presenter widget, if enabled
+	if (group.readEntry("PresenterModeInteractive", false)) {
+		DynamicPresenterWidget* dynamicPresenterWidget = new DynamicPresenterWidget(m_worksheet);
+		dynamicPresenterWidget->showFullScreen();
+		return;
+	}
+
+	//show static presenter widget (default)
+	QRectF sourceRect(scene()->sceneRect());
+
+	int w = Worksheet::convertFromSceneUnits(sourceRect.width(), Worksheet::Millimeter);
+	int h = Worksheet::convertFromSceneUnits(sourceRect.height(), Worksheet::Millimeter);
+	w *= QApplication::desktop()->physicalDpiX()/25.4;
+	h *= QApplication::desktop()->physicalDpiY()/25.4;
+
+	QRectF targetRect(0, 0, w, h);
+
+	QDesktopWidget* const dw = QApplication::desktop();
+	const int primaryScreenIdx = dw->primaryScreen();
+	const QRectF& screenSize = dw->availableGeometry(primaryScreenIdx);
+
+	if (targetRect.width() > screenSize.width() || ((targetRect.height() > screenSize.height()))) {
+		const double ratio = qMin(screenSize.width() / targetRect.width(), screenSize.height() / targetRect.height());
+		targetRect.setWidth(targetRect.width()* ratio);
+		targetRect.setHeight(targetRect.height() * ratio);
+	}
+
+	QImage image(QSize(targetRect.width(), targetRect.height()), QImage::Format_ARGB32_Premultiplied);
+	image.fill(Qt::transparent);
+	QPainter painter;
+	painter.begin(&image);
+	painter.setRenderHint(QPainter::Antialiasing);
+	exportPaint(&painter, targetRect, sourceRect, true);
+	painter.end();
+
+	PresenterWidget* presenterWidget = new PresenterWidget(QPixmap::fromImage(image), m_worksheet->name());
+	presenterWidget->showFullScreen();
+}
+
+void WorksheetView::keyPressEvent(QKeyEvent *event) {
+	if (event->matches(QKeySequence::Copy))
+		//add here copying of objects
+		exportToClipboard();
+}
