@@ -53,6 +53,7 @@
 #include "kdefrontend/HistoryDialog.h"
 #include "kdefrontend/SettingsDialog.h"
 #include "kdefrontend/GuiObserver.h"
+#include "kdefrontend/widgets/FITSHeaderEditDialog.h"
 
 #include <QMdiArea>
 #include <QMenu>
@@ -96,6 +97,7 @@ MainWin::MainWin(QWidget *parent, const QString& filename)
 	  m_autoSaveActive(false),
 	  m_visibilityMenu(0),
 	  m_newMenu(0),
+	  m_editMenu(0),
 	  axisDock(0),
 	  notesDock(0),
 	  cartesianPlotDock(0),
@@ -106,6 +108,9 @@ MainWin::MainWin(QWidget *parent, const QString& filename)
 	  projectDock(0),
 	  xyCurveDock(0),
 	  xyEquationCurveDock(0),
+	  xyDataReductionCurveDock(0),
+	  xyDifferentiationCurveDock(0),
+	  xyIntegrationCurveDock(0),
 	  xyInterpolationCurveDock(0),
 	  xySmoothCurveDock(0),
 	  xyFitCurveDock(0),
@@ -126,12 +131,10 @@ MainWin::MainWin(QWidget *parent, const QString& filename)
 MainWin::~MainWin() {
 	//write settings
 	m_recentProjectsAction->saveEntries( KGlobal::config()->group("Recent Files") );
-// 	qDebug()<<"SAVED m_recentProjectsAction->urls()="<<m_recentProjectsAction->urls()<<endl;
-	//etc...
 
 	KGlobal::config()->sync();
 
-	if (m_project!=0) {
+	if (m_project != 0) {
 		m_mdiArea->closeAllSubWindows();
 		disconnect(m_project, 0, this, 0);
 		delete m_project;
@@ -152,7 +155,7 @@ void MainWin::initGUI(const QString& fileName) {
 	m_mdiArea = new QMdiArea;
 	setCentralWidget(m_mdiArea);
 	connect(m_mdiArea, SIGNAL(subWindowActivated(QMdiSubWindow*)),
-	        this, SLOT(handleCurrentSubWindowChanged(QMdiSubWindow*)));
+		this, SLOT(handleCurrentSubWindowChanged(QMdiSubWindow*)));
 
 	statusBar()->showMessage(i18nc("%1 is the LabPlot version", "Welcome to LabPlot %1", QLatin1String(LVERSION)));
 	initActions();
@@ -171,7 +174,7 @@ void MainWin::initGUI(const QString& fileName) {
 	m_recentProjectsAction->loadEntries( KGlobal::config()->group("Recent Files") );
 
 	//set the view mode of the mdi area
-	KConfigGroup group = KGlobal::config()->group("General");
+	KConfigGroup group = KGlobal::config()->group(QLatin1String("Settings_General"));
 	int viewMode = group.readEntry("ViewMode", 0);
 	if (viewMode == 1) {
 		m_mdiArea->setViewMode(QMdiArea::TabbedView);
@@ -190,20 +193,20 @@ void MainWin::initGUI(const QString& fileName) {
 	m_autoSaveTimer.setInterval(interval);
 	connect(&m_autoSaveTimer, SIGNAL(timeout()), this, SLOT(autoSaveProject()));
 
-	if ( !fileName.isEmpty() ) {
+	if (!fileName.isEmpty())
 		openProject(fileName);
-	} else {
+	else {
 		//There is no file to open. Depending on the settings do nothing,
 		//create a new project or open the last used project.
 		int load = group.readEntry("LoadOnStart", 0);
-		if (load == 1) { //create new project
+		if (load == 1)   //create new project
 			newProject();
-		} else if (load == 2) { //create new project with a worksheet
+		else if (load == 2) { //create new project with a worksheet
 			newProject();
 			newWorksheet();
 		} else if (load == 3) { //open last used project
-			if (m_recentProjectsAction->urls().size()) {
-				qDebug()<<"TO OPEN m_recentProjectsAction->urls()="<<m_recentProjectsAction->urls().first()<<endl;
+			if (!m_recentProjectsAction->urls().isEmpty()) {
+				QDEBUG("TO OPEN m_recentProjectsAction->urls() =" << m_recentProjectsAction->urls().first());
 				openRecentProject( m_recentProjectsAction->urls().first() );
 			}
 		}
@@ -212,12 +215,10 @@ void MainWin::initGUI(const QString& fileName) {
 }
 
 void MainWin::initActions() {
-	KAction* action;
-
 	// ******************** File-menu *******************************
 	//add some standard actions
-	action = KStandardAction::openNew(this, SLOT(newProject()),actionCollection());
-	action = KStandardAction::open(this, SLOT(openProject()),actionCollection());
+	KStandardAction::openNew(this, SLOT(newProject()),actionCollection());
+	KStandardAction::open(this, SLOT(openProject()),actionCollection());
 	m_recentProjectsAction = KStandardAction::openRecent(this, SLOT(openRecentProject(KUrl)),actionCollection());
 	m_closeAction = KStandardAction::close(this, SLOT(closeProject()),actionCollection());
 	m_saveAction = KStandardAction::save(this, SLOT(saveProject()),actionCollection());
@@ -229,27 +230,27 @@ void MainWin::initActions() {
 	//New Folder/Workbook/Spreadsheet/Matrix/Worksheet/Datasources
 	m_newWorkbookAction = new KAction(KIcon("labplot-workbook-new"),i18n("Workbook"),this);
 	actionCollection()->addAction("new_workbook", m_newWorkbookAction);
-	connect(m_newWorkbookAction, SIGNAL(triggered()),SLOT(newWorkbook()));
+	connect(m_newWorkbookAction, SIGNAL(triggered()), SLOT(newWorkbook()));
 
 	m_newDatapickerAction = new KAction(KIcon("color-picker-black"),i18n("Datapicker"),this);
 	actionCollection()->addAction("new_datapicker", m_newDatapickerAction);
-	connect(m_newDatapickerAction, SIGNAL(triggered()),SLOT(newDatapicker()));
+	connect(m_newDatapickerAction, SIGNAL(triggered()), SLOT(newDatapicker()));
 
 	m_newSpreadsheetAction = new KAction(KIcon("labplot-spreadsheet-new"),i18n("Spreadsheet"),this);
 // 	m_newSpreadsheetAction->setShortcut(Qt::CTRL+Qt::Key_Equal);
 	actionCollection()->addAction("new_spreadsheet", m_newSpreadsheetAction);
-	connect(m_newSpreadsheetAction, SIGNAL(triggered()),SLOT(newSpreadsheet()));
+	connect(m_newSpreadsheetAction, SIGNAL(triggered()), SLOT(newSpreadsheet()));
 
 	m_newMatrixAction = new KAction(KIcon("labplot-matrix-new"),i18n("Matrix"),this);
 // 	m_newMatrixAction->setShortcut(Qt::CTRL+Qt::Key_Equal);
 	actionCollection()->addAction("new_matrix", m_newMatrixAction);
-	connect(m_newMatrixAction, SIGNAL(triggered()),SLOT(newMatrix()));
+	connect(m_newMatrixAction, SIGNAL(triggered()), SLOT(newMatrix()));
 
 	m_newWorksheetAction= new KAction(KIcon("labplot-worksheet-new"),i18n("Worksheet"),this);
 // 	m_newWorksheetAction->setShortcut(Qt::ALT+Qt::Key_X);
 	actionCollection()->addAction("new_worksheet", m_newWorksheetAction);
 	connect(m_newWorksheetAction, SIGNAL(triggered()), SLOT(newWorksheet()));
-	
+
 	m_newNotesAction= new KAction(KIcon("document-new"),i18n("Note"),this);
 	actionCollection()->addAction("new_notes", m_newNotesAction);
 	connect(m_newNotesAction, SIGNAL(triggered()), SLOT(newNotes()));
@@ -260,7 +261,7 @@ void MainWin::initActions() {
 
 	m_newFolderAction = new KAction(KIcon("folder-new"),i18n("Folder"),this);
 	actionCollection()->addAction("new_folder", m_newFolderAction);
-	connect(m_newFolderAction, SIGNAL(triggered()),SLOT(newFolder()));
+	connect(m_newFolderAction, SIGNAL(triggered()), SLOT(newFolder()));
 
 	//"New file datasources"
 	m_newFileDataSourceAction = new KAction(KIcon("application-octet-stream"),i18n("File Data Source"),this);
@@ -275,12 +276,16 @@ void MainWin::initActions() {
 	m_importAction = new KAction(KIcon("document-import-database"), i18n("Import"), this);
 	m_importAction->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_I);
 	actionCollection()->addAction("import", m_importAction);
-	connect(m_importAction, SIGNAL(triggered()),SLOT(importFileDialog()));
+	connect(m_importAction, SIGNAL(triggered()), SLOT(importFileDialog()));
 
 	m_exportAction = new KAction(KIcon("document-export-database"), i18n("Export"), this);
 	m_exportAction->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_E);
 	actionCollection()->addAction("export", m_exportAction);
-	connect(m_exportAction, SIGNAL(triggered()),SLOT(exportDialog()));
+	connect(m_exportAction, SIGNAL(triggered()), SLOT(exportDialog()));
+
+	m_editFitsFileAction = new KAction(KIcon("document-edit"), i18n("FITS Metadata Editor"), this);
+	actionCollection()->addAction("edit_fits", m_editFitsFileAction);
+	connect(m_editFitsFileAction, SIGNAL(triggered()), SLOT(editFitsFileDialog()));
 
 	// Edit
 	//Undo/Redo-stuff
@@ -289,16 +294,17 @@ void MainWin::initActions() {
 
 	m_historyAction = new KAction(KIcon("view-history"), i18n("Undo/Redo History"),this);
 	actionCollection()->addAction("history", m_historyAction);
-	connect(m_historyAction, SIGNAL(triggered()),SLOT(historyDialog()));
+	connect(m_historyAction, SIGNAL(triggered()), SLOT(historyDialog()));
 
-	// Appearance
+	// TODO: more menus
+	//  Appearance
 	// Analysis: see WorksheetView.cpp
 	// Drawing
 	// Script
 
 	//Windows
-	action  = new KAction(i18n("Cl&ose"), this);
-	action->setShortcut(i18n("Ctrl+W"));
+	KAction* action = new KAction(i18n("&Close"), this);
+	action->setShortcut(i18n("Ctrl+C"));
 	action->setStatusTip(i18n("Close the active window"));
 	actionCollection()->addAction("close window", action);
 	connect(action, SIGNAL(triggered()), m_mdiArea, SLOT(closeActiveSubWindow()));
@@ -388,6 +394,10 @@ void MainWin::initMenus() {
 	m_visibilityMenu ->addAction(m_visibilityFolderAction);
 	m_visibilityMenu ->addAction(m_visibilitySubfolderAction);
 	m_visibilityMenu ->addAction(m_visibilityAllAction);
+
+	//menu for editing files
+	m_editMenu = new QMenu(i18n("Edit"), this);
+	m_editMenu->addAction(m_editFitsFileAction);
 }
 
 /*!
@@ -420,15 +430,15 @@ void MainWin::updateGUIOnProjectChanges() {
 	if (m_closing)
 		return;
 
-	KXMLGUIFactory* factory=this->guiFactory();
-	if (factory->container("worksheet", this)==NULL) {
+	KXMLGUIFactory* factory = this->guiFactory();
+	if (factory->container("worksheet", this) == NULL) {
 		//no worksheet menu found, most probably labplot2ui.rc
 		//was not properly installed -> return here in order not to crash
 		return;
 	}
 
 	//disable all menus if there is no project
-	bool b = (m_project==0);
+	bool b = (m_project == 0);
 	m_saveAction->setEnabled(!b);
 	m_saveAsAction->setEnabled(!b);
 	m_printAction->setEnabled(!b);
@@ -477,8 +487,8 @@ void MainWin::updateGUI() {
 	if (m_closing)
 		return;
 
-	KXMLGUIFactory* factory=this->guiFactory();
-	if (factory->container("worksheet", this)==NULL) {
+	KXMLGUIFactory* factory = this->guiFactory();
+	if (factory->container("worksheet", this) == NULL) {
 		//no worksheet menu found, most probably labplot2ui.rc
 		//was not properly installed -> return here in order not to crash
 		return;
@@ -504,14 +514,13 @@ void MainWin::updateGUI() {
 	//TODO: is this the usual behaviour for toolbars defined in the rc-file?
 	KConfigGroup group = KGlobal::config()->group("MainWindow");
 
-
 	//Handle the Worksheet-object
 	Worksheet* w = this->activeWorksheet();
-	if (w!=0) {
+	if (w != 0) {
 		//enable worksheet related menus
 		factory->container("worksheet", this)->setEnabled(true);
- 		factory->container("analysis", this)->setEnabled(true);
-// 		factory->container("drawing", this)->setEnabled(true);
+		factory->container("analysis", this)->setEnabled(true);
+//TODO 		factory->container("drawing", this)->setEnabled(true);
 
 		//disable spreadsheet and matrix related menus
 		factory->container("spreadsheet", this)->setEnabled(false);
@@ -519,42 +528,41 @@ void MainWin::updateGUI() {
 
 		//populate worksheet menu
 		WorksheetView* view=qobject_cast<WorksheetView*>(w->view());
-		QMenu* menu=qobject_cast<QMenu*>(factory->container("worksheet", this));
+		QMenu* menu = qobject_cast<QMenu*>(factory->container("worksheet", this));
 		menu->clear();
 		view->createContextMenu(menu);
 
 		//populate analysis menu
-		menu=qobject_cast<QMenu*>(factory->container("analysis", this));
+		menu = qobject_cast<QMenu*>(factory->container("analysis", this));
 		menu->clear();
 		view->createAnalysisMenu(menu);
 
 		//populate worksheet-toolbar
-		QToolBar* toolbar=qobject_cast<QToolBar*>(factory->container("worksheet_toolbar", this));
-		if (group.groupList().indexOf("Toolbar worksheet_toolbar")==-1)
+		QToolBar* toolbar = qobject_cast<QToolBar*>(factory->container("worksheet_toolbar", this));
+		if (group.groupList().indexOf("Toolbar worksheet_toolbar") == -1)
 			toolbar->setToolButtonStyle(KToolBar::toolButtonStyleSetting());
 
-		toolbar->setVisible(true);
 		toolbar->clear();
 		view->fillToolBar(toolbar);
+		toolbar->setVisible(true);
 
 		//populate the toolbar for cartesian plots
 		toolbar=qobject_cast<QToolBar*>(factory->container("cartesian_plot_toolbar", this));
-		if (group.groupList().indexOf("Toolbar cartesian_plot_toolbar")==-1)
+		if (group.groupList().indexOf("Toolbar cartesian_plot_toolbar") == -1)
 			toolbar->setToolButtonStyle(KToolBar::toolButtonStyleSetting());
 
-		toolbar->setVisible(true);
 		toolbar->clear();
 		view->fillCartesianPlotToolBar(toolbar);
+		toolbar->setVisible(true);
 
 		//hide the spreadsheet toolbar
 		factory->container("spreadsheet_toolbar", this)->setVisible(false);
 	} else {
 		factory->container("worksheet", this)->setEnabled(false);
- 		factory->container("analysis", this)->setEnabled(false);
+		factory->container("analysis", this)->setEnabled(false);
 //		factory->container("drawing", this)->setEnabled(false);
 		factory->container("worksheet_toolbar", this)->setVisible(false);
 		factory->container("cartesian_plot_toolbar", this)->setVisible(false);
-
 	}
 
 	//Handle the Spreadsheet-object
@@ -564,14 +572,14 @@ void MainWin::updateGUI() {
 		factory->container("spreadsheet", this)->setEnabled(true);
 
 		//populate spreadsheet-menu
-		SpreadsheetView* view=qobject_cast<SpreadsheetView*>(spreadsheet->view());
-		QMenu* menu=qobject_cast<QMenu*>(factory->container("spreadsheet", this));
+		SpreadsheetView* view = qobject_cast<SpreadsheetView*>(spreadsheet->view());
+		QMenu* menu = qobject_cast<QMenu*>(factory->container("spreadsheet", this));
 		menu->clear();
 		view->createContextMenu(menu);
 
 		//populate spreadsheet-toolbar
-		QToolBar* toolbar=qobject_cast<QToolBar*>(factory->container("spreadsheet_toolbar", this));
-		if (group.groupList().indexOf("Toolbar spreadsheet_toolbar")==-1)
+		QToolBar* toolbar = qobject_cast<QToolBar*>(factory->container("spreadsheet_toolbar", this));
+		if (group.groupList().indexOf("Toolbar spreadsheet_toolbar") == -1)
 			toolbar->setToolButtonStyle(KToolBar::toolButtonStyleSetting());
 
 		toolbar->setVisible(true);
@@ -588,31 +596,30 @@ void MainWin::updateGUI() {
 		factory->container("matrix", this)->setEnabled(true);
 
 		//populate matrix-menu
-		MatrixView* view=qobject_cast<MatrixView*>(matrix->view());
-		QMenu* menu=qobject_cast<QMenu*>(factory->container("matrix", this));
+		MatrixView* view = qobject_cast<MatrixView*>(matrix->view());
+		QMenu* menu = qobject_cast<QMenu*>(factory->container("matrix", this));
 		menu->clear();
 		view->createContextMenu(menu);
-	} else {
+	} else
 		factory->container("matrix", this)->setEnabled(false);
-	}
 
 	const Datapicker* datapicker = this->activeDatapicker();
 	if (datapicker) {
 		factory->container("datapicker", this)->setEnabled(true);
 		//populate datapicker-menu
-		DatapickerView* view=qobject_cast<DatapickerView*>(datapicker->view());
-		QMenu* menu=qobject_cast<QMenu*>(factory->container("datapicker", this));
+		DatapickerView* view = qobject_cast<DatapickerView*>(datapicker->view());
+		QMenu* menu = qobject_cast<QMenu*>(factory->container("datapicker", this));
 		menu->clear();
 		view->createContextMenu(menu);
 
 		//populate spreadsheet-toolbar
-		QToolBar* toolbar=qobject_cast<QToolBar*>(factory->container("datapicker_toolbar", this));
-		if (group.groupList().indexOf("Toolbar datapicker_toolbar")==-1)
+		QToolBar* toolbar = qobject_cast<QToolBar*>(factory->container("datapicker_toolbar", this));
+		if (group.groupList().indexOf("Toolbar datapicker_toolbar") == -1)
 			toolbar->setToolButtonStyle(KToolBar::toolButtonStyleSetting());
 
-		toolbar->setVisible(true);
 		toolbar->clear();
 		view->fillToolBar(toolbar);
+		toolbar->setVisible(true);
 	} else {
 		factory->container("datapicker", this)->setEnabled(false);
 		factory->container("datapicker_toolbar", this)->setVisible(false);
@@ -639,7 +646,7 @@ bool MainWin::newProject() {
 	m_currentAspect = m_project;
 	m_currentFolder = m_project;
 
-	KConfigGroup group = KGlobal::config()->group("General");
+	KConfigGroup group = KGlobal::config()->group(QLatin1String("Settings_General"));
 	Project::MdiWindowVisibility vis = Project::MdiWindowVisibility(group.readEntry("MdiWindowVisibility", 0));
 	m_project->setMdiWindowVisibility( vis );
 	if (vis == Project::folderOnly)
@@ -653,7 +660,7 @@ bool MainWin::newProject() {
 
 	//newProject is called for the first time, there is no project explorer yet
 	//-> initialize the project explorer,  the GUI-observer and the dock widgets.
-	if ( m_projectExplorer==0 ) {
+	if (m_projectExplorer == 0) {
 		m_projectExplorerDock = new QDockWidget(this);
 		m_projectExplorerDock->setObjectName("projectexplorer");
 		m_projectExplorerDock->setWindowTitle(i18n("Project Explorer"));
@@ -664,6 +671,7 @@ bool MainWin::newProject() {
 
 		connect(m_projectExplorer, SIGNAL(currentAspectChanged(AbstractAspect*)),
 		        this, SLOT(handleCurrentAspectChanged(AbstractAspect*)));
+		connect(m_projectExplorerDock, SIGNAL(visibilityChanged(bool)), SLOT(projectExplorerDockVisibilityChanged(bool)));
 
 		//Properties dock
 		m_propertiesDock = new QDockWidget(this);
@@ -677,6 +685,8 @@ bool MainWin::newProject() {
 		sa->setWidgetResizable(true);
 		m_propertiesDock->setWidget(sa);
 
+		connect(m_propertiesDock, SIGNAL(visibilityChanged(bool)), SLOT(propertiesDockVisibilityChanged(bool)));
+
 		//GUI-observer;
 		m_guiObserver = new GuiObserver(this);
 	}
@@ -710,7 +720,7 @@ void MainWin::openProject() {
 	KConfigGroup conf(KSharedConfig::openConfig(), "MainWin");
 	QString dir = conf.readEntry("LastOpenDir", "");
 	QString path = KFileDialog::getOpenFileName(KUrl(dir),
-		i18n("LabPlot Projects (*.lml *.lml.gz *.lml.bz2 *.lml.xz *.LML *.LML.GZ *.LML.BZ2 *.LML.XZ)"), this, i18n("Open project"));
+	               i18n("LabPlot Projects (*.lml *.lml.gz *.lml.bz2 *.lml.xz *.LML *.LML.GZ *.LML.BZ2 *.LML.XZ)"), this, i18n("Open project"));
 
 	if (!path.isEmpty()) {
 		this->openProject(path);
@@ -731,13 +741,13 @@ void MainWin::openProject(const QString& filename) {
 	}
 
 	QIODevice *file;
-	// first try gzip compression, because older files are gzipped but end with .lml
-	if (filename.endsWith(".lml", Qt::CaseInsensitive))
-		file = KFilterDev::deviceForFile(filename, "application/x-gzip", true);
+	// first try gzip compression, because projects can be gzipped and end with .lml
+	if (filename.endsWith(QLatin1String(".lml"), Qt::CaseInsensitive))
+		file = KFilterDev::deviceForFile(filename, QLatin1String("application/x-gzip"), true);
 	else	// opens filename using file ending
 		file = KFilterDev::deviceForFile(filename);
 
-	if (file==0)
+	if (file == 0)
 		file = new QFile(filename);
 
 	if (!file->open(QIODevice::ReadOnly)) {
@@ -806,15 +816,17 @@ bool MainWin::openXML(QIODevice *file) {
 		return false;
 	}
 
-	//TODO: show warnings in a kind of "log window" but not in message box
-// 	if (reader.hasWarnings()) {
-// 		QString msg_text = i18n("The following problems occurred when loading the project:\n");
-// 		QStringList warnings = reader.warningStrings();
-// 		foreach(const QString& str, warnings)
-// 			msg_text += str + '\n';
-// 		KMessageBox::error(this, msg_text, i18n("Project loading partly failed"));
-// 		statusBar()->showMessage(msg_text);
-// 	}
+	if (reader.hasWarnings()) {
+		QString msg = i18n("The following problems occurred when loading the project file:\n");
+		const QStringList& warnings = reader.warningStrings();
+		foreach (const QString& str, warnings)
+			msg += str + '\n';
+
+		qWarning() << msg;
+//TODO: show warnings in a kind of "log window" but not in message box
+// 		KMessageBox::error(this, msg, i18n("Project loading partly failed"));
+// 		statusBar()->showMessage(msg);
+	}
 
 	return true;
 }
@@ -823,16 +835,16 @@ bool MainWin::openXML(QIODevice *file) {
 	Closes the current project, if available. Return \c true, if the project was closed.
 */
 bool MainWin::closeProject() {
-	if (m_project==0)
+	if (m_project == 0)
 		return true; //nothing to close
 
 	if (warnModified())
 		return false;
 
 	delete m_aspectTreeModel;
-	m_aspectTreeModel=0;
+	m_aspectTreeModel = 0;
 	delete m_project;
-	m_project=0;
+	m_project = 0;
 	m_currentFileName = "";
 
 	//update the UI if we're just closing a project
@@ -840,8 +852,8 @@ bool MainWin::closeProject() {
 	if (!m_closing) {
 		m_projectExplorerDock->hide();
 		m_propertiesDock->hide();
-		m_currentAspect=0;
-		m_currentFolder=0;
+		m_currentAspect = 0;
+		m_currentFolder = 0;
 		updateGUIOnProjectChanges();
 
 		if (m_autoSaveActive)
@@ -881,7 +893,13 @@ bool MainWin::saveProjectAs() {
 bool MainWin::save(const QString& fileName) {
 	WAIT_CURSOR;
 	// use file ending to find out how to compress file
-	QIODevice* file = KFilterDev::deviceForFile(fileName);
+	QIODevice* file;
+	// if ending is .lml, do gzip compression anyway
+	if (fileName.endsWith(QLatin1String(".lml")))
+		file = KFilterDev::deviceForFile(fileName, QLatin1String("application/x-gzip"), true);
+	else
+		file = KFilterDev::deviceForFile(fileName);
+
 	if (file == 0)
 		file = new QFile(fileName);
 
@@ -942,9 +960,11 @@ void MainWin::print() {
 		return;
 
 	AbstractPart* part = dynamic_cast<PartMdiView*>(win)->part();
-    if (part->printView()) {
-        statusBar()->showMessage(i18n("%1 printed", part->name()));
-    }
+	statusBar()->showMessage(i18n("Preparing printing of %1", part->name()));
+	if (part->printView())
+		statusBar()->showMessage(i18n("%1 printed", part->name()));
+	else
+		statusBar()->showMessage("");
 }
 
 void MainWin::printPreview() {
@@ -953,9 +973,11 @@ void MainWin::printPreview() {
 		return;
 
 	AbstractPart* part = dynamic_cast<PartMdiView*>(win)->part();
-    if (part->printPreview()) {
-        statusBar()->showMessage(i18n("%1 printed", part->name()));
-    }
+	statusBar()->showMessage(i18n("Preparing printing of %1", part->name()));
+	if (part->printPreview())
+		statusBar()->showMessage(i18n("%1 printed", part->name()));
+	else
+		statusBar()->showMessage("");
 }
 
 /**************************************************************************************/
@@ -977,7 +999,7 @@ void MainWin::newWorkbook() {
 }
 
 /*!
-    adds a new Datapicker to the project.
+	adds a new Datapicker to the project.
 */
 void MainWin::newDatapicker() {
 	Datapicker* datapicker = new Datapicker(0, i18n("Datapicker"));
@@ -1029,7 +1051,7 @@ void MainWin::newMatrix() {
 	adds a new Worksheet to the project.
 */
 void MainWin::newWorksheet() {
-	Worksheet* worksheet= new Worksheet(0,  i18n("Worksheet"));
+	Worksheet* worksheet= new Worksheet(0, i18n("Worksheet"));
 	this->addAspectToProject(worksheet);
 }
 
@@ -1053,8 +1075,8 @@ Workbook* MainWin::activeWorkbook() const {
 }
 
 /*!
-    returns a pointer to a Datapicker-object, if the currently active Mdi-Subwindow is \a DatapickerView.
-    Otherwise returns \a 0.
+	returns a pointer to a Datapicker-object, if the currently active Mdi-Subwindow is \a DatapickerView.
+	Otherwise returns \a 0.
 */
 Datapicker* MainWin::activeDatapicker() const {
 	QMdiSubWindow* win = m_mdiArea->currentSubWindow();
@@ -1092,9 +1114,8 @@ Spreadsheet* MainWin::activeSpreadsheet() const {
 					spreadsheet = dynamic_cast<Spreadsheet*>(m_currentAspect->parentAspect());
 			}
 		}
-	} else {
+	} else
 		spreadsheet = dynamic_cast<Spreadsheet*>(part);
-	}
 
 	return spreadsheet;
 }
@@ -1121,9 +1142,8 @@ Matrix* MainWin::activeMatrix() const {
 			//->check whether we have a matrix currently selected in the project explorer
 			matrix = dynamic_cast<Matrix*>(m_currentAspect);
 		}
-	} else {
+	} else
 		matrix = dynamic_cast<Matrix*>(part);
-	}
 
 	return matrix;
 }
@@ -1170,9 +1190,8 @@ void MainWin::handleCurrentSubWindowChanged(QMdiSubWindow* win) {
 		//This event happens, when labplot loses the focus (modal window is opened or the user switches to another application)
 		//and gets it back (modal window is closed or the user switches back to labplot).
 		return;
-	} else {
+	} else
 		m_currentSubWindow = view;
-	}
 
 	updateGUI();
 	if (!m_suppressCurrentSubWindowChangedEvent)
@@ -1221,7 +1240,7 @@ void MainWin::handleCurrentAspectChanged(AbstractAspect *aspect) {
 		aspect = m_project; // should never happen, just in case
 
 	m_suppressCurrentSubWindowChangedEvent = true;
-	if (aspect->folder() != m_currentFolder)	{
+	if (aspect->folder() != m_currentFolder) {
 		m_currentFolder = aspect->folder();
 		updateMdiWindowVisibility();
 	}
@@ -1279,11 +1298,10 @@ void MainWin::activateSubWindowForAspect(const AbstractAspect* aspect) const {
 				if (!datapicker)
 					datapicker = dynamic_cast<Datapicker*>(parent->parentAspect()->parentAspect());
 
-				if (workbook) {
+				if (workbook)
 					workbook->childSelected(parent);
-				} else if (datapicker) {
+				else if (datapicker)
 					datapicker->childSelected(parent);
-				}
 			}
 		}
 	}
@@ -1353,15 +1371,15 @@ void MainWin::redo() {
 */
 void MainWin::updateMdiWindowVisibility() const {
 	QList<QMdiSubWindow *> windows = m_mdiArea->subWindowList();
-	PartMdiView * part_view;
+	PartMdiView* part_view;
 	switch (m_project->mdiWindowVisibility()) {
 	case Project::allMdiWindows:
-		foreach(QMdiSubWindow* window, windows)
+		foreach (QMdiSubWindow* window, windows)
 			window->show();
 
 		break;
 	case Project::folderOnly:
-		foreach(QMdiSubWindow *window, windows) {
+		foreach (QMdiSubWindow *window, windows) {
 			part_view = qobject_cast<PartMdiView *>(window);
 			Q_ASSERT(part_view);
 			if (part_view->part()->folder() == m_currentFolder)
@@ -1371,7 +1389,7 @@ void MainWin::updateMdiWindowVisibility() const {
 		}
 		break;
 	case Project::folderAndSubfolders:
-		foreach(QMdiSubWindow *window, windows) {
+		foreach (QMdiSubWindow *window, windows) {
 			part_view = qobject_cast<PartMdiView *>(window);
 			if (part_view->part()->isDescendantOf(m_currentFolder))
 				part_view->show();
@@ -1396,10 +1414,18 @@ void MainWin::toggleDockWidget(QAction* action) const {
 	}
 }
 
+void MainWin::projectExplorerDockVisibilityChanged(bool visible) {
+	m_toggleProjectExplorerDockAction->setChecked(visible);
+}
+
+void MainWin::propertiesDockVisibilityChanged(bool visible) {
+	m_togglePropertiesDockAction->setChecked(visible);
+}
+
 void MainWin::toggleFullScreen() {
-	if (this->windowState() == Qt::WindowFullScreen) {
+	if (this->windowState() == Qt::WindowFullScreen)
 		this->setWindowState(m_lastWindowState);
-	} else {
+	else {
 		m_lastWindowState = this->windowState();
 		this->showFullScreen();
 	}
@@ -1426,7 +1452,7 @@ void MainWin::dropEvent(QDropEvent* event) {
 }
 
 void MainWin::handleSettingsChanges() {
-	const KConfigGroup group = KGlobal::config()->group( "General" );
+	const KConfigGroup group = KGlobal::config()->group(QLatin1String("Settings_General"));
 
 	QMdiArea::ViewMode viewMode = QMdiArea::ViewMode(group.readEntry("ViewMode", 0));
 	if (m_mdiArea->viewMode() != viewMode) {
@@ -1457,8 +1483,8 @@ void MainWin::handleSettingsChanges() {
 	}
 
 	int interval = group.readEntry("AutoSaveInterval", 1);
-	interval = interval*60*1000;
-	if (interval!=m_autoSaveTimer.interval())
+	interval *= 60*1000;
+	if (interval != m_autoSaveTimer.interval())
 		m_autoSaveTimer.setInterval(interval);
 }
 
@@ -1491,11 +1517,13 @@ void MainWin::historyDialog() {
   Opens the dialog to import data to the selected workbook, spreadsheet or matrix
 */
 void MainWin::importFileDialog(const QString& fileName) {
+	DEBUG("MainWin::importFileDialog()");
 	m_importFileDialog = new ImportFileDialog(this, false, fileName);
 
-	if (m_currentAspect->inherits("Spreadsheet") || m_currentAspect->inherits("Matrix") || m_currentAspect->inherits("Workbook")) {
+	// select existing container
+	if (m_currentAspect->inherits("Spreadsheet") || m_currentAspect->inherits("Matrix") || m_currentAspect->inherits("Workbook"))
 		m_importFileDialog->setCurrentIndex( m_projectExplorer->currentIndex());
-	} else if (m_currentAspect->inherits("Column")) {
+	else if (m_currentAspect->inherits("Column")) {
 		if (m_currentAspect->parentAspect()->inherits("Spreadsheet"))
 			m_importFileDialog->setCurrentIndex( m_aspectTreeModel->modelIndexOfAspect(m_currentAspect->parentAspect()));
 	}
@@ -1507,6 +1535,7 @@ void MainWin::importFileDialog(const QString& fileName) {
 
 	delete m_importFileDialog;
 	m_importFileDialog = 0;
+	DEBUG("MainWin::importFileDialog() DONE");
 }
 
 /*!
@@ -1518,9 +1547,16 @@ void MainWin::exportDialog() {
 		return;
 
 	AbstractPart* part = dynamic_cast<PartMdiView*>(win)->part();
-    if (part->exportView()) {
-        statusBar()->showMessage(i18n("%1 exported", part->name()));
-    }
+	if (part->exportView())
+		statusBar()->showMessage(i18n("%1 exported", part->name()));
+}
+
+void MainWin::editFitsFileDialog() {
+	FITSHeaderEditDialog* editDialog = new FITSHeaderEditDialog(this);
+	if (editDialog->exec() == KDialog::Accepted) {
+		if (editDialog->saved())
+			statusBar()->showMessage(i18n("FITS files saved"));
+	}
 }
 
 /*!
@@ -1548,7 +1584,7 @@ void MainWin::addAspectToProject(AbstractAspect* aspect) {
 	if (!index.isValid())
 		m_project->addChild(aspect);
 	else {
-		AbstractAspect * parent_aspect = static_cast<AbstractAspect *>(index.internalPointer());
+		AbstractAspect* parent_aspect = static_cast<AbstractAspect *>(index.internalPointer());
 		// every aspect contained in the project should have a folder
 		Q_ASSERT(parent_aspect->folder());
 		parent_aspect->folder()->addChild(aspect);
@@ -1559,5 +1595,4 @@ void MainWin::settingsDialog() {
 	SettingsDialog* dlg = new SettingsDialog(this);
 	connect (dlg, SIGNAL(settingsChanged()), this, SLOT(handleSettingsChanges()));
 	dlg->exec();
-	delete dlg;
 }
