@@ -56,6 +56,9 @@ class ProjectDock;
 class SpreadsheetDock;
 class XYCurveDock;
 class XYEquationCurveDock;
+class XYDataReductionCurveDock;
+class XYDifferentiationCurveDock;
+class XYIntegrationCurveDock;
 class XYInterpolationCurveDock;
 class XYSmoothCurveDock;
 class XYFitCurveDock;
@@ -125,7 +128,7 @@ private:
 	KAction* m_tileWindows;
 	KAction* m_cascadeWindows;
 	KAction* m_newDatapickerAction;
-
+	KAction* m_editFitsFileAction;
 
 	//toggling doch widgets
 	KAction* m_toggleProjectExplorerDockAction;
@@ -155,6 +158,7 @@ private:
 	//Menus
 	QMenu* m_visibilityMenu;
 	QMenu* m_newMenu;
+	QMenu* m_editMenu;
 
 	//Docks
 	QStackedWidget* stackedWidget;
@@ -168,6 +172,9 @@ private:
 	ProjectDock* projectDock;
 	XYCurveDock* xyCurveDock;
 	XYEquationCurveDock* xyEquationCurveDock;
+	XYDataReductionCurveDock* xyDataReductionCurveDock;
+	XYDifferentiationCurveDock* xyDifferentiationCurveDock;
+	XYIntegrationCurveDock* xyIntegrationCurveDock;
 	XYInterpolationCurveDock* xyInterpolationCurveDock;
 	XYSmoothCurveDock* xySmoothCurveDock;
 	XYFitCurveDock* xyFitCurveDock;
@@ -224,6 +231,7 @@ private slots:
 	void historyDialog();
 	void importFileDialog(const QString& fileName = QString());
 	void exportDialog();
+	void editFitsFileDialog();
 	void settingsDialog();
 	void projectChanged();
 
@@ -254,6 +262,8 @@ private slots:
 	void updateMdiWindowVisibility() const;
 	void toggleDockWidget(QAction*) const;
 	void toggleFullScreen();
+	void projectExplorerDockVisibilityChanged(bool);
+	void propertiesDockVisibilityChanged(bool);
 };
 
 #endif
