@@ -3,8 +3,8 @@ File                 : ImportFileWidget.cpp
 Project              : LabPlot
 Description          : import file data widget
 --------------------------------------------------------------------
-Copyright            : (C) 2009-2015 Stefan Gerlach (stefan.gerlach@uni.kn)
-Copyright            : (C) 2009-2015 Alexander Semke (alexander.semke@web.de)
+Copyright            : (C) 2009-2017 Stefan Gerlach (stefan.gerlach@uni.kn)
+Copyright            : (C) 2009-2017 Alexander Semke (alexander.semke@web.de)
 
 ***************************************************************************/
 
@@ -34,26 +34,25 @@ Copyright            : (C) 2009-2015 Alexander Semke (alexander.semke@web.de)
 #include "backend/datasources/filters/HDFFilter.h"
 #include "backend/datasources/filters/NetCDFFilter.h"
 #include "backend/datasources/filters/ImageFilter.h"
+#include "backend/datasources/filters/FITSFilter.h"
 
 #include <QTableWidget>
 #include <QInputDialog>
 #include <QDir>
 #include <QFileDialog>
 #include <QProcess>
-#include <QTextStream>
-#include <KUrlCompletion>
-#include <QDebug>
 #include <QTimer>
 #include <QStandardItemModel>
 #include <QImageReader>
 
+#include <KUrlCompletion>
+
 /*!
    \class ImportFileWidget
    \brief Widget for importing data from a file.
 
    \ingroup kdefrontend
 */
-
 ImportFileWidget::ImportFileWidget(QWidget* parent, const QString& fileName) : QWidget(parent), m_fileName(fileName) {
 	ui.setupUi(this);
 
@@ -62,11 +61,11 @@ ImportFileWidget::ImportFileWidget(QWidget* parent, const QString& fileName) : Q
 
 	ui.cbFileType->addItems(FileDataSource::fileTypes());
 	QStringList filterItems;
-	filterItems<<i18n("Automatic")<<i18n("Custom");
+	filterItems << i18n("Automatic") << i18n("Custom");
 	ui.cbFilter->addItems( filterItems );
 
 	// file type specific option widgets
-	QWidget* asciiw=new QWidget(0);
+	QWidget* asciiw = new QWidget(0);
 	asciiOptionsWidget.setupUi(asciiw);
 	asciiOptionsWidget.cbSeparatingCharacter->addItems(AsciiFilter::separatorCharacters());
 	asciiOptionsWidget.cbCommentCharacter->addItems(AsciiFilter::commentCharacters());
@@ -79,32 +78,44 @@ ImportFileWidget::ImportFileWidget(QWidget* parent, const QString& fileName) : Q
 	binaryOptionsWidget.cbByteOrder->addItems(BinaryFilter::byteOrders());
 	ui.swOptions->insertWidget(FileDataSource::Binary, binaryw);
 
-	QWidget* imagew=new QWidget(0);
+	QWidget* imagew = new QWidget(0);
 	imageOptionsWidget.setupUi(imagew);
 	imageOptionsWidget.cbImportFormat->addItems(ImageFilter::importFormats());
 	ui.swOptions->insertWidget(FileDataSource::Image, imagew);
 
-	QWidget* hdfw=new QWidget(0);
+	QWidget* hdfw = new QWidget(0);
 	hdfOptionsWidget.setupUi(hdfw);
 	QStringList hdfheaders;
-	hdfheaders<<i18n("Name")<<i18n("Link")<<i18n("Type")<<i18n("Properties")<<i18n("Attributes");
+	hdfheaders << i18n("Name") << i18n("Link") << i18n("Type") << i18n("Properties") << i18n("Attributes");
 	hdfOptionsWidget.twContent->setHeaderLabels(hdfheaders);
+	hdfOptionsWidget.twContent->setAlternatingRowColors(true);
 	// link and type column are hidden
 	hdfOptionsWidget.twContent->hideColumn(1);
 	hdfOptionsWidget.twContent->hideColumn(2);
 	hdfOptionsWidget.twContent->setSelectionMode(QAbstractItemView::ExtendedSelection);
+	hdfOptionsWidget.twPreview->setEditTriggers(QAbstractItemView::NoEditTriggers);
 	ui.swOptions->insertWidget(FileDataSource::HDF, hdfw);
 
-	QWidget* netcdfw=new QWidget(0);
+	QWidget* netcdfw = new QWidget(0);
 	netcdfOptionsWidget.setupUi(netcdfw);
 	QStringList headers;
-	headers<<i18n("Name")<<i18n("Type")<<i18n("Properties")<<i18n("Values");
+	headers << i18n("Name") << i18n("Type") << i18n("Properties") << i18n("Values");
 	netcdfOptionsWidget.twContent->setHeaderLabels(headers);
 	// type column is hidden
 	netcdfOptionsWidget.twContent->hideColumn(1);
 	netcdfOptionsWidget.twContent->setSelectionMode(QAbstractItemView::ExtendedSelection);
+	netcdfOptionsWidget.twContent->setAlternatingRowColors(true);
+	netcdfOptionsWidget.twPreview->setEditTriggers(QAbstractItemView::NoEditTriggers);
 	ui.swOptions->insertWidget(FileDataSource::NETCDF, netcdfw);
 
+	QWidget* fitsw = new QWidget(0);
+	fitsOptionsWidget.setupUi(fitsw);
+	fitsOptionsWidget.twExtensions->headerItem()->setText(0, i18n("Content"));
+	fitsOptionsWidget.twExtensions->setSelectionMode(QAbstractItemView::SingleSelection);
+	fitsOptionsWidget.twExtensions->setAlternatingRowColors(true);
+	fitsOptionsWidget.twPreview->setEditTriggers(QAbstractItemView::NoEditTriggers);
+	ui.swOptions->insertWidget(FileDataSource::FITS, fitsw);
+
 	// the table widget for preview
 	twPreview = new QTableWidget(ui.tePreview);
 	twPreview->horizontalHeader()->hide();
@@ -117,18 +128,23 @@ ImportFileWidget::ImportFileWidget(QWidget* parent, const QString& fileName) : Q
 
 	// default filter
 	ui.swOptions->setCurrentIndex(FileDataSource::Ascii);
-#if !defined(HAVE_HDF5) || !defined(HAVE_NETCDF)
+#if !defined(HAVE_HDF5) || !defined(HAVE_NETCDF) || !defined(HAVE_FITS)
 	const QStandardItemModel* model = qobject_cast<const QStandardItemModel*>(ui.cbFileType->model());
 #endif
 #ifndef HAVE_HDF5
 	// disable HDF5 item
 	QStandardItem* item = model->item(FileDataSource::HDF);
-	item->setFlags(item->flags() & ~(Qt::ItemIsSelectable|Qt::ItemIsEnabled));
+	item->setFlags(item->flags() & ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled));
 #endif
 #ifndef HAVE_NETCDF
 	// disable NETCDF item
 	QStandardItem* item2 = model->item(FileDataSource::NETCDF);
-	item2->setFlags(item2->flags() & ~(Qt::ItemIsSelectable|Qt::ItemIsEnabled));
+	item2->setFlags(item2->flags() & ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled));
+#endif
+#ifndef HAVE_FITS
+	// disable FITS item
+	QStandardItem* item3 = model->item(FileDataSource::FITS);
+	item3->setFlags(item3->flags() & ~(Qt::ItemIsSelectable | Qt::ItemIsEnabled));
 #endif
 
 	ui.gbOptions->hide();
@@ -151,10 +167,12 @@ ImportFileWidget::ImportFileWidget(QWidget* parent, const QString& fileName) : Q
 	connect( ui.bRefreshPreview, SIGNAL(clicked()), SLOT(refreshPreview()) );
 
 	connect( asciiOptionsWidget.chbHeader, SIGNAL(stateChanged(int)), SLOT(headerChanged(int)) );
-	connect( hdfOptionsWidget.twContent, SIGNAL(itemActivated(QTreeWidgetItem*,int)), SLOT(hdfTreeWidgetItemSelected(QTreeWidgetItem*,int)) );
+	connect( hdfOptionsWidget.twContent, SIGNAL(itemSelectionChanged()), SLOT(hdfTreeWidgetSelectionChanged()) );
 	connect( hdfOptionsWidget.bRefreshPreview, SIGNAL(clicked()), SLOT(refreshPreview()) );
-	connect( netcdfOptionsWidget.twContent, SIGNAL(itemActivated(QTreeWidgetItem*,int)), SLOT(netcdfTreeWidgetItemSelected(QTreeWidgetItem*,int)) );
+	connect( netcdfOptionsWidget.twContent, SIGNAL(itemSelectionChanged()), SLOT(netcdfTreeWidgetSelectionChanged()) );
 	connect( netcdfOptionsWidget.bRefreshPreview, SIGNAL(clicked()), SLOT(refreshPreview()) );
+	connect( fitsOptionsWidget.twExtensions, SIGNAL(itemSelectionChanged()), SLOT(fitsTreeWidgetSelectionChanged()));
+	connect( fitsOptionsWidget.bRefreshPreview, SIGNAL(clicked()), SLOT(refreshPreview()) );
 
 	//TODO: implement save/load of user-defined settings later and activate these buttons again
 	ui.bSaveFilter->hide();
@@ -166,7 +184,7 @@ ImportFileWidget::ImportFileWidget(QWidget* parent, const QString& fileName) : Q
 
 void ImportFileWidget::loadSettings() {
 	//load last used settings
-	KConfigGroup conf(KSharedConfig::openConfig(),"Import");
+	KConfigGroup conf(KSharedConfig::openConfig(), "Import");
 
 	//settings for data type specific widgets
 	// ascii data
@@ -200,7 +218,7 @@ void ImportFileWidget::loadSettings() {
 
 ImportFileWidget::~ImportFileWidget() {
 	// save current settings
-	KConfigGroup conf(KSharedConfig::openConfig(),"Import");
+	KConfigGroup conf(KSharedConfig::openConfig(), "Import");
 
 	// general settings
 	conf.writeEntry("LastImportedFile", ui.kleFileName->text());
@@ -249,6 +267,15 @@ void ImportFileWidget::showOptions(bool b) {
 }
 
 QString ImportFileWidget::fileName() const {
+	if (currentFileType() == FileDataSource::FITS) {
+		if (fitsOptionsWidget.twExtensions->currentItem() != 0) {
+			if (fitsOptionsWidget.twExtensions->currentItem()->text(0) != i18n("Primary header")) {
+				return ui.kleFileName->text() + QLatin1String("[") +
+				       fitsOptionsWidget.twExtensions->currentItem()->text(fitsOptionsWidget.twExtensions->currentColumn()) + QLatin1String("]");
+			}
+		}
+
+	}
 	return ui.kleFileName->text();
 }
 
@@ -279,94 +306,97 @@ FileDataSource::FileType ImportFileWidget::currentFileType() const {
 	returns the currently used filter.
 */
 AbstractFileFilter* ImportFileWidget::currentFileFilter() const {
-	//FileDataSource::FileType fileType = this->currentFileType();
+	DEBUG("currentFileFilter()");
 	FileDataSource::FileType fileType = (FileDataSource::FileType)ui.cbFileType->currentIndex();
 
-	//qDebug()<<"	current filter ="<<ui.cbFilter->currentIndex();
-
 	switch (fileType) {
 	case FileDataSource::Ascii: {
-		//TODO use auto_ptr
-		AsciiFilter* filter = new AsciiFilter();
+			//TODO use auto_ptr
+			AsciiFilter* filter = new AsciiFilter();
 
-		if (ui.cbFilter->currentIndex() == 0) { //"automatic"
-			filter->setAutoModeEnabled(true);
-		} else if (ui.cbFilter->currentIndex() == 1) { //"custom"
-			filter->setAutoModeEnabled(false);
-			filter->setCommentCharacter( asciiOptionsWidget.cbCommentCharacter->currentText() );
-			filter->setSeparatingCharacter( asciiOptionsWidget.cbSeparatingCharacter->currentText() );
-			filter->setSimplifyWhitespacesEnabled( asciiOptionsWidget.chbSimplifyWhitespaces->isChecked() );
-			filter->setSkipEmptyParts( asciiOptionsWidget.chbSkipEmptyParts->isChecked() );
-			filter->setTransposed( asciiOptionsWidget.chbTranspose->isChecked() );
-			filter->setVectorNames( asciiOptionsWidget.kleVectorNames->text() );
-			filter->setHeaderEnabled( asciiOptionsWidget.chbHeader->isChecked() );
-		} else {
-			filter->loadFilterSettings( ui.cbFilter->currentText() );
+			if (ui.cbFilter->currentIndex() == 0)   //"automatic"
+				filter->setAutoModeEnabled(true);
+			else if (ui.cbFilter->currentIndex() == 1) { //"custom"
+				filter->setAutoModeEnabled(false);
+				filter->setCommentCharacter( asciiOptionsWidget.cbCommentCharacter->currentText() );
+				filter->setSeparatingCharacter( asciiOptionsWidget.cbSeparatingCharacter->currentText() );
+				filter->setSimplifyWhitespacesEnabled( asciiOptionsWidget.chbSimplifyWhitespaces->isChecked() );
+				filter->setSkipEmptyParts( asciiOptionsWidget.chbSkipEmptyParts->isChecked() );
+				filter->setTransposed( asciiOptionsWidget.chbTranspose->isChecked() );
+				filter->setVectorNames( asciiOptionsWidget.kleVectorNames->text() );
+				filter->setHeaderEnabled( asciiOptionsWidget.chbHeader->isChecked() );
+			} else
+				filter->loadFilterSettings( ui.cbFilter->currentText() );
+
+			//save the data portion to import
+			filter->setStartRow( ui.sbStartRow->value());
+			filter->setEndRow( ui.sbEndRow->value() );
+			filter->setStartColumn( ui.sbStartColumn->value());
+			filter->setEndColumn( ui.sbEndColumn->value());
+
+			return filter;
 		}
-
-		//save the data portion to import
-		filter->setStartRow( ui.sbStartRow->value());
-		filter->setEndRow( ui.sbEndRow->value() );
-		filter->setStartColumn( ui.sbStartColumn->value());
-		filter->setEndColumn( ui.sbEndColumn->value());
-
-		return filter;
-//		source->setFilter(filter);
-	}
 	case FileDataSource::Binary: {
-		BinaryFilter* filter = new BinaryFilter();
-		if ( ui.cbFilter->currentIndex()==0 ) {	//"automatic"
-			filter->setAutoModeEnabled(true);
-		} else if ( ui.cbFilter->currentIndex()==1 ) { //"custom"
-			filter->setAutoModeEnabled(false);
-			filter->setVectors( binaryOptionsWidget.niVectors->value() );
-			filter->setDataType( (BinaryFilter::DataType) binaryOptionsWidget.cbDataType->currentIndex() );
-		} else {
-			//TODO: load filter settings
+			BinaryFilter* filter = new BinaryFilter();
+			if ( ui.cbFilter->currentIndex() == 0 ) 	//"automatic"
+				filter->setAutoModeEnabled(true);
+			else if ( ui.cbFilter->currentIndex() == 1 ) {	//"custom"
+				filter->setAutoModeEnabled(false);
+				filter->setVectors( binaryOptionsWidget.niVectors->value() );
+				filter->setDataType( (BinaryFilter::DataType) binaryOptionsWidget.cbDataType->currentIndex() );
+			} else {
+				//TODO: load filter settings
 // 			filter->setFilterName( ui.cbFilter->currentText() );
+			}
+
+			filter->setStartRow( ui.sbStartRow->value() );
+			filter->setEndRow( ui.sbEndRow->value() );
+
+			return filter;
 		}
-
-		filter->setStartRow( ui.sbStartRow->value() );
-		filter->setEndRow( ui.sbEndRow->value() );
-
-//		source->setFilter(filter);
-		return filter;
-	}
 	case FileDataSource::Image: {
-		ImageFilter* filter = new ImageFilter();
+			ImageFilter* filter = new ImageFilter();
 
-		filter->setImportFormat((ImageFilter::ImportFormat)imageOptionsWidget.cbImportFormat->currentIndex());
-		filter->setStartRow( ui.sbStartRow->value() );
-		filter->setEndRow( ui.sbEndRow->value() );
-		filter->setStartColumn( ui.sbStartColumn->value() );
-		filter->setEndColumn( ui.sbEndColumn->value() );
+			filter->setImportFormat((ImageFilter::ImportFormat)imageOptionsWidget.cbImportFormat->currentIndex());
+			filter->setStartRow( ui.sbStartRow->value() );
+			filter->setEndRow( ui.sbEndRow->value() );
+			filter->setStartColumn( ui.sbStartColumn->value() );
+			filter->setEndColumn( ui.sbEndColumn->value() );
 
-		return filter;
-	}
+			return filter;
+		}
 	case FileDataSource::HDF: {
-		HDFFilter* filter = new HDFFilter();
+			HDFFilter* filter = new HDFFilter();
 
-		if (!selectedHDFNames().isEmpty())
-			filter->setCurrentDataSetName(selectedHDFNames()[0]);
-		filter->setStartRow( ui.sbStartRow->value() );
-		filter->setEndRow( ui.sbEndRow->value() );
-		filter->setStartColumn( ui.sbStartColumn->value() );
-		filter->setEndColumn( ui.sbEndColumn->value() );
+			if (!selectedHDFNames().isEmpty())
+				filter->setCurrentDataSetName(selectedHDFNames()[0]);
+			filter->setStartRow( ui.sbStartRow->value() );
+			filter->setEndRow( ui.sbEndRow->value() );
+			filter->setStartColumn( ui.sbStartColumn->value() );
+			filter->setEndColumn( ui.sbEndColumn->value() );
 
-		return filter;
-	}
+			return filter;
+		}
 	case FileDataSource::NETCDF: {
-		NetCDFFilter* filter = new NetCDFFilter();
+			NetCDFFilter* filter = new NetCDFFilter();
 
-		if (!selectedNetCDFNames().isEmpty())
-			filter->setCurrentVarName(selectedNetCDFNames()[0]);
-		filter->setStartRow( ui.sbStartRow->value() );
-		filter->setEndRow( ui.sbEndRow->value() );
-		filter->setStartColumn( ui.sbStartColumn->value() );
-		filter->setEndColumn( ui.sbEndColumn->value() );
+			if (!selectedNetCDFNames().isEmpty())
+				filter->setCurrentVarName(selectedNetCDFNames()[0]);
+			filter->setStartRow( ui.sbStartRow->value() );
+			filter->setEndRow( ui.sbEndRow->value() );
+			filter->setStartColumn( ui.sbStartColumn->value() );
+			filter->setEndColumn( ui.sbEndColumn->value() );
 
-		return filter;
-	}
+			return filter;
+		}
+	case FileDataSource::FITS: {
+			FITSFilter* filter = new FITSFilter();
+			filter->setStartRow( ui.sbStartRow->value());
+			filter->setEndRow( ui.sbEndRow->value() );
+			filter->setStartColumn( ui.sbStartColumn->value());
+			filter->setEndColumn( ui.sbEndColumn->value());
+			return filter;
+		}
 	}
 
 	return 0;
@@ -412,15 +442,19 @@ void ImportFileWidget::selectFile() {
 	and activates the corresponding options.
 */
 void ImportFileWidget::fileNameChanged(const QString& name) {
-	QString fileName=name;
-#ifndef _WIN32
+	QString fileName = name;
+#ifndef HAVE_WINDOWS
 	// make relative path
-	if ( !fileName.isEmpty() && fileName.left(1) != QDir::separator()) {
-		fileName=QDir::homePath() + QDir::separator() + fileName;
-	}
+	if ( !fileName.isEmpty() && fileName.left(1) != QDir::separator())
+		fileName = QDir::homePath() + QDir::separator() + fileName;
 #endif
 
 	bool fileExists = QFile::exists(fileName);
+	if (fileExists)
+		ui.kleFileName->setStyleSheet("");
+	else
+		ui.kleFileName->setStyleSheet("QLineEdit{background:red;}");
+
 	ui.gbOptions->setEnabled(fileExists);
 	ui.bFileInfo->setEnabled(fileExists);
 	ui.cbFileType->setEnabled(fileExists);
@@ -430,34 +464,42 @@ void ImportFileWidget::fileNameChanged(const QString& name) {
 	ui.chbWatchFile->setEnabled(fileExists);
 	ui.chbLinkFile->setEnabled(fileExists);
 	if (!fileExists) {
-		refreshPreview();
+		//file doesn't exist -> delete the content preview that is still potentially
+		//available from the previously selected file
+		ui.tePreview->clear();
+		twPreview->clear();
+		hdfOptionsWidget.twContent->clear();
+		hdfOptionsWidget.twPreview->clear();
+		netcdfOptionsWidget.twContent->clear();
+		netcdfOptionsWidget.twPreview->clear();
+		fitsOptionsWidget.twExtensions->clear();
+		fitsOptionsWidget.twPreview->clear();
+
 		emit fileNameChanged();
 		return;
 	}
 
 	QString fileInfo;
-#ifndef _WIN32
+#ifndef HAVE_WINDOWS
 	//check, if we can guess the file type by content
 	QProcess *proc = new QProcess(this);
 	QStringList args;
-	args<<"-b"<<ui.kleFileName->text();
+	args << "-b" << ui.kleFileName->text();
 	proc->start("file", args);
 	if (proc->waitForReadyRead(1000) == false) {
-		qDebug()<<"ERROR: reading file type of file"<<fileName;
+		QDEBUG("ERROR: reading file type of file" << fileName);
 		return;
 	}
 	fileInfo = proc->readLine();
 #endif
 
 	QByteArray imageFormat = QImageReader::imageFormat(fileName);
-	if (fileInfo.contains("compressed data") || fileInfo.contains("ASCII") ||
-			fileName.endsWith("dat", Qt::CaseInsensitive) || fileName.endsWith("txt", Qt::CaseInsensitive)) {
+	if (fileInfo.contains(QLatin1String("compressed data")) || fileInfo.contains(QLatin1String("ASCII")) ||
+	        fileName.endsWith(QLatin1String("dat"), Qt::CaseInsensitive) || fileName.endsWith(QLatin1String("txt"), Qt::CaseInsensitive)) {
 		//probably ascii data
 		ui.cbFileType->setCurrentIndex(FileDataSource::Ascii);
-	} else if (fileInfo.contains("image") || fileInfo.contains("bitmap") || !imageFormat.isEmpty()) {
-		ui.cbFileType->setCurrentIndex(FileDataSource::Image);
-	} else if (fileInfo.contains("Hierarchical Data Format") || fileName.endsWith("h5", Qt::CaseInsensitive) ||
-			fileName.endsWith("hdf", Qt::CaseInsensitive) || fileName.endsWith("hdf5", Qt::CaseInsensitive) ) {
+	} else if (fileInfo.contains(QLatin1String("Hierarchical Data Format")) || fileName.endsWith(QLatin1String("h5"), Qt::CaseInsensitive) ||
+	           fileName.endsWith(QLatin1String("hdf"), Qt::CaseInsensitive) || fileName.endsWith(QLatin1String("hdf5"), Qt::CaseInsensitive) ) {
 		ui.cbFileType->setCurrentIndex(FileDataSource::HDF);
 
 		// update HDF tree widget using current selected file
@@ -466,12 +508,12 @@ void ImportFileWidget::fileNameChanged(const QString& name) {
 		QTreeWidgetItem *rootItem = hdfOptionsWidget.twContent->invisibleRootItem();
 		HDFFilter *filter = (HDFFilter *)this->currentFileFilter();
 		filter->parse(fileName, rootItem);
-		hdfOptionsWidget.twContent->insertTopLevelItem(0,rootItem);
+		hdfOptionsWidget.twContent->insertTopLevelItem(0, rootItem);
 		hdfOptionsWidget.twContent->expandAll();
 		hdfOptionsWidget.twContent->resizeColumnToContents(0);
 		hdfOptionsWidget.twContent->resizeColumnToContents(3);
-	} else if (fileInfo.contains("NetCDF Data Format") || fileName.endsWith("nc", Qt::CaseInsensitive) ||
-			fileName.endsWith("netcdf", Qt::CaseInsensitive) || fileName.endsWith("cdf", Qt::CaseInsensitive)) {
+	} else if (fileInfo.contains(QLatin1String("NetCDF Data Format")) || fileName.endsWith(QLatin1String("nc"), Qt::CaseInsensitive) ||
+	           fileName.endsWith(QLatin1String("netcdf"), Qt::CaseInsensitive) || fileName.endsWith(QLatin1String("cdf"), Qt::CaseInsensitive)) {
 		ui.cbFileType->setCurrentIndex(FileDataSource::NETCDF);
 
 		// update NetCDF tree widget using current selected file
@@ -480,13 +522,23 @@ void ImportFileWidget::fileNameChanged(const QString& name) {
 		QTreeWidgetItem *rootItem = netcdfOptionsWidget.twContent->invisibleRootItem();
 		NetCDFFilter *filter = (NetCDFFilter *)this->currentFileFilter();
 		filter->parse(fileName, rootItem);
-		netcdfOptionsWidget.twContent->insertTopLevelItem(0,rootItem);
+		netcdfOptionsWidget.twContent->insertTopLevelItem(0, rootItem);
 		netcdfOptionsWidget.twContent->expandAll();
 		netcdfOptionsWidget.twContent->resizeColumnToContents(0);
 		netcdfOptionsWidget.twContent->resizeColumnToContents(2);
-	} else {
-		ui.cbFileType->setCurrentIndex(FileDataSource::Binary);	// default
-	}
+	} else if (fileInfo.contains(QLatin1String("FITS image data")) || fileName.endsWith(QLatin1String("fits"), Qt::CaseInsensitive) ||
+	           fileName.endsWith(QLatin1String("fit"), Qt::CaseInsensitive) || fileName.endsWith(QLatin1String("fts"), Qt::CaseInsensitive)) {
+#ifdef HAVE_FITS
+		ui.cbFileType->setCurrentIndex(FileDataSource::FITS);
+#endif
+		fitsOptionsWidget.twExtensions->clear();
+		QString fileName = ui.kleFileName->text();
+		FITSFilter *filter = (FITSFilter *)this->currentFileFilter();
+		filter->parseExtensions(fileName, fitsOptionsWidget.twExtensions, true);
+	} else if (fileInfo.contains("image") || fileInfo.contains("bitmap") || !imageFormat.isEmpty())
+		ui.cbFileType->setCurrentIndex(FileDataSource::Image);
+	else
+		ui.cbFileType->setCurrentIndex(FileDataSource::Binary);
 
 	refreshPreview();
 	emit fileNameChanged();
@@ -498,7 +550,7 @@ void ImportFileWidget::fileNameChanged(const QString& name) {
 void ImportFileWidget::saveFilter() {
 	bool ok;
 	QString text = QInputDialog::getText(this, i18n("Save Filter Settings as"),
-				i18n("Filter name:"), QLineEdit::Normal, i18n("new filter"), &ok);
+	                                     i18n("Filter name:"), QLineEdit::Normal, i18n("new filter"), &ok);
 	if (ok && !text.isEmpty()) {
 		//TODO
 		//AsciiFilter::saveFilter()
@@ -525,8 +577,8 @@ void ImportFileWidget::fileTypeChanged(int fileType) {
 
 	//if we switch from netCDF-format (only two tabs available), add the data preview-tab again
 	if (ui.tabWidget->count() == 2) {
-		ui.tabWidget->setTabText(0,i18n("Data format"));
-		ui.tabWidget->insertTab(1,ui.tabDataPreview,i18n("Preview"));
+		ui.tabWidget->setTabText(0, i18n("Data format"));
+		ui.tabWidget->insertTab(1, ui.tabDataPreview, i18n("Preview"));
 	}
 	ui.lPreviewLines->show();
 	ui.sbPreviewLines->show();
@@ -549,7 +601,7 @@ void ImportFileWidget::fileTypeChanged(int fileType) {
 		ui.lFilter->hide();
 		ui.cbFilter->hide();
 		// hide global preview tab. we have our own
-		ui.tabWidget->setTabText(0,i18n("Data format && preview"));
+		ui.tabWidget->setTabText(0, i18n("Data format && preview"));
 		ui.tabWidget->removeTab(1);
 		ui.tabWidget->setCurrentIndex(0);
 		break;
@@ -559,6 +611,15 @@ void ImportFileWidget::fileTypeChanged(int fileType) {
 		ui.lFilter->hide();
 		ui.cbFilter->hide();
 		break;
+	case FileDataSource::FITS:
+		ui.lFilter->hide();
+		ui.cbFilter->hide();
+		ui.tabWidget->setTabText(0, i18n("Data format && preview"));
+		ui.tabWidget->removeTab(1);
+		ui.tabWidget->setCurrentIndex(0);
+		break;
+	default:
+		DEBUG("unknown file type");
 	}
 
 	hdfOptionsWidget.twContent->clear();
@@ -577,14 +638,20 @@ void ImportFileWidget::fileTypeChanged(int fileType) {
 }
 
 /*!
-	updates the selected data set of a HDF file when the tree widget item is selected
+	updates the selected data set of a HDF file when a new tree widget item is selected
 */
-void ImportFileWidget::hdfTreeWidgetItemSelected(QTreeWidgetItem* item, int column) {
-	Q_UNUSED(column);
-	if (item->data(2, Qt::DisplayRole).toString() == "data set")
+void ImportFileWidget::hdfTreeWidgetSelectionChanged() {
+	DEBUG("hdfTreeWidgetItemSelected()");
+	QDEBUG("SELECTED ITEMS =" << hdfOptionsWidget.twContent->selectedItems());
+
+	if (hdfOptionsWidget.twContent->selectedItems().isEmpty())
+		return;
+
+	QTreeWidgetItem* item = hdfOptionsWidget.twContent->selectedItems().first();
+	if (item->data(2, Qt::DisplayRole).toString() == i18n("data set"))
 		refreshPreview();
 	else
-		qDebug()<<"non data set selected in HDF tree widget";
+		DEBUG("non data set selected in HDF tree widget");
 }
 
 /*!
@@ -592,49 +659,126 @@ void ImportFileWidget::hdfTreeWidgetItemSelected(QTreeWidgetItem* item, int colu
 */
 const QStringList ImportFileWidget::selectedHDFNames() const {
 	QStringList names;
-	QList<QTreeWidgetItem *> items = hdfOptionsWidget.twContent->selectedItems();
+	QList<QTreeWidgetItem*> items = hdfOptionsWidget.twContent->selectedItems();
 
 	// the data link is saved in the second column
-	for (int i=0; i < items.size(); i++)
-		names<<items[i]->data(1,Qt::DisplayRole).toString();
+	foreach (QTreeWidgetItem* item, items)
+		names << item->text(1);
 
 	return names;
 }
 
+//TODO
+void ImportFileWidget::fitsTreeWidgetSelectionChanged() {
+	DEBUG("fitsTreeWidgetItemSelected()");
+	QDEBUG("SELECTED ITEMS =" << fitsOptionsWidget.twExtensions->selectedItems());
+
+	if (fitsOptionsWidget.twExtensions->selectedItems().isEmpty())
+		return;
+
+	QTreeWidgetItem* item = fitsOptionsWidget.twExtensions->selectedItems().first();
+	int column = fitsOptionsWidget.twExtensions->currentColumn();
+
+	WAIT_CURSOR;
+	const QString& itemText = item->text(column);
+	QString selectedExtension;
+	int extType = 0;
+	if (itemText.contains(QLatin1String("IMAGE #")) ||
+	        itemText.contains(QLatin1String("ASCII_TBL #")) ||
+	        itemText.contains(QLatin1String("BINARY_TBL #")))
+		extType = 1;
+	else if (!itemText.compare(i18n("Primary header")))
+		extType = 2;
+	if (extType == 0) {
+		if (item->parent() != 0) {
+			if (item->parent()->parent() != 0)
+				selectedExtension = item->parent()->parent()->text(0) + QLatin1String("[") + item->text(column) + QLatin1String("]");
+		}
+	} else if (extType == 1) {
+		if (item->parent() != 0) {
+			if (item->parent()->parent() != 0) {
+				bool ok;
+				int hduNum = itemText.right(1).toInt(&ok);
+				selectedExtension = item->parent()->parent()->text(0) + QLatin1String("[") + QString::number(hduNum-1) + QLatin1String("]");
+			}
+		}
+	} else {
+		if (item->parent()->parent() != 0)
+			selectedExtension = item->parent()->parent()->text(column);
+	}
+
+	if (!selectedExtension.isEmpty()) {
+		FITSFilter* filter = (FITSFilter*)this->currentFileFilter();
+		bool readFitsTableToMatrix;
+		QList<QStringList> importedStrings = filter->readChdu(selectedExtension, &readFitsTableToMatrix, ui.sbPreviewLines->value());
+		emit checkedFitsTableToMatrix(readFitsTableToMatrix);
+
+		const int rows = importedStrings.size();
+		fitsOptionsWidget.twPreview->clear();
+
+		fitsOptionsWidget.twPreview->setRowCount(rows);
+		int colCount = 0;
+		const int maxColumns = 300;
+		for (int i = 0; i < rows; i++) {
+			QStringList lineString = importedStrings[i];
+			if (i == 0) {
+				colCount = lineString.size() > maxColumns ? maxColumns : lineString.size();
+				fitsOptionsWidget.twPreview->setColumnCount(colCount);
+			}
+			colCount = lineString.size() > maxColumns ? maxColumns : lineString.size();
+
+			for (int j = 0; j < colCount; j++) {
+				QTableWidgetItem* item = new QTableWidgetItem(lineString[j]);
+				fitsOptionsWidget.twPreview->setItem(i, j, item);
+			}
+		}
+		fitsOptionsWidget.twPreview->resizeColumnsToContents();
+	}
+	RESET_CURSOR;
+}
 
 /*!
 	updates the selected var name of a NetCDF file when the tree widget item is selected
 */
-void ImportFileWidget::netcdfTreeWidgetItemSelected(QTreeWidgetItem* item, int column) {
-	Q_UNUSED(column);
-	if (item->data(1, Qt::DisplayRole).toString() == "variable") {
+void ImportFileWidget::netcdfTreeWidgetSelectionChanged() {
+	DEBUG("netcdfTreeWidgetItemSelected()");
+	QDEBUG("SELECTED ITEMS =" << netcdfOptionsWidget.twContent->selectedItems());
+
+	if (netcdfOptionsWidget.twContent->selectedItems().isEmpty())
+		return;
+
+	QTreeWidgetItem* item = netcdfOptionsWidget.twContent->selectedItems().first();
+	if (item->data(1, Qt::DisplayRole).toString() == "variable")
 		refreshPreview();
-	} else if (item->data(1, Qt::DisplayRole).toString().contains("attribute")) {
+	else if (item->data(1, Qt::DisplayRole).toString().contains("attribute")) {
 		// reads attributes (only for preview)
 		NetCDFFilter *filter = (NetCDFFilter *)this->currentFileFilter();
 		QString fileName = ui.kleFileName->text();
-		QString name = item->data(0,Qt::DisplayRole).toString();
-		QString varName = item->data(1,Qt::DisplayRole).toString().split(" ")[0];
+		QString name = item->data(0, Qt::DisplayRole).toString();
+		QString varName = item->data(1, Qt::DisplayRole).toString().split(' ')[0];
+		QDEBUG("name =" << name << "varName =" << varName);
 
-		QString importedText = filter->readAttribute(fileName,name,varName);
-		netcdfOptionsWidget.twPreview->clear();
+		QString importedText = filter->readAttribute(fileName, name, varName);
+		QDEBUG("importedText =" << importedText);
 
-		QStringList lineStrings = importedText.split("\n");
-		netcdfOptionsWidget.twPreview->setRowCount(lineStrings.size());
-		for (int i=0; i < lineStrings.size(); i++) {
-			QStringList lineString = lineStrings[i].split(" ");
-			if (i == 0)
-				netcdfOptionsWidget.twPreview->setColumnCount(lineString.size()-1);
+		QStringList lineStrings = importedText.split('\n');
+		int rows = lineStrings.size();
+		netcdfOptionsWidget.twPreview->setRowCount(rows);
+		netcdfOptionsWidget.twPreview->setColumnCount(0);
+		for (int i = 0; i < rows; i++) {
+			QStringList lineString = lineStrings[i].split(' ');
+			int cols = lineString.size();
+			if (netcdfOptionsWidget.twPreview->columnCount() < cols)
+				netcdfOptionsWidget.twPreview->setColumnCount(cols);
 
-			for (int j=0; j < lineString.size(); j++) {
+			for (int j = 0; j < cols; j++) {
 				QTableWidgetItem* item = new QTableWidgetItem();
 				item->setText(lineString[j]);
-				netcdfOptionsWidget.twPreview->setItem(i,j,item);
+				netcdfOptionsWidget.twPreview->setItem(i, j, item);
 			}
 		}
-	}
-	else
-		qDebug()<<"non showable object selected in NetCDF tree widget";
+	} else
+		DEBUG("non showable object selected in NetCDF tree widget");
 }
 
 /*!
@@ -644,12 +788,21 @@ const QStringList ImportFileWidget::selectedNetCDFNames() const {
 	QStringList names;
 	QList<QTreeWidgetItem *> items = netcdfOptionsWidget.twContent->selectedItems();
 
-	for (int i=0; i < items.size(); i++)
-		names<<items[i]->data(0,Qt::DisplayRole).toString();
+	foreach (QTreeWidgetItem* item, items)
+		names << item->text(0);
 
 	return names;
 }
 
+const QStringList ImportFileWidget::selectedFITSExtensions() const {
+	QStringList extensionNames;
+	//TODO
+	QList<QTreeWidgetItem* > items = fitsOptionsWidget.twExtensions->selectedItems();
+	foreach (QTreeWidgetItem* item, items)
+		extensionNames << item->text(0);
+	return extensionNames;
+}
+
 /*!
 	shows the dialog with the information about the file(s) to be imported.
 */
@@ -665,8 +818,8 @@ void ImportFileWidget::fileInfoDialog() {
 */
 void ImportFileWidget::filterChanged(int index) {
 	// ignore filter for these formats
-	if (ui.cbFileType->currentIndex() == FileDataSource::HDF || ui.cbFileType->currentIndex() == FileDataSource::NETCDF 
-		|| ui.cbFileType->currentIndex() == FileDataSource::Image) {
+	if (ui.cbFileType->currentIndex() == FileDataSource::HDF || ui.cbFileType->currentIndex() == FileDataSource::NETCDF
+	        || ui.cbFileType->currentIndex() == FileDataSource::Image || ui.cbFileType->currentIndex() == FileDataSource::FITS) {
 		ui.swOptions->setEnabled(true);
 		return;
 	}
@@ -699,15 +852,16 @@ void ImportFileWidget::headerChanged(int state) {
 }
 
 void ImportFileWidget::refreshPreview() {
+	DEBUG("refreshPreview()");
 	WAIT_CURSOR;
 
 	QString fileName = ui.kleFileName->text();
-#ifndef _WIN32
+#ifndef HAVE_WINDOWS
 	if (fileName.left(1) != QDir::separator())
 		fileName = QDir::homePath() + QDir::separator() + fileName;
 #endif
 
-	QString importedText;
+	QList<QStringList> importedStrings;
 	FileDataSource::FileType fileType = (FileDataSource::FileType)ui.cbFileType->currentIndex();
 
 	// generic table widget
@@ -718,80 +872,121 @@ void ImportFileWidget::refreshPreview() {
 
 	int lines = ui.sbPreviewLines->value();
 
-	bool ok=true;
-	QTableWidget *tmpTableWidget=0;
+	bool ok = true;
+	QTableWidget *tmpTableWidget = 0;
 	switch (fileType) {
 	case FileDataSource::Ascii: {
-		ui.tePreview->clear();
+			ui.tePreview->clear();
 
-		AsciiFilter *filter = (AsciiFilter *)this->currentFileFilter();
-		importedText = filter->readData(fileName, NULL, AbstractFileFilter::Replace, lines);
-		tmpTableWidget = twPreview;
-		break;
-	}
+			AsciiFilter *filter = (AsciiFilter *)this->currentFileFilter();
+			importedStrings = filter->readData(fileName, NULL, AbstractFileFilter::Replace, lines);
+			tmpTableWidget = twPreview;
+			break;
+		}
 	case FileDataSource::Binary: {
-		ui.tePreview->clear();
+			ui.tePreview->clear();
 
-		BinaryFilter *filter = (BinaryFilter *)this->currentFileFilter();
-		importedText = filter->readData(fileName, NULL, AbstractFileFilter::Replace, lines);
-		tmpTableWidget = twPreview;
-		break;
-	}
+			BinaryFilter *filter = (BinaryFilter *)this->currentFileFilter();
+			importedStrings = filter->readData(fileName, NULL, AbstractFileFilter::Replace, lines);
+			tmpTableWidget = twPreview;
+			break;
+		}
 	case FileDataSource::Image: {
-		ui.tePreview->clear();
+			ui.tePreview->clear();
 
-		QImage image(fileName);
-		QTextCursor cursor = ui.tePreview->textCursor();
-		cursor.insertImage(image);
-		RESET_CURSOR;
-		return;
-	}
+			QImage image(fileName);
+			QTextCursor cursor = ui.tePreview->textCursor();
+			cursor.insertImage(image);
+			RESET_CURSOR;
+			return;
+		}
 	case FileDataSource::HDF: {
-		HDFFilter *filter = (HDFFilter *)this->currentFileFilter();
-		lines = hdfOptionsWidget.sbPreviewLines->value();
-		importedText = filter->readCurrentDataSet(fileName, NULL, ok, AbstractFileFilter::Replace, lines);
-		tmpTableWidget = hdfOptionsWidget.twPreview;
-		break;
-	}
+			HDFFilter *filter = (HDFFilter *)this->currentFileFilter();
+			lines = hdfOptionsWidget.sbPreviewLines->value();
+			importedStrings = filter->readCurrentDataSet(fileName, NULL, ok, AbstractFileFilter::Replace, lines);
+			tmpTableWidget = hdfOptionsWidget.twPreview;
+			break;
+		}
 	case FileDataSource::NETCDF: {
-		NetCDFFilter *filter = (NetCDFFilter *)this->currentFileFilter();
-		lines = netcdfOptionsWidget.sbPreviewLines->value();
-		importedText = filter->readCurrentVar(fileName, NULL, AbstractFileFilter::Replace, lines);
-		tmpTableWidget = netcdfOptionsWidget.twPreview;
-		break;
-	}
+			NetCDFFilter *filter = (NetCDFFilter *)this->currentFileFilter();
+			lines = netcdfOptionsWidget.sbPreviewLines->value();
+			importedStrings = filter->readCurrentVar(fileName, NULL, AbstractFileFilter::Replace, lines);
+			tmpTableWidget = netcdfOptionsWidget.twPreview;
+			break;
+		}
+	case FileDataSource::FITS: {
+			FITSFilter* filter = (FITSFilter*)this->currentFileFilter();
+			lines = fitsOptionsWidget.sbPreviewLines->value();
+			if (fitsOptionsWidget.twExtensions->currentItem() != 0) {
+				const QTreeWidgetItem* item = fitsOptionsWidget.twExtensions->currentItem();
+				const int currentColumn = fitsOptionsWidget.twExtensions->currentColumn();
+				QString itemText = item->text(currentColumn);
+				int extType = 0;
+				if (itemText.contains(QLatin1String("IMAGE #")) ||
+				        itemText.contains(QLatin1String("ASCII_TBL #")) ||
+				        itemText.contains(QLatin1String("BINARY_TBL #")))
+					extType = 1;
+				else if (!itemText.compare(i18n("Primary header")))
+					extType = 2;
+				if (extType == 0) {
+					if (item->parent() != 0) {
+						if (item->parent()->parent() != 0)
+							fileName = item->parent()->parent()->text(0) + QLatin1String("[")+ item->text(currentColumn) + QLatin1String("]");
+					}
+				} else if (extType == 1) {
+					if (item->parent() != 0) {
+						if (item->parent()->parent() != 0) {
+							bool ok;
+							int hduNum = itemText.right(1).toInt(&ok);
+							fileName = item->parent()->parent()->text(0) + QLatin1String("[") + QString::number(hduNum-1) + QLatin1String("]");
+						}
+					}
+				} else {
+					if (item->parent()->parent() != 0)
+						fileName = item->parent()->parent()->text(currentColumn);
+				}
+			}
+			bool readFitsTableToMatrix;
+			importedStrings = filter->readChdu(fileName, &readFitsTableToMatrix, lines);
+			emit checkedFitsTableToMatrix(readFitsTableToMatrix);
+
+			tmpTableWidget = fitsOptionsWidget.twPreview;
+			break;
+		}
 	}
 
 	// fill the table widget
-	if (!importedText.isEmpty()) {
-		tmpTableWidget->clear();
-
+	tmpTableWidget->setRowCount(0);
+	tmpTableWidget->setColumnCount(0);
+	if( !importedStrings.isEmpty() ) {
+		QDEBUG("importedStrings =" << importedStrings);	// new
 		if (!ok) {
-			// show importedText as error message
+			// show imported strings as error message
 			tmpTableWidget->setRowCount(1);
 			tmpTableWidget->setColumnCount(1);
 			QTableWidgetItem* item = new QTableWidgetItem();
-			item->setText(importedText);
-			tmpTableWidget->setItem(0,0,item);
+			item->setText(importedStrings[0][0]);
+			tmpTableWidget->setItem(0, 0, item);
 		} else {
+			//TODO: maxrows not used
+			const int rows = qMax(importedStrings.size(), 1);
+			const int maxColumns = 300;
+			tmpTableWidget->setRowCount(rows);	// new
+			for (int i = 0; i < rows; i++) {
+				QDEBUG(importedStrings[i]);
 
-			QStringList lineStrings = importedText.split("\n");
-			tmpTableWidget->setRowCount(qMax(lineStrings.size()-1,1));
-			for (int i=0; i < lineStrings.size(); i++) {
-				QStringList lineString = lineStrings[i].split(" ");
-				if (i == 0)
-					tmpTableWidget->setColumnCount(qMax(lineString.size()-1, 1));
+				int cols = importedStrings[i].size() > maxColumns ? maxColumns : importedStrings[i].size();	// new
+				if (cols > tmpTableWidget->columnCount())
+					tmpTableWidget->setColumnCount(cols);
 
-				for (int j=0; j < lineString.size(); j++) {
-					QTableWidgetItem* item = new QTableWidgetItem();
-					item->setText(lineString[j]);
-					tmpTableWidget->setItem(i,j,item);
+				for (int j = 0; j < cols; j++) {
+					QTableWidgetItem* item = new QTableWidgetItem(importedStrings[i][j]);
+					tmpTableWidget->setItem(i, j, item);
 				}
 			}
 		}
 
 		tmpTableWidget->horizontalHeader()->resizeSections(QHeaderView::ResizeToContents);
 	}
-
 	RESET_CURSOR;
 }
