@@ -47,7 +47,6 @@
 
   \ingroup kdefrontend
 */
-
 CartesianPlotLegendDock::CartesianPlotLegendDock(QWidget *parent): QWidget(parent),
 	m_legend(0),
 	labelWidget(0),
@@ -238,10 +237,10 @@ void CartesianPlotLegendDock::retranslateUi() {
 	ui.cbBackgroundType->addItem(i18n("pattern"));
 
 	ui.cbBackgroundColorStyle->addItem(i18n("single color"));
-	ui.cbBackgroundColorStyle->addItem(i18n("horizontal linear gradient"));
-	ui.cbBackgroundColorStyle->addItem(i18n("vertical linear gradient"));
-	ui.cbBackgroundColorStyle->addItem(i18n("diagonal linear gradient (start from top left)"));
-	ui.cbBackgroundColorStyle->addItem(i18n("diagonal linear gradient (start from bottom left)"));
+	ui.cbBackgroundColorStyle->addItem(i18n("horizontal gradient"));
+	ui.cbBackgroundColorStyle->addItem(i18n("vertical gradient"));
+	ui.cbBackgroundColorStyle->addItem(i18n("diag. gradient (from top left)"));
+	ui.cbBackgroundColorStyle->addItem(i18n("diag. gradient (from bottom left)"));
 	ui.cbBackgroundColorStyle->addItem(i18n("radial gradient"));
 
 	ui.cbBackgroundImageStyle->addItem(i18n("scaled and cropped"));
@@ -414,7 +413,7 @@ void CartesianPlotLegendDock::backgroundTypeChanged(int index) {
 			ui.lBackgroundSecondColor->hide();
 			ui.kcbBackgroundSecondColor->hide();
 		}else{
-			ui.lBackgroundFirstColor->setText(i18n("First Color"));
+			ui.lBackgroundFirstColor->setText(i18n("First color"));
 			ui.lBackgroundSecondColor->show();
 			ui.kcbBackgroundSecondColor->show();
 		}
@@ -466,7 +465,7 @@ void CartesianPlotLegendDock::backgroundColorStyleChanged(int index) {
 		ui.lBackgroundSecondColor->hide();
 		ui.kcbBackgroundSecondColor->hide();
 	}else{
-		ui.lBackgroundFirstColor->setText(i18n("First Color"));
+		ui.lBackgroundFirstColor->setText(i18n("First color"));
 		ui.lBackgroundSecondColor->show();
 		ui.kcbBackgroundSecondColor->show();
 		ui.lBackgroundBrushStyle->hide();
@@ -510,7 +509,7 @@ void CartesianPlotLegendDock::backgroundSecondColorChanged(const QColor& c) {
 	if (m_initializing)
 		return;
 
-	foreach(CartesianPlotLegend* legend, m_legendList)
+	foreach (CartesianPlotLegend* legend, m_legendList)
 		legend->setBackgroundSecondColor(c);
 }
 
@@ -522,7 +521,7 @@ void CartesianPlotLegendDock::selectFile() {
 	QString dir = conf.readEntry("LastImageDir", "");
 
 	QString formats;
-	foreach(const QByteArray format, QImageReader::supportedImageFormats()) {
+	foreach (const QByteArray& format, QImageReader::supportedImageFormats()) {
 		QString f = "*." + QString(format.constData());
 		formats.isEmpty() ? formats+=f : formats+=' '+f;
 	}
@@ -532,15 +531,15 @@ void CartesianPlotLegendDock::selectFile() {
 		return; //cancel was clicked in the file-dialog
 
 	int pos = path.lastIndexOf(QDir::separator());
-	if (pos!=-1) {
+	if (pos != -1) {
 		QString newDir = path.left(pos);
-		if (newDir!=dir)
+		if (newDir != dir)
 			conf.writeEntry("LastImageDir", newDir);
 	}
 
     ui.kleBackgroundFileName->setText( path );
 
-	foreach(CartesianPlotLegend* legend, m_legendList)
+	foreach (CartesianPlotLegend* legend, m_legendList)
 		legend->setBackgroundFileName(path);
 }
 
@@ -549,7 +548,12 @@ void CartesianPlotLegendDock::fileNameChanged() {
 		return;
 
 	QString fileName = ui.kleBackgroundFileName->text();
-	foreach(CartesianPlotLegend* legend, m_legendList)
+	if (!fileName.isEmpty() && !QFile::exists(fileName))
+		ui.kleBackgroundFileName->setStyleSheet("QLineEdit{background:red;}");
+	else
+		ui.kleBackgroundFileName->setStyleSheet("");
+
+	foreach (CartesianPlotLegend* legend, m_legendList)
 		legend->setBackgroundFileName(fileName);
 }
 
@@ -558,7 +562,7 @@ void CartesianPlotLegendDock::backgroundOpacityChanged(int value) {
 		return;
 
 	float opacity = (float)value/100.;
-	foreach(CartesianPlotLegend* legend, m_legendList)
+	foreach (CartesianPlotLegend* legend, m_legendList)
 		legend->setBackgroundOpacity(opacity);
 }
 
@@ -569,8 +573,8 @@ void CartesianPlotLegendDock::borderStyleChanged(int index) {
 
 	Qt::PenStyle penStyle=Qt::PenStyle(index);
 	QPen pen;
-	foreach(CartesianPlotLegend* legend, m_legendList) {
-		pen=legend->borderPen();
+	foreach (CartesianPlotLegend* legend, m_legendList) {
+		pen = legend->borderPen();
 		pen.setStyle(penStyle);
 		legend->setBorderPen(pen);
 	}
@@ -581,15 +585,15 @@ void CartesianPlotLegendDock::borderColorChanged(const QColor& color) {
 		return;
 
 	QPen pen;
-	foreach(CartesianPlotLegend* legend, m_legendList) {
-		pen=legend->borderPen();
+	foreach (CartesianPlotLegend* legend, m_legendList) {
+		pen = legend->borderPen();
 		pen.setColor(color);
 		legend->setBorderPen(pen);
 	}
 
-	m_initializing=true;
+	m_initializing = true;
 	GuiTools::updatePenStyles(ui.cbBorderStyle, color);
-	m_initializing=false;
+	m_initializing = false;
 }
 
 void CartesianPlotLegendDock::borderWidthChanged(double value) {
@@ -597,8 +601,8 @@ void CartesianPlotLegendDock::borderWidthChanged(double value) {
 		return;
 
 	QPen pen;
-	foreach(CartesianPlotLegend* legend, m_legendList) {
-		pen=legend->borderPen();
+	foreach (CartesianPlotLegend* legend, m_legendList) {
+		pen = legend->borderPen();
 		pen.setWidthF( Worksheet::convertToSceneUnits(value, Worksheet::Point) );
 		legend->setBorderPen(pen);
 	}
@@ -608,7 +612,7 @@ void CartesianPlotLegendDock::borderCornerRadiusChanged(double value) {
 	if (m_initializing)
 		return;
 
-	foreach(CartesianPlotLegend* legend, m_legendList)
+	foreach (CartesianPlotLegend* legend, m_legendList)
 		legend->setBorderCornerRadius(Worksheet::convertToSceneUnits(value, Worksheet::Centimeter));
 }
 
@@ -617,7 +621,7 @@ void CartesianPlotLegendDock::borderOpacityChanged(int value) {
 		return;
 
 	float opacity = (float)value/100.;
-	foreach(CartesianPlotLegend* legend, m_legendList)
+	foreach (CartesianPlotLegend* legend, m_legendList)
 		legend->setBorderOpacity(opacity);
 }
 
@@ -626,7 +630,7 @@ void CartesianPlotLegendDock::layoutTopMarginChanged(double margin) {
 	if (m_initializing)
 		return;
 
-	foreach(CartesianPlotLegend* legend, m_legendList)
+	foreach (CartesianPlotLegend* legend, m_legendList)
 		legend->setLayoutTopMargin(Worksheet::convertToSceneUnits(margin, Worksheet::Centimeter));
 }
 
@@ -634,7 +638,7 @@ void CartesianPlotLegendDock::layoutBottomMarginChanged(double margin) {
 	if (m_initializing)
 		return;
 
-	foreach(CartesianPlotLegend* legend, m_legendList)
+	foreach (CartesianPlotLegend* legend, m_legendList)
 		legend->setLayoutBottomMargin(Worksheet::convertToSceneUnits(margin, Worksheet::Centimeter));
 }
 
@@ -642,7 +646,7 @@ void CartesianPlotLegendDock::layoutLeftMarginChanged(double margin) {
 	if (m_initializing)
 		return;
 
-	foreach(CartesianPlotLegend* legend, m_legendList)
+	foreach (CartesianPlotLegend* legend, m_legendList)
 		legend->setLayoutLeftMargin(Worksheet::convertToSceneUnits(margin, Worksheet::Centimeter));
 }
 
@@ -650,7 +654,7 @@ void CartesianPlotLegendDock::layoutRightMarginChanged(double margin) {
 	if (m_initializing)
 		return;
 
-	foreach(CartesianPlotLegend* legend, m_legendList)
+	foreach (CartesianPlotLegend* legend, m_legendList)
 		legend->setLayoutRightMargin(Worksheet::convertToSceneUnits(margin, Worksheet::Centimeter));
 }
 
@@ -658,7 +662,7 @@ void CartesianPlotLegendDock::layoutHorizontalSpacingChanged(double spacing) {
 	if (m_initializing)
 		return;
 
-	foreach(CartesianPlotLegend* legend, m_legendList)
+	foreach (CartesianPlotLegend* legend, m_legendList)
 		legend->setLayoutHorizontalSpacing(Worksheet::convertToSceneUnits(spacing, Worksheet::Centimeter));
 }
 
@@ -666,7 +670,7 @@ void CartesianPlotLegendDock::layoutVerticalSpacingChanged(double spacing) {
 	if (m_initializing)
 		return;
 
-	foreach(CartesianPlotLegend* legend, m_legendList)
+	foreach (CartesianPlotLegend* legend, m_legendList)
 		legend->setLayoutVerticalSpacing(Worksheet::convertToSceneUnits(spacing, Worksheet::Centimeter));
 }
 
@@ -677,7 +681,7 @@ void CartesianPlotLegendDock::layoutColumnCountChanged(int count) {
 	if (m_initializing)
 		return;
 
-	foreach(CartesianPlotLegend* legend, m_legendList)
+	foreach (CartesianPlotLegend* legend, m_legendList)
 		legend->setLayoutColumnCount(count);
 }
 
@@ -895,6 +899,12 @@ void CartesianPlotLegendDock::load() {
 	ui.kcbBackgroundSecondColor->setColor( m_legend->backgroundSecondColor() );
 	ui.sbBackgroundOpacity->setValue( round(m_legend->backgroundOpacity()*100.0) );
 
+	//highlight the text field for the background image red if an image is used and cannot be found
+	if (!m_legend->backgroundFileName().isEmpty() && !QFile::exists(m_legend->backgroundFileName()))
+		ui.kleBackgroundFileName->setStyleSheet("QLineEdit{background:red;}");
+	else
+		ui.kleBackgroundFileName->setStyleSheet("");
+
 	//Border
 	ui.kcbBorderColor->setColor( m_legend->borderPen().color() );
 	ui.cbBorderStyle->setCurrentIndex( (int) m_legend->borderPen().style() );
