@@ -1,5 +1,5 @@
 /***************************************************************************
-    File             : XYEquationCurveDock.h
+    File             : XYEquationCurveDock.cpp
     Project          : LabPlot
     --------------------------------------------------------------------
     Copyright        : (C) 2014 Alexander Semke (alexander.semke@web.de)
@@ -54,7 +54,8 @@
 */
 
 XYEquationCurveDock::XYEquationCurveDock(QWidget *parent): XYCurveDock(parent), m_equationCurve(0) {
-
+	//remove the tab "Error bars"
+	ui.tabWidget->removeTab(5);
 }
 
 /*!
