@@ -111,6 +111,9 @@ void XYInterpolationCurveDock::setupGeneral() {
 	connect( uiGeneralTab.leName, SIGNAL(returnPressed()), this, SLOT(nameChanged()) );
 	connect( uiGeneralTab.leComment, SIGNAL(returnPressed()), this, SLOT(commentChanged()) );
 	connect( uiGeneralTab.chkVisible, SIGNAL(clicked(bool)), this, SLOT(visibilityChanged(bool)) );
+	connect( uiGeneralTab.cbAutoRange, SIGNAL(clicked(bool)), this, SLOT(autoRangeChanged()) );
+	connect( uiGeneralTab.sbMin, SIGNAL(valueChanged(double)), this, SLOT(xRangeMinChanged()) );
+	connect( uiGeneralTab.sbMax, SIGNAL(valueChanged(double)), this, SLOT(xRangeMaxChanged()) );
 
 	connect( uiGeneralTab.cbType, SIGNAL(currentIndexChanged(int)), this, SLOT(typeChanged()) );
 	connect( uiGeneralTab.cbVariant, SIGNAL(currentIndexChanged(int)), this, SLOT(variantChanged()) );
@@ -149,6 +152,10 @@ void XYInterpolationCurveDock::initGeneralTab() {
 	Q_ASSERT(m_interpolationCurve);
 	XYCurveDock::setModelIndexFromColumn(cbXDataColumn, m_interpolationCurve->xDataColumn());
 	XYCurveDock::setModelIndexFromColumn(cbYDataColumn, m_interpolationCurve->yDataColumn());
+	uiGeneralTab.cbAutoRange->setChecked(m_interpolationData.autoRange);
+	uiGeneralTab.sbMin->setValue(m_interpolationData.xRange.first());
+	uiGeneralTab.sbMax->setValue(m_interpolationData.xRange.last());
+	this->autoRangeChanged();
 	// update list of selectable types
 	xDataColumnChanged(cbXDataColumn->currentModelIndex());
 
@@ -254,6 +261,11 @@ void XYInterpolationCurveDock::xDataColumnChanged(const QModelIndex& index) {
 
 	// disable types that need more data points
 	if (column != 0) {
+		if (uiGeneralTab.cbAutoRange->isChecked()) {
+			uiGeneralTab.sbMin->setValue(column->minimum());
+			uiGeneralTab.sbMax->setValue(column->maximum());
+		}
+
 		unsigned int n=0;
 		for (int row=0; row < column->rowCount(); row++)
 			if (!std::isnan(column->valueAt(row)) && !column->isMasked(row)) 
@@ -337,6 +349,43 @@ void XYInterpolationCurveDock::yDataColumnChanged(const QModelIndex& index) {
 		dynamic_cast<XYInterpolationCurve*>(curve)->setYDataColumn(column);
 }
 
+void XYInterpolationCurveDock::autoRangeChanged() {
+	bool autoRange = uiGeneralTab.cbAutoRange->isChecked();
+	m_interpolationData.autoRange = autoRange;
+
+	if (autoRange) {
+		uiGeneralTab.lMin->setEnabled(false);
+		uiGeneralTab.sbMin->setEnabled(false);
+		uiGeneralTab.lMax->setEnabled(false);
+		uiGeneralTab.sbMax->setEnabled(false);
+		m_interpolationCurve = dynamic_cast<XYInterpolationCurve*>(m_curve);
+		Q_ASSERT(m_interpolationCurve);
+		if (m_interpolationCurve->xDataColumn()) {
+			uiGeneralTab.sbMin->setValue(m_interpolationCurve->xDataColumn()->minimum());
+			uiGeneralTab.sbMax->setValue(m_interpolationCurve->xDataColumn()->maximum());
+		}
+	} else {
+		uiGeneralTab.lMin->setEnabled(true);
+		uiGeneralTab.sbMin->setEnabled(true);
+		uiGeneralTab.lMax->setEnabled(true);
+		uiGeneralTab.sbMax->setEnabled(true);
+	}
+
+}
+void XYInterpolationCurveDock::xRangeMinChanged() {
+	double xMin = uiGeneralTab.sbMin->value();
+
+	m_interpolationData.xRange.first() = xMin;
+	uiGeneralTab.pbRecalculate->setEnabled(true);
+}
+
+void XYInterpolationCurveDock::xRangeMaxChanged() {
+	double xMax = uiGeneralTab.sbMax->value();
+
+	m_interpolationData.xRange.last() = xMax;
+	uiGeneralTab.pbRecalculate->setEnabled(true);
+}
+
 void XYInterpolationCurveDock::typeChanged() {
 	nsl_interp_type type = (nsl_interp_type)uiGeneralTab.cbType->currentIndex();
 	m_interpolationData.type = type;
@@ -346,7 +395,16 @@ void XYInterpolationCurveDock::typeChanged() {
 		uiGeneralTab.lVariant->show();
 		uiGeneralTab.cbVariant->show();
 		break;
-	default:
+	case nsl_interp_type_linear:
+	case nsl_interp_type_polynomial:
+	case nsl_interp_type_cspline:
+	case nsl_interp_type_cspline_periodic:
+	case nsl_interp_type_akima:
+	case nsl_interp_type_akima_periodic:
+	case nsl_interp_type_steffen:
+	case nsl_interp_type_cosine:
+	case nsl_interp_type_exponential:
+	case nsl_interp_type_rational:
 		uiGeneralTab.lVariant->hide();
 		uiGeneralTab.cbVariant->hide();
 		uiGeneralTab.cbVariant->setCurrentIndex(nsl_interp_pch_variant_finite_difference);
