@@ -30,7 +30,9 @@
 
 #include <QFileDialog>
 #include <QStandardItemModel>
+
 #include <KMessageBox>
+#include <KUrlCompletion>
 
 /*!
 	\class ExportSpreadsheetDialog
@@ -38,18 +40,18 @@
 
 	\ingroup kdefrontend
 */
-
 ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : KDialog(parent),
-    m_matrixMode(false), urlCompletion(new KUrlCompletion) {
+	m_matrixMode(false), m_format(Format::ASCII), urlCompletion(new KUrlCompletion) {
 	mainWidget = new QWidget(this);
 	ui.setupUi(mainWidget);
 	ui.gbOptions->hide();
 
-    ui.kleFileName->setCompletionObject(urlCompletion);
+	ui.kleFileName->setCompletionObject(urlCompletion);
 
 	ui.cbFormat->addItem("ASCII");
 	ui.cbFormat->addItem("Binary");
 	ui.cbFormat->addItem("LaTeX");
+	ui.cbFormat->addItem("FITS");
 
 	ui.cbSeparator->addItem("TAB");
 	ui.cbSeparator->addItem("SPACE");
@@ -76,11 +78,13 @@ ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : KDialog(pare
 	connect( ui.kleFileName, SIGNAL(textChanged(QString)), this, SLOT(fileNameChanged(QString)) );
 	connect(this,SIGNAL(user1Clicked()), this, SLOT(toggleOptions()));
 	connect(ui.cbFormat, SIGNAL(currentIndexChanged(int)), this, SLOT(formatChanged(int)));
+	connect(ui.cbExportToFITS, SIGNAL(currentIndexChanged(int)), this, SLOT(fitsExportToChanged(int)));
 
 	setCaption(i18n("Export spreadsheet"));
 	setWindowIcon(KIcon("document-export-database"));
 
 	//restore saved settings
+
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportSpreadsheetDialog");
 	ui.cbFormat->setCurrentIndex(conf.readEntry("Format", 0));
 	ui.chkExportHeader->setChecked(conf.readEntry("Header", true));
@@ -92,7 +96,8 @@ ExportSpreadsheetDialog::ExportSpreadsheetDialog(QWidget* parent) : KDialog(pare
 	ui.cbLaTeXExport->setCurrentIndex(conf.readEntry("ExportOnly", 0));
 	ui.chkMatrixHHeader->setChecked(conf.readEntry("MatrixHorizontalHeader", true));
 	ui.chkMatrixVHeader->setChecked(conf.readEntry("MatrixVerticalHeader", true));
-
+	ui.chkMatrixVHeader->setChecked(conf.readEntry("FITSSpreadsheetColumnsUnits", true));
+	ui.cbExportToFITS->setCurrentIndex(conf.readEntry("FITSTo", 0));
 	m_showOptions = conf.readEntry("ShowOptions", false);
 	ui.gbOptions->setVisible(m_showOptions);
 	m_showOptions ? setButtonText(KDialog::User1,i18n("Hide Options")) : setButtonText(KDialog::User1,i18n("Show Options"));
@@ -113,9 +118,11 @@ ExportSpreadsheetDialog::~ExportSpreadsheetDialog() {
 	conf.writeEntry("ExportOnly", ui.cbLaTeXExport->currentIndex());
 	conf.writeEntry("MatrixVerticalHeader", ui.chkMatrixVHeader->isChecked());
 	conf.writeEntry("MatrixHorizontalHeader", ui.chkMatrixHHeader->isChecked());
+	conf.writeEntry("FITSTo", ui.cbExportToFITS->currentIndex());
+	conf.writeEntry("FITSSpreadsheetColumnsUnits", ui.chkColumnsAsUnits->isChecked());
 
 	saveDialogSize(conf);
-    delete urlCompletion;
+	delete urlCompletion;
 }
 
 void ExportSpreadsheetDialog::setFileName(const QString& name) {
@@ -126,6 +133,18 @@ void ExportSpreadsheetDialog::setFileName(const QString& name) {
 	this->formatChanged(ui.cbFormat->currentIndex());
 }
 
+void ExportSpreadsheetDialog::fitsExportToChanged(int idx) {
+	if (idx == 0) {
+		ui.chkColumnsAsUnits->hide();
+		ui.lColumnAsUnits->hide();
+	} else {
+		if (!m_matrixMode) {
+			ui.chkColumnsAsUnits->show();
+			ui.lColumnAsUnits->show();
+		}
+	}
+}
+
 void ExportSpreadsheetDialog::setMatrixMode(bool b) {
 	if (b) {
 		setCaption(i18n("Export matrix"));
@@ -133,13 +152,20 @@ void ExportSpreadsheetDialog::setMatrixMode(bool b) {
 		ui.chkExportHeader->hide();
 		ui.lEmptyRows->hide();
 		ui.chkEmptyRows->hide();
-		ui.chkMatrixHHeader->show();
-		ui.chkMatrixVHeader->show();
-		ui.lMatrixHHeader->show();
-		ui.lMatrixVHeader->show();
+		if (ui.cbFormat->currentIndex() != 3) {
+			ui.chkMatrixHHeader->show();
+			ui.chkMatrixVHeader->show();
+			ui.lMatrixHHeader->show();
+			ui.lMatrixVHeader->show();
+		}
+
 		ui.lHeader->hide();
 		ui.chkHeaders->hide();
 		ui.cbLaTeXExport->setItemText(0,i18n("Export matrix"));
+		ui.cbExportToFITS->setCurrentIndex(0);
+
+		ui.lColumnAsUnits->hide();
+		ui.chkColumnsAsUnits->hide();
 
 		m_matrixMode = b;
 	}
@@ -149,6 +175,10 @@ QString ExportSpreadsheetDialog::path() const {
 	return ui.kleFileName->text();
 }
 
+int ExportSpreadsheetDialog::exportToFits() const {
+	return ui.cbExportToFITS->currentIndex();
+}
+
 bool ExportSpreadsheetDialog::exportHeader() const {
 	return ui.chkExportHeader->isChecked();
 }
@@ -185,6 +215,10 @@ bool ExportSpreadsheetDialog::matrixVerticalHeader() const {
 	return ui.chkMatrixVHeader->isChecked();
 }
 
+bool ExportSpreadsheetDialog::commentsAsUnitsFits() const {
+	return ui.chkColumnsAsUnits->isChecked();
+}
+
 QString ExportSpreadsheetDialog::separator() const {
 	return ui.cbSeparator->currentText();
 }
@@ -196,14 +230,21 @@ void ExportSpreadsheetDialog::slotButtonClicked(int button) {
 		KDialog::slotButtonClicked(button);
 }
 
+void ExportSpreadsheetDialog::setExportToImage(bool possible) {
+	if (!possible) {
+		ui.cbExportToFITS->setCurrentIndex(1);
+		ui.cbExportToFITS->setItemData(0, 0, Qt::UserRole - 1);
+	}
+}
+
 //SLOTS
 void ExportSpreadsheetDialog::okClicked() {
-	if ( QFile::exists(ui.kleFileName->text()) ) {
-		int r=KMessageBox::questionYesNo(this, i18n("The file already exists. Do you really want to overwrite it?"), i18n("Export"));
-		if (r==KMessageBox::No)
-			return;
-	}
-
+	if (format() != FITS)
+		if ( QFile::exists(ui.kleFileName->text()) ) {
+			int r=KMessageBox::questionYesNo(this, i18n("The file already exists. Do you really want to overwrite it?"), i18n("Export"));
+			if (r==KMessageBox::No)
+				return;
+		}
 	KConfigGroup conf(KSharedConfig::openConfig(), "ExportSpreadsheetDialog");
 	conf.writeEntry("Format", ui.cbFormat->currentIndex());
 	conf.writeEntry("Header", ui.chkExportHeader->isChecked());
@@ -261,23 +302,23 @@ void ExportSpreadsheetDialog::selectFile() {
  */
 void ExportSpreadsheetDialog::formatChanged(int index) {
 	QStringList extensions;
-	extensions<<".txt"<<".bin" << ".tex";
-    QString path = ui.kleFileName->text();
-    int i = path.indexOf(".");
-    if (index != -1) {
-        if (i==-1)
-            path = path + extensions.at(index);
-        else
-            path=path.left(i) + extensions.at(index);
-    }
-    if (ui.cbFormat->currentIndex() == 2) {
-        ui.cbSeparator->hide();
-        ui.lSeparator->hide();
+	extensions << ".txt" << ".bin" << ".tex" << ".fits";
+	QString path = ui.kleFileName->text();
+	int i = path.indexOf(".");
+	if (index != 1) {
+		if (i==-1)
+			path = path + extensions.at(index);
+		else
+			path=path.left(i) + extensions.at(index);
+	}
+	if (ui.cbFormat->currentIndex() == 2) {
+		ui.cbSeparator->hide();
+		ui.lSeparator->hide();
 
-        ui.chkCaptions->show();
-        ui.chkGridLines->show();;
-        ui.lExportArea->show();
-        ui.lGridLines->show();
+		ui.chkCaptions->show();
+		ui.chkGridLines->show();;
+		ui.lExportArea->show();
+		ui.lGridLines->show();
 		ui.lCaptions->show();
 		ui.cbLaTeXExport->show();
 
@@ -286,16 +327,47 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 			ui.chkHeaders->show();
 			ui.lEmptyRows->show();
 			ui.chkEmptyRows->show();
-            ui.lMatrixHHeader->hide();
-            ui.lMatrixVHeader->hide();
-            ui.chkMatrixHHeader->hide();
-            ui.chkMatrixVHeader->hide();
+			ui.lMatrixHHeader->hide();
+			ui.lMatrixVHeader->hide();
+			ui.chkMatrixHHeader->hide();
+			ui.chkMatrixVHeader->hide();
 		} else {
 			ui.lMatrixHHeader->show();
 			ui.lMatrixVHeader->show();
 			ui.chkMatrixHHeader->show();
 			ui.chkMatrixVHeader->show();
 		}
+		ui.cbExportToFITS->hide();
+		ui.lExportToFITS->hide();
+		ui.lColumnAsUnits->hide();
+		ui.chkColumnsAsUnits->hide();
+		//FITS
+	} else if(ui.cbFormat->currentIndex() == 3) {
+		ui.lCaptions->hide();
+		ui.lEmptyRows->hide();
+		ui.lExportArea->hide();
+		ui.lGridLines->hide();
+		ui.lMatrixHHeader->hide();
+		ui.lMatrixVHeader->hide();
+		ui.lSeparator->hide();
+		ui.lHeader->hide();
+		ui.chkEmptyRows->hide();
+		ui.chkHeaders->hide();
+		ui.chkExportHeader->hide();
+		ui.lExportHeader->hide();
+		ui.chkGridLines->hide();
+		ui.chkMatrixHHeader->hide();
+		ui.chkMatrixVHeader->hide();
+		ui.chkCaptions->hide();
+		ui.cbLaTeXExport->hide();
+		ui.cbSeparator->hide();
+
+		ui.cbExportToFITS->show();
+		ui.lExportToFITS->show();
+		if (!m_matrixMode) {
+			ui.lColumnAsUnits->show();
+			ui.chkColumnsAsUnits->show();
+		}
 	} else {
 		ui.cbSeparator->show();
 		ui.lSeparator->show();
@@ -315,6 +387,11 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 
 		ui.lHeader->hide();
 		ui.chkHeaders->hide();
+
+		ui.cbExportToFITS->hide();
+		ui.lExportToFITS->hide();
+		ui.lColumnAsUnits->hide();
+		ui.chkColumnsAsUnits->hide();
 	}
 
 	if (!m_matrixMode) {
@@ -324,23 +401,31 @@ void ExportSpreadsheetDialog::formatChanged(int index) {
 		ui.chkExportHeader->hide();
 		ui.lExportHeader->hide();
 	}
+	if (ui.cbFormat->currentIndex() == 3) {
+		ui.chkExportHeader->hide();
+		ui.lExportHeader->hide();
+	}
 
 	setFormat(static_cast<Format>(index));
 	ui.kleFileName->setText(path);
 }
 
 void ExportSpreadsheetDialog::setExportSelection(bool enable) {
-    if (!enable) {
-        const QStandardItemModel* areaToExportModel = qobject_cast<const QStandardItemModel*>(ui.cbLaTeXExport->model());
-        QStandardItem* item = areaToExportModel->item(1);
-        item->setFlags(item->flags() & ~(Qt::ItemIsSelectable|Qt::ItemIsEnabled));
-    }
+	if (!enable) {
+		const QStandardItemModel* areaToExportModel = qobject_cast<const QStandardItemModel*>(ui.cbLaTeXExport->model());
+		QStandardItem* item = areaToExportModel->item(1);
+		item->setFlags(item->flags() & ~(Qt::ItemIsSelectable|Qt::ItemIsEnabled));
+	}
 }
 
 void ExportSpreadsheetDialog::setFormat(Format format) {
 	m_format = format;
 }
 
+void ExportSpreadsheetDialog::setExportTo(const QStringList &to) {
+	ui.cbExportToFITS->addItems(to);
+}
+
 ExportSpreadsheetDialog::Format ExportSpreadsheetDialog::format() const {
 	return m_format;
 }
